//                 Программа Блока контроля транзисторного усилителя мощности и блока защит с индикацией на TFT_HX8357&ILI9486
//                                         г.Снежное, ДНР, D0ITC, D0ISM 1 января 2018г - 3 декабря 2020г.
//********************************************************************************************************************************* Подключаем библиотеки
#include "src/FreqCount.h"                                                                  //библиотека измерения частоты
#include "src/DS1307RTC.h"                                                                  //библиотека модуля часов реального времени DS3231
#include "src/TimeLib.h"                                                                    //дополнение к "Time.h" макросы для временных констант и преобразования единиц времени
#include <Wire.h>                                                                           //библиотека I2C
#include "src/TonePlayer.h"                                                                 //библиотека формирования тона бипера
#include "src/TFT_HX8357.h"                                                                 //библиотека для индикатора HX8357
#include <EEPROM.h>                                                                         //библиотека EEPROM
#include "src/ACS712.h"                                                                     //библиотека для датчика ACS712
#include "src/OneWire.h"                                                                    //библиотека для датчика ds18b20
#include "src/sav_button.h"                                                                 //библиотека кнопок
#include "src/Free_Fonts.h"                                                                 //шрифт Free_Fonts
OneWire ds1(A3);                                                                            //инициализируем ds18b20
OneWire ds2(A12);                                                                           //инициализируем ds18b20
ACS712 sensor(ACS712_20A,A5);                                                               //инициализируем ACS712 20A
TFT_HX8357 tft=TFT_HX8357();                                                                //вызваем пользовательскую библиотеку
//********************************************************************************************************************************* Задаём константы
#define ACS712_20_AMPERS  0.100                                                             //выбор датчика 20А
#define ACS712_30_AMPERS  0.066                                                             //выбор датчика 30А
#define ACS758_50_AMPERS  0.040                                                             //выбор датчика 50А
#define ACS758_100_AMPERS 0.020                                                             //выбор датчика 100А
#define STEP1 5                                                                             //шаг уменьшения градусника выходной мощности
#define STEP2 10                                                                            //шаг уменьшения градусника входной мощности
#define R1 100                                                                              //входной делитель вольтметра R1(100K)
#define D0 0                                                                                //порт подключения дешифратора ФНЧ(D0)
#define D1 1                                                                                //порт подключения дешифратора ФНЧ(D1)
#define D2 2                                                                                //порт подключения дешифратора ФНЧ(D2)
#define D3 3                                                                                //порт подключения дешифратора ФНЧ(D3)
#define BCD_A_IN  A8                                                                        //порт A8 подключения по стандарту Yaesu BCD
#define BCD_B_IN  A9                                                                        //порт A9 подключения по стандарту Yaesu BCD
#define BCD_C_IN  A10                                                                       //порт A10 подключения по стандарту Yaesu BCD
#define BCD_D_IN  A11                                                                       //порт A11 подключения по стандарту Yaesu BCD
#define att3dB  4                                                                           //порт подключения аттенюатора -3дБ
#define att6dB  5                                                                           //порт подключения аттенюатора -6дБ
#define TX      7                                                                           //порт подключения транзисторного ключа перевода УМ на передачу
#define pttIN   8                                                                           //порт подключения педали PTT
#define Fantemp 9                                                                           //порт подключения транзисторного ключа вентилятора
#define Invers  11                                                                          //инвертирование цвета дисплея
#define Rotat   12                                                                          //ориентация дисплея
#define in120   14                                                                          //порт подключения внешнего делителя мощности 120Вт
#define on_off  15                                                                          //порт управления питанием
#define for(from,to) for(uint16_t i=(from); i<(to); i++)                                    //макрос цикла
TonePlayer tone4 (TCCR4A,TCCR4B,OCR4AH,OCR4AL,TCNT4H,TCNT4L);                               //вывод тонального сигнала на вывод D6
SButton button1(13,50,500,0,0);                                                             //конфигурация кнопоки ON/OFF -------------------------------------
SButton button2(12,50,500,600,200);                                                         //конфигурация кнопоки BAND (BAND "MANUAL", "YAESU", "ICOM", "AUTO")
SButton button3(11,50,500,600,100);                                                         //конфигурация кнопоки ATT (VOX)
SButton button4(10,50,500,600,100);                                                         //конфигурация кнопоки PTT (PWR VIEW), в скобках длинное нажатие
    float Upk1, Upk2, I4pk;                                                                 //переменные пиковых значений
    float U1,U2,U4,U5,U6,I4;                                                                //переменные прямой и обратной волны выходной мощности, входной мощности, тока
    uint8_t I4count;                                                                        //счетчик задержки вывода тока
    int flag_PTT;                                                                           //флаг перевода УМ на передачу кнопкой PTT
    int pwr_on, PTT, beep;                                                                  //переменные кнопок PTT, BEEPER и ON/OFF, выбраны при загрузке
    int valAutoATT;                                                                         //счётчик времени задержки отключения аттенюатора в режиме AutoATT
    long AutoATTMillis;                                                                     //начальное значение для счетчика millis AutoATT
    int att;                                                                                //переменная выбора режима ATT
    int flag_autoATT, flag_auto3dB;                                                         //флаги управления ATT
    int ATTDelay;                                                                           //переменная установки отпускания AUTO ATT в режиме МЕНЮ
    uint8_t VOXcount;                                                                       //счетчик задержки системы VOX
    int VOXDelay;                                                                           //переменная установки задержки отпускания VOX в режиме МЕНЮ
    long VoxMillis;                                                                         //начальное значение для счетчика millis VOX
    int vox;                                                                                //переменная управления режимом VOX
    int band;                                                                               //переменная переключения диапазонов
    int flag_mode_band=1;                                                                   //флаг фиксации состояния индикации режимов переключения диапазонов
    int mode_band;                                                                          //переменная выбора режимов переключения диапазонов
    int band_get;                                                                           //переменная полученного диапазона в режиме "AUTO"
    int flag_band_switch, frq_vox;                                                          //флаг подтверждения переключения диапазона и переменная блокировки TX
    uint16_t frq, frq_old1, frq_old2, frq_old3;                                             //переменные частоты входного сигнала
    int BandDelay;                                                                          //переменная задержки переключения диапазонов в режиме авто
    bool statealarm;                                                                        //переменная состояния флага всех аварийных ситуаций
    long TONE=0;                                                                            //переменная тона звучания сигналов аварийных ситуаций
    int N, Time;                                                                            //переменные количества звуковых сигналов и времени между ними
    int flag_erroralarm;                                                                    //флаг аварийной ситуации по error
    int flag_tempalarm;                                                                     //флаг аварийной ситуации по температуре
    int flag_curalarm;                                                                      //флаг аварийной ситуации по току
    int flag_swralarm;                                                                      //флаг аварийной ситуации по КСВ
    int flag_inputalarm;                                                                    //флаг аварийной ситуации по уровню входного сигнала
    int flag_voltagealarm;                                                                  //флаг аварийной ситуации по напряжению
    int Scale;                                                                              //переменная выбора выходной мощности
    int Acs;                                                                                //переменная выбора датчика тока
    float l2=7.746; float l1=2.45;                                                          //переменные вычисления мощности 3Вт и 30Вт
    float h=15.492;                                                                         //переменная вычисления мощности 120Вт
    float A; int B,C,D;                                                                     //переменные шкалы выходной мощности
    int Red,Green,Blue;                                                                     //переменные для отрисовки цвета градусника выходной мощности
    int pwr_view;                                                                           //переменная для смены вывода на экран часов или информационной строки
    int PWR,PWRf,PWRi,PWRiold=1;                                                            //переменные входных мощностей 30Вт и 120Вт
    float temp,temp1,temp2,vin;                                                             //переменные температуры, вольтметра
    uint8_t num18b20;                                                                       //переменная количества датчиков DS18B20
    uint8_t flagFan;                                                                        //флаг состояния вентилятора
    uint16_t Draw_color,Draw_colorOld;                                                      //переменные цвета знака вентилятора
    uint16_t u,Psupply;                                                                     //переменные КПД и подводимой мощности
    float PWRi3,PWRi3old=1;                                                                 //переменная входной мощности 3Вт
    int InvDisp=0;                                                                          //переменная инвертирования цвета дисплея
    int BORDER,Cclock;                                                                      //переменные изменения цвета окантовок рамки и вывода часов
    int place=0;                                                                            //при загрузке первой страницы меню активируем пункт 1
    int TFanOff,TFanOn,TFanMax;                                                             //переменные управления вентилятором от температуры
    int Imax,Vmin,Vmax;                                                                     //переменные тока и напряжения для срабатывания защиты
    int ATToff,ATT3dB,ATT6dB;                                                               //переменные срабатывания защиты в "ATT OFF", "ATT-3dB" и "ATT-6dB"
    int ATTauto,ATTalarm;                                                                   //переменные мощности срабатывания аттенюатора в "ATT AUTO" и защиты
    float SWRpk;                                                                            //переменная пикового значения КСВ
    uint8_t SWRcount;                                                                       //счетчик времени удержания пикового значения КСВ
    float SWRmax; int Tonbeep;                                                              //переменные максимального КСВ для срабатывания защиты и тона бипера
    uint8_t TimeBeep;                                                                       //переменная включения/выключения "TimeBeep"
    float divider;                                                                          //переменная входного делителя вольтметра R2(10K)
    uint8_t Length,Reserve;                                                                 //переменная переключения вывода дня недели
    int RotationDisp;                                                                       //переменная смены ориентации дисплея
    int powerin;                                                                            //переменная выбора входного градусника 3Вт или 30Вт
    int ALC;                                                                                //переменная выбора режима ALC
    int RefreshTime;                                                                        //переменная времени возобновления счёта усреднения
    int flag_clock=0;                                                                       //флаг подачи звукового сигнала через каждые 15 минут
    bool wait=0;                                                                            //флаг управления выводом надписи "WAIT"
    uint8_t FPS,FPSpk,FPScount;                                                             //переменные FPSF,PSpk,FPScount
    uint32_t millisFPS;                                                                     //счетчик времени FPS
    uint8_t singleBE;                                                                       //флаг однократного срабатывания BAND ERROR
    uint8_t singleIN3;                                                                      //флаг однократного вывода мощности 3Вт
    uint16_t PWRfold=1;                                                                     //переменная предыдущего состояния мощности
    int aOld=1, bOld=1;                                                                     //переменные предыдущего состояния градусников выходной и входной мощности
    uint8_t module;                                                                         //переменная наличия модуля часов DS3231
    tmElements_t tm;                                                                        //фукция вызова часов
    uint16_t dy,da,mo,ya;                                                                   //переменные дня, дня недели, месяца и года
    uint8_t newsecond;                                                                      //переменная секунд
    uint8_t rnd;                                                                            //переменная выбора номера визуального эффекта (анимации)
    volatile uint8_t Seconds;                                                               //переменная счетчика секунд
    volatile uint8_t ss,mm,hh;                                                              //переменные секунд, минут и часов
    volatile uint8_t singleTemp=1;                                                          //флаг вызова измерения температуры
    byte decToBcd(byte val){return((val/10*16)+(val%10));}                                  //перевод из десятичных чисел в двоичные
    uint8_t pwr_inv;                                                                        //переменная инверсии защиты отключения питания

void setup(){//==================================================================================================================== Установочная часть программы
    tft.init();                                                                             //инициализируем дисплей
    button1.begin(); button2.begin(); button3.begin(); button4.begin();                     //инициализируем кнопоки
    FreqCount.begin(1);                                                                     //инициализируем библиотеку измерения частоты
    TCCR1A=(1<<WGM11);                                                                      //режим 14 FAST PWM 
    TCCR1B=(1<<CS12)|(1<<WGM13)|(1<<WGM12);                                                 //делить частоту CPU на 256
    ICR1=62027;                                                                             //регистр переполнений
    TIMSK1=(1<<TOIE1);                                                                      //разрешить прерывание
    
    Wire.requestFrom(104,2);                                                                //проверяем наличие модуля DS3231
  if (Wire.available()) module=1;                                                           //если есть, флаг в 1
    
    ds1.reset(); ds1.write(0xCC); ds1.write(0x44);                                          //сброс датчика 1 при загрузке программы
    ds1.reset(); ds1.write(0xCC); ds1.write(0xBE);                                          //запрос данных от датчика 1
    temp1=((ds1.read()|(ds1.read()<<8)))/16.0;                                              //получение температуры от датчика 1 в градусах цельсия
    ds2.reset(); ds2.write(0xCC); ds2.write(0x44);                                          //сброс датчика 2 при загрузке программы
    ds2.reset(); ds2.write(0xCC); ds2.write(0xBE);                                          //запрос данных от датчика 2
    temp2=((ds2.read()|(ds2.read()<<8)))/16.0;                                              //получение температуры от датчика 2 в градусах цельсия
  if (!temp1 && !temp2)   num18b20=0;                                                       //не подключено ни одного датчика DS18B20
  if ((temp1 && !temp2)||                                                                   //подключен один датчик DS18B20
     (!temp1 && temp2))   num18b20=1;                                                       //-----------------------------
  if (temp1  &&  temp2)   num18b20=2;                                                       //подключены оба датчика DS18B20
    
    pinMode(D0,OUTPUT);                                                                     //назначаем вывод(D0)на выход, подключение дешифратора ФНЧ(0)
    pinMode(D1,OUTPUT);                                                                     //назначаем вывод(D1)на выход, подключение дешифратора ФНЧ(1)
    pinMode(D2,OUTPUT);                                                                     //назначаем вывод(D2)на выход, подключение дешифратора ФНЧ(2)
    pinMode(D3,OUTPUT);                                                                     //назначаем вывод(D3)на выход, подключение дешифратора ФНЧ(3)
    pinMode(BCD_A_IN, INPUT);                                                               //назначаем вывод(A8)на вход
    pinMode(BCD_B_IN, INPUT);                                                               //назначаем вывод(A9)на вход
    pinMode(BCD_C_IN, INPUT);                                                               //назначаем вывод(A10)на вход
    pinMode(BCD_D_IN, INPUT);                                                               //назначаем вывод(A11)на вход
    pinMode(att3dB,OUTPUT);                                                                 //назначаем порт управления att-3dB на выход(4)
    pinMode(att6dB,OUTPUT);                                                                 //назначаем порт управления att-6dB на выход(5)
    pinMode(6,OUTPUT);                                                                      //назначаем порт пьезо излучателя на выход(6)
    pinMode(TX,OUTPUT);                                                                     //назначаем управление PTT на выход(7)
    pinMode(pttIN,INPUT_PULLUP);                                                            //назначаем вывод подключения педали PTT на вход с внутренней подтяжкой к +(8)
    pinMode(Fantemp,OUTPUT);                                                                //назначаем управление вентилятором на выход(9)
    pinMode(Invers,INPUT_PULLUP);                                                           //назначаем вывод кнопки Invers на вход с внутренней подтяжкой к +5v(11)
    pinMode(Rotat,INPUT_PULLUP);                                                            //назначаем вывод кнопки Rotat на вход с внутренней подтяжкой к +5v(12)
    pinMode(in120,OUTPUT);                                                                  //назначаем вывод подключения внешнего делителя на выход(14)
    pinMode(on_off,OUTPUT);                                                                 //назначаем вывод управления питанием на выход(15)
    
    pwr_inv=EEPROM.read(40);                                                                //читаем из 40 ячейки EEPROM состояние инверсии защиты по питанию
  if (pwr_inv>1){EEPROM.update(40,0); pwr_inv=EEPROM.read(40);}                             //если больше 1, обновляем как 0 и еще раз читаем из памяти
  switch (pwr_inv){                                                                         //инверсия защиты отключения питания
    case 0: digitalWrite(on_off,LOW); break;                                                //если инверсия отключена, на выходе 0
    case 1: digitalWrite(on_off,HIGH); break;}                                              //если инверсия включена, на выходе 1
    
    band=EEPROM.read(0);                                                                    //читаем состояние выбранного диапазона из нулевой ячейки EEPROM
  if ((band<1)||(band>10)){EEPROM.update(0,5); band=EEPROM.read(0);}                        //если в ячейке не коррректное значение пишем по умолчанию

    mode_band=EEPROM.read(1);                                                               //читаем состояние выбранного режима переключения диапазонов из первой ячейки EEPROM
  if ((mode_band<1)||(mode_band>5)){EEPROM.update(1,5); mode_band=EEPROM.read(1);}          //если в ячейке не коррректное значение пишем по умолчанию

    att=EEPROM.read(2);                                                                     //читаем состояние аттенюаторов из второй ячейки EEPROM
  if ((att<1)||(att>4)){EEPROM.update(2,1); att=EEPROM.read(2);}                            //если в ячейке не коррректное значение пишем по умолчанию

    vox=EEPROM.read(3);                                                                     //читаем состояние VOX из третьей ячейки EEPROM
  if (vox>1){EEPROM.update(3,0); vox=EEPROM.read(3);}                                       //если в ячейке не коррректное значение пишем по умолчанию

    beep=EEPROM.read(4);                                                                    //читаем из 4 ячейки EEPROM состояние beep
  if (beep>1){EEPROM.update(4,1); beep=EEPROM.read(4);}                                     //если в ячейке не коррректное значение пишем по умолчанию

    pwr_view=EEPROM.read(5);                                                                //читаем из 5 ячейки EEPROM состояние pwr_view
  if (pwr_view>1){EEPROM.update(5,1); pwr_view=EEPROM.read(5);}                             //если в ячейке не коррректное значение пишем по умолчанию

    RefreshTime=EEPROM.read(7);                                                             //читаем из 7 ячейки EEPROM состояние RefreshTime
  if ((RefreshTime<2)||(RefreshTime>50)){EEPROM.update(7,5); RefreshTime=EEPROM.read(7);}   //если в ячейке не коррректное значение пишем по умолчанию

    Acs=EEPROM.read(8);                                                                     //читаем из 8 ячейки EEPROM состояние Acs
  if ((Acs<1)||(Acs>4)){EEPROM.update(8,2); Acs=EEPROM.read(8);}                            //если в ячейке не коррректное значение пишем по умолчанию

    Length=EEPROM.read(9);                                                                  //читаем из 9 ячейки EEPROM состояние Length
  if (Length>1){EEPROM.update(9,1); Length=EEPROM.read(9);}                                 //если в ячейке не коррректное значение пишем по умолчанию

    VOXDelay=EEPROM.read(10);                                                               //читаем из 10 ячейки EEPROM состояние TimeVox
  if ((VOXDelay<2)||(VOXDelay>100)){EEPROM.update(10,15); VOXDelay=EEPROM.read(10);}        //если в ячейке не коррректное значение пишем по умолчанию

    ATTDelay=EEPROM.read(11);                                                               //читаем из 11 ячейки EEPROM состояние TimeAutoATT
  if ((ATTDelay<1)||(ATTDelay>250)){EEPROM.update(11,2); ATTDelay=EEPROM.read(11);}         //если в ячейке не коррректное значение пишем по умолчанию

    Imax=EEPROM.read(12);                                                                   //читаем из 12 ячейки EEPROM состояние Imax
  if (Imax>100){EEPROM.update(12,25); Imax=EEPROM.read(12);}                                //если в ячейке не коррректное значение пишем по умолчанию

    Vmin=EEPROM.read(13);                                                                   //читаем из 13 ячейки EEPROM состояние Vmin
  if (Vmin>50){EEPROM.update(13,45); Vmin=EEPROM.read(13);}                                 //если в ячейке не коррректное значение пишем по умолчанию

    Vmax=EEPROM.read(14);                                                                   //читаем из 14 ячейки EEPROM состояние Vmax
  if (Vmax>60){EEPROM.update(14,50); Vmax=EEPROM.read(14);}                                 //если в ячейке не коррректное значение пишем по умолчанию

    TFanOff=EEPROM.read(15);                                                                //читаем из 15 ячейки EEPROM состояние TFanOff
  if (TFanOff>50){EEPROM.update(15,28); TFanOff=EEPROM.read(15);}                           //если в ячейке не коррректное значение пишем по умолчанию

    TFanOn=EEPROM.read(16);                                                                 //читаем из 16 ячейки EEPROM состояние TFanOn
  if (TFanOn>50){EEPROM.update(16,30); TFanOn=EEPROM.read(16);}                             //если в ячейке не коррректное значение пишем по умолчанию

    TFanMax=EEPROM.read(17);                                                                //читаем из 17 ячейки EEPROM состояние TFanMax
  if (TFanMax>75){EEPROM.update(17,31); TFanMax=EEPROM.read(17);}                           //если в ячейке не коррректное значение пишем по умолчанию

    BandDelay=EEPROM.read(18);                                                              //читаем из 18 ячейки EEPROM состояние BandDelay
  if ((BandDelay<1)||(BandDelay>20)){EEPROM.update(18,5); BandDelay=EEPROM.read(18);}       //если в ячейке не коррректное значение пишем по умолчанию

    RotationDisp=EEPROM.read(19);                                                           //читаем содержимое ячейки 19 и выводим ориентацию дисплея
  if (RotationDisp>3){EEPROM.update(19,3); RotationDisp=EEPROM.read(19);}                   //если в ячейке не коррректное значение пишем по умолчанию

    ATToff=EEPROM.read(20);                                                                 //читаем из 20 ячейки EEPROM состояние ATToff
  if (ATToff>30){EEPROM.update(20,15); ATToff=EEPROM.read(20);}                             //если в ячейке не коррректное значение пишем по умолчанию

    ATT3dB=EEPROM.read(21);                                                                 //читаем из 21 ячейки EEPROM состояние ATT3dB
  if (ATT3dB>30){EEPROM.update(21,25); ATT3dB=EEPROM.read(21);}                             //если в ячейке не коррректное значение пишем по умолчанию

    ATT6dB=EEPROM.read(22);                                                                 //читаем из 22 ячейки EEPROM состояние ATT6dB
  if (ATT6dB>30){EEPROM.update(22,30); ATT6dB=EEPROM.read(22);}                             //если в ячейке не коррректное значение пишем по умолчанию

    ATTauto=EEPROM.read(23);                                                                //читаем из 23 ячейки EEPROM состояние ATTauto
  if (ATTauto>30){EEPROM.update(23,15); ATTauto=EEPROM.read(23);}                           //если в ячейке не коррректное значение пишем по умолчанию

    ATTalarm=EEPROM.read(24);                                                               //читаем из 24 ячейки EEPROM состояние ATTalarm
  if (ATTalarm>30){EEPROM.update(24,25); ATTalarm=EEPROM.read(24);}                         //если в ячейке не коррректное значение пишем по умолчанию

    TimeBeep=EEPROM.read(25);                                                               //читаем из 25 ячейки EEPROM состояние TimeBeep
  if (TimeBeep>1){EEPROM.update(25,1); TimeBeep=EEPROM.read(25);}                           //если в ячейке не коррректное значение пишем по умолчанию

    Tonbeep=EEPROM.read(26);                                                                //читаем из 26 ячейки EEPROM состояние Tonbeep
  if (Tonbeep>30){EEPROM.update(26,9); Tonbeep=EEPROM.read(26);}                            //если в ячейке не коррректное значение пишем по умолчанию

    EEPROM.get(27,SWRmax);                                                                  //читаем из 27-30 ячеек EEPROM состояние SWRmax
  if ((isnanf(SWRmax)==true)||((SWRmax<1.2)||(SWRmax>9.9))){                                //
    EEPROM.put(27,3.0); EEPROM.get(27,SWRmax);}                                             //если в ячейке не коррректное значение пишем по умолчанию

    EEPROM.get(31,divider);                                                                 //читаем из 31-34 ячеек EEPROM состояние divider
  if ((isnanf(divider)==true)||((divider<9.0)||(divider>11.0))){                            //
    EEPROM.put(31,10.0); EEPROM.get(31,divider);}                                           //если в ячейке не коррректное значение пишем по умолчанию

    Scale=EEPROM.read(35);                                                                  //читаем из 35 ячейки EEPROM состояние Scale
  if ((Scale<1)||(Scale>4)){EEPROM.update(35,2); Scale=EEPROM.read(35);}                    //если в ячейке не коррректное значение пишем по умолчанию

    BORDER=EEPROM.read(36);                                                                 //читаем из 36 ячейки EEPROM состояние BORDER
  if ((BORDER<1)||(BORDER>5)){EEPROM.update(36,2); BORDER=EEPROM.read(36);}                 //если в ячейке не коррректное значение пишем по умолчанию

    ALC=EEPROM.read(37);                                                                    //читаем из 37 ячейки EEPROM состояние ALC
  if (ALC>1){EEPROM.update(37,0); ALC=EEPROM.read(37);}                                     //если в ячейке не коррректное значение пишем по умолчанию

    Cclock=EEPROM.read(38);                                                                 //читаем из 38 ячейки EEPROM состояние Cclock
  if ((Cclock<1)||(Cclock>5)){EEPROM.update(38,2); Cclock=EEPROM.read(38);}                 //если в ячейке не коррректное значение пишем по умолчанию

    powerin=EEPROM.read(39);                                                                //читаем из 39 ячейки EEPROM состояние powerin
  if (powerin>1){EEPROM.update(39,1); powerin=EEPROM.read(39);}                             //если в ячейке не коррректное значение пишем по умолчанию

  if (digitalRead(Rotat)==LOW){RotationDisp=EEPROM.read(19);                                //при включении питания с удержанием кнопки Rotat читаем текущее значение "RotationDisp"
    tft.fillRoundRect(8,8,464,304,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
    tft.setFreeFont(FSBI24); tft.drawCentreString("Display rotation",243,103,1);            //выводим подложку надписи "Display rotation"
    tft.setTextColor(TFT_RED); tft.drawCentreString("Display rotation",240,100,1);          //выводим надпись "Display rotation"
  while (digitalRead(Rotat)==LOW){}                                                         //ждём отпускания кнопки "Rotat"
  if (RotationDisp==3){EEPROM.write(19,1);}                                                 //если значение RotationDisp==3 пишем в ячейку 19 1
  if (RotationDisp==1){EEPROM.write(19,3);}}                                                //если значение RotationDisp==1 пишем в ячейку 19 3
  
  if (digitalRead(Invers)==LOW){InvDisp=EEPROM.read(6);                                     //при включении питания с удержанием кнопки Invers читаем текущее значение "InvDisp"
    tft.fillRoundRect(8,8,464,304,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
    tft.setFreeFont(FSBI24); tft.drawCentreString("Display inversion",243,103,1);           //выводим подложку надписи "Display inversion"
    tft.setTextColor(TFT_RED); tft.drawCentreString("Display inversion",240,100,1);         //выводим надпись "Display inversion"
  while (digitalRead(Invers)==LOW){}                                                        //ждём отпускания кнопки "Invers"
    EEPROM.write(6,!InvDisp);}                                                              //инвертируем состояние и пишем в 6 ячейку EEPROM
    
    InvDisp=EEPROM.read(6);                                                                 //читаем содержимое ячейки 6 и выводим нормальный или инверсный цвет дисплея
  if (InvDisp>1) EEPROM.update(6,0);                                                        //если в ячейке не коррректное значение пишем по умолчанию
    tft.invertDisplay(EEPROM.read(6));                                                      //читаем содержимое ячейки 6 и выводим нормальный или инверсный цвет дисплея
    tft.setRotation(EEPROM.read(19));                                                       //читаем содержимое ячейки 19 и выводим ориентацию дисплея
    
    tft.fillScreen(TFT_GREY60);//************************************************************ Заставка
    tft.fillRoundRect(6,6,468,308,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
  if (BORDER==1){BORDER=TFT_GREEN;}                                                         //если BORDER==1 включается зелёный цвет окантовок рамки
  if (BORDER==2){BORDER=TFT_SILVER;}                                                        //если BORDER==2 включается серебряный цвет окантовок рамки
  if (BORDER==3){BORDER=TFT_PINK;}                                                          //если BORDER==3 включается розовый цвет окантовок рамки
  if (BORDER==4){BORDER=TFT_ORANGE;}                                                        //если BORDER==3 включается оранжевый цвет окантовок рамки
  if (BORDER==5){BORDER=TFT_CYAN;}                                                          //если BORDER==3 включается голубой цвет окантовок рамки
  for(0,2){                                                                                 //включаем цикл
    tft.drawRect(0+i,0+i,480-i*2,320-i*2,BORDER);                                           //рисуем наружную окантовку
    tft.drawRoundRect(6+i,6+i,468-i*2,308-i*2,8-i,BORDER);}                                 //рисуем внутреннюю окантовку с закруглёнными углами
    
    tft.setFreeFont(FSSB9); tft.setTextColor(TFT_DARKGREY);                                 //шрифт FSSB9, темно-серый цвет
  if (module) tft.drawCentreString("DS3231 is enabled ...",120,15,1);                       //если модуль часов подключен, выводим "DS3231 is enabled ..."
  else        tft.drawCentreString("DS3231 is disabled ...",120,15,1);                      //если не подключен выводим "DS3231 is disabled ..."
    char cstr[6];                                                                           //символьная переменная
    sprintf(cstr,"Number DS18B20 = %d",num18b20); tft.drawCentreString(cstr,360,15,1);      //выводим число подключенных датчиков DS18B20

    tft.setFreeFont(FSBI24); tft.setTextColor(TFT_DARKGREY);                                //подключаем внешний шрифт FSBI24, выбираем цвет текста
    tft.drawCentreString("PA Control Unit",243,103,1);                                      //выводим подложку надписи "PA Control Unit"
    tft.drawCentreString("With Protection",243,153,1);                                      //выводим подложку надписи "With Protection"
    tft.setTextColor(TFT_RED);                                                              //устанавливаем цвет текста
    tft.drawCentreString("PA Control Unit",240,100,1);                                      //выводим надпись "PA Control Unit"
    tft.drawCentreString("With Protection",240,150,1);                                      //выводим надпись "With Protection"
    tft.setFreeFont(FSBI18); tft.setTextColor(TFT_DARKGREY);                                //подключаем внешний шрифт FSBI18, выбираем цвет текста
    tft.drawCentreString("D0ITC 2020 D0ISM",240,260,1);                                     //выводим надпись "D0ISM 2019 D0ICT"
    delay(3000);                                                                            //задержка 2с
    U4=analogRead(A4);                                                                      //предварительное чтение уровня напряжения блока питания
    animation();                                                                            //анимация
    preparing_the_screen();}                                                                //вызываем подпрограмму подготовки экрана
    
    ISR(TIMER1_OVF_vect){//****************************************** Таймер ************** //подпрограмма прерываний каждые 1 сек
    singleTemp=1;                                                                           //флаг однократного считывания температуры с датчика(ов) DS18B20
  if (++Seconds>59) Seconds=0;                                                              //секундный интервал
  if (!module){                                                                             //получаем время, если отсутствует модуль часов
  if (++ss>59){ss=0;                                                                        //если значение секунд больше 59 обнуляем секунды и добавляем единицу к минутам
  if (++mm>59){mm=0;                                                                        //если значение минут больше 59 обнуляем минуты и добавляем единицу к часам
  if (++hh>23)hh=0;}}}                                                                      //если значение часов больше 23 обнуляем часы
}
void loop(){//===================================================================================================================== Основной цикл
    FPS=1000/(millis()-millisFPS); millisFPS=millis();                                      //вычисляем кол-во проходов пр-мы за 1000 мсек
  if (FPS>FPSpk) {FPSpk=FPS; FPScount=0;}                                                   //фиксируем пиковое значение FPSpk, обнуляем счетчик
  if ((++FPScount<31)&&(FPSpk<100)){                                                        //если счетчик меньше 31 и FPS меньше 100
    tft.setTextPadding(15); tft.setTextColor(TFT_CYAN,TFT_RED);                             //цвет шрифта
    tft.drawNumber(FPSpk,10,12,2);}                                                         //выводим значение FPSpk
  else FPSpk=FPS;                                                                           //иначе обновляем новое значение FPSpk

    U1=(analogRead(A0)+U1)/2;                                                               //новый алгоритм обработки от скачков напряжения на входе АЦП
    U2=(analogRead(A1)+U2)/2;                                                               //и усреднения сигнала на ходу без остановки программы
    U4=(analogRead(A4)+U4)/2;                                                               //
    U5=(analogRead(A6)+U5)/2;                                                               //
    U6=(analogRead(A7)+U6)/2;                                                               //
    I4=(sensor.getCurrentDC()+I4)/2;                                                        //
  
  if (U1<10) U1=0;                                                                          //убираем шум на входе АЦП
  if (U2<10) U2=0;                                                                          //убираем шум на входе АЦП
  if (U5<10) U5=0;                                                                          //убираем шум на входе АЦП
  
  if (U1>Upk1) Upk1=U1;                                                                     //фиксируем пиковое напряжение градусника 1
  if (U2>Upk2) Upk2=U2;                                                                     //фиксируем пиковое напряжение градусника 2
  if (Upk1){                                                                                //если пиковое значение больше 0
  if (Upk1<STEP1) Upk1=0;                                                                   //если пиковое значение меньше шага 1, обнуляем пиковое значение 1
  else Upk1-=STEP1;}                                                                        //иначе уменьшаем "высоту градусника 1"
  if (Upk2){                                                                                //если пиковое значение больше 0
  if (Upk2<STEP2) Upk2=0;                                                                   //если пиковое значение меньше шага 2, обнуляем пиковое значение 2
  else Upk2-=STEP2;}                                                                        //уменьшение "высоты градусника 2"

  if (singleTemp){singleTemp=0; set_temp(); get3231();}                                     //вызываем подпрограммы
     energy();                                                                              //
    float SWR;//***************************************************************************** Расчёт КСВ
    tft.setFreeFont(FSSB12); tft.setTextColor(TFT_GREY60);                                  //шрифт FSSB12, серый цвет
  if ((!U1)&&(!wait)){wait=1; SWR=1;                                                        //если прямая волна равна нулю выводим "WAIT"
    tft.fillRoundRect(8,172,170,54,8,TFT_BLACK);                                            //стираем предыдущее значение
    tft.drawString("SWR = WAIT",25,192,1);}                                                 //выводим "SWR = WAIT"
  if ((U1)&&(U5)&&(U5>=U1))SWR=9.99;                                                        //если обратная больше прямой волны, то КСВ равно 9.99
  if (U1>U5) SWR=(U1+U5)/(U1-U5);                                                           //если U1>U5, то расчитываем значение КСВ
  if (SWR>=9.99) SWR=9.99;                                                                  //ограничиваем значение КСВ на уровне 9.99
  
  if (U1){wait=0;                                                                           //если есть напряжение прямой волны U1
  if (SWR<SWRmax) tft.setTextColor(TFT_GREEN,TFT_BLACK);                                    //если SWR<SWRmax выбираем зелёный цвет надписи
  if (SWR>=SWRmax)tft.setTextColor(TFT_RED,TFT_BLACK);                                      //если SWR>=SWRmax, выбираем красный цвет надписи
  if (SWR>=SWRpk) {SWRpk=SWR; SWRcount=0;}                                                  //фиксируем пиковое значение SWRpk, обнуляем счетчик
  if (++SWRcount<21){                                                                       //если счетчик меньше 21
    tft.setTextPadding(0); tft.drawString("SWR =",25,192,1);                                //выводим "SWR ="
    tft.setTextPadding(65); tft.drawFloat(SWRpk,2,107,190,4);}                              //выводим значение КСВ
  else SWRpk=SWR;}                                                                          //иначе обновляем новое значение SWRpk
  
  if ((SWR>=SWRmax)&&(!statealarm)){flag_swralarm=1;                                        //если SWR>=SWRmax и флаг аварии 0, устанавливаем флаг аварии в 1
    PTT=0; flag_PTT=0; pwr_on=0;                                                            //
    tft.setTextColor(TFT_RED,TFT_BLACK);                                                    //выбираем красный цвет надписи
    tft.setTextPadding(152); TONE=500; Time=150; N=3;                                       //включаем обновление подложки шрифта, включаем тон частотой 500Гц через 150мc
    tft.drawString("SWR  HIGH!!!",200,120,4);                                               //выводим надпись "SWR  HIGH!!!" красным цветом
    tft.setTextPadding(50); tft.drawCentreString("",440,120,4);}                            //стираем "VOX" или "TX"
  if (!statealarm){//************************************************************************ Сигнализация аварийных ситуаций
  if ((flag_tempalarm)||(flag_curalarm)||(flag_swralarm)||                                  //при совпадении одного из флагов аварий
     (flag_inputalarm)||(flag_voltagealarm)||(flag_erroralarm)){                            //-------------------------------
    digitalWrite(TX,LOW);                                                                   //на выводе TX низкий уровень
  switch (pwr_inv){                                                                         //отключение питания
    case 0: digitalWrite(on_off,LOW); break;                                                //если инверсия отключена, на выходе 0
    case 1: digitalWrite(on_off,HIGH); break;}                                              //если инверсия включена, на выходе 1
    PTT=0; flag_PTT=0; pwr_on=0; PWRSwitch(); draw_inp_pwr120();                            //флаг передачи и питания в 0, масштаб входной мощности 120Вт
    tft.setTextPadding(50); tft.drawCentreString("",440,120,4);                             //стираем "VOX" или "TX"
  for(0,N){tone4.tone(TONE);                                                                //включаем цикл N-ного повторения тонального сигнала
  for(0,6){tft.drawRect(i,i,480-i*2,320-i*2,TFT_RED);}                                      //включаем цикл, мигаем наружной окантовкой красным цветом
    delay(Time);                                                                            //в зависимости от сработанной аварии меняем длительность тонального сигнала
    tone4.noTone();                                                                         //выключаем тональный сигнал
  for(0,2){tft.drawRect(i,i,480-i*2,320-i*2,BORDER);}                                       //восстанавливаем серебряный цвет наружной рамки
  for(0,4){tft.drawRect(2+i,2+i,476-i*2,316-i*2,TFT_GREY60);}                               //восстанавливаем серый цвет наружной рамки
    delay(Time);}                                                                           //в зависимости от сработанной аварии меняем длительность паузы тонального сигнала
    statealarm=1;}}                                                                         //по окончании цикла устанавливаем сосотояние флага "statealarm=true"
//******************************************************************************************* Сигнализация переключения диапазонов
  if (flag_band_switch){tone4.tone(2800); PTT=0; flag_PTT=0;                                //если флаг переключения диапазона больше 0, тональный сигнал, режим приема
  if (++flag_band_switch>BandDelay){flag_band_switch=0; tone4.noTone();}}                   //увеличиваем флаг на 1 с каждым проходом до значения задержки, флаг в 0, откл. сигнал

//******************************************************************************************* Сигнал таймбипа
  if (((mm==15)||(mm==30)||(mm==45))&&(ss==0)&&(TimeBeep)){                                 //каждые 15, 30, 45 минут, 0 секунд и флаг таймбипа 1
  if (++flag_clock<10) tone4.tone(1800); else tone4.noTone();}                              //начинаем считать время, тональный сигнал, после отключаем сигнал
  if ((mm==0)&&(ss==0)&&(TimeBeep)){                                                        //каждые 0 минут и секунд и флага таймбипа 1
  if (++flag_clock<20) tone4.tone(2200); else tone4.noTone();}                              //начинаем считать время, тональный сигнал, после отключаем сигнал
  if (((mm==15)||(mm==30)||(mm==45)||(mm==0))&&(ss==1)) flag_clock=0;                       //через каждые 15 минут и 1 секунду сбрасываем флаг в 0
  switch(button1.Loop()){//****************************************************************** Кнопка питания
    case SB_CLICK: beeper(); if (++pwr_on>1) pwr_on=0;                                      //определяем алгоритм работы кнопки ON/OFF по короткому нажатию с бипером
  if (pwr_on) {PWRSwitch(); VOXcount=VOXDelay;                                              //если питание включено, обновляем кнопку ON/OFF, выравниваем счетчик задержки VOX
  if (powerin==0){draw_inp_pwr3(); singleIN3=0; PWRi3old=1;}                                //выводим прорисовку шкалы 3Вт
  if (powerin==1){draw_inp_pwr30();}                                                        //выводим прорисовку шкалы 30Вт
     statealarm=0; flag_auto3dB=0;                                                          //сбрасываем флаги в 0 (сброс аварии)
    flag_inputalarm=0; flag_voltagealarm=0;                                                 //
    flag_swralarm=0; flag_curalarm=0; flag_tempalarm=0;                                     //
    flag_erroralarm=0; band=band_get; singleBE=0;                                           //выравниваем значение диапазона
  switch (pwr_inv){                                                                         //включение питания
    case 0: digitalWrite(on_off,HIGH); break;                                               //если инверсия отключена, на выходе 1
    case 1: digitalWrite(on_off,LOW); break;}}                                              //если инверсия включена, на выходе 0

  if (!pwr_on) {PWRSwitch();                                                                //если питание отключено, обновляем кнопку ON/OFF
    tft.setTextPadding(50); tft.drawCentreString("",440,120,4);                             //стираем "VOX" или "TX"
    tft.setTextPadding(152); tft.drawString("",200,120,4);                                  //стираем надписи всех аттенюаторов
    PTT=0; digitalWrite(TX,LOW); draw_inp_pwr120(); PWRiold=1;                              //режим приема, выводим в порт TX 0, рисуем шкалу 120Вт
  switch (pwr_inv){                                                                         //инверсия включения/отключения питания
    case 0: digitalWrite(on_off,LOW); break;                                                //если инверсия отключена, на выходе 0
    case 1: digitalWrite(on_off,HIGH); break;}                                              //если инверсия включена, на выходе 1
    EEPROM.update(0,band); EEPROM.update(1,mode_band);                                      //записываем состояние режимов "band" и "mode_band" в EEPROM
    EEPROM.update(2,att); EEPROM.update(3,vox);                                             //записываем состояние режимов "att" и "vox" в EEPROM
    EEPROM.update(5,pwr_view);} break;                                                      //записываем состояние режима "pwr_view"
    case SB_LONG_CLICK: pwr_on=0; PTT=0; beeper();                                          //длинным нажатием
    digitalWrite(TX,LOW);                                                                   //выключаем "TX" и входим в меню с бипером
    EEPROM.update(0,band); EEPROM.update(1,mode_band);                                      //записываем состояние режимов "band" и "mode_band" в EEPROM
    EEPROM.update(2,att); EEPROM.update(3,vox);                                             //записываем состояние режимов "att" и "vox" в EEPROM
    EEPROM.update(5,pwr_view); animation(); menu(); break;}                                 //записываем состояние режима "pwr_view", анимация, меню
  switch (button2.Loop()){//***************************************************************** Переключение диапазонов
    case SB_CLICK: if (mode_band==1){if (++band>10) band=1; beeper();}                      //по короткому нажатию в режиме "MANUAL"
   band_get=band; break;                                                                    //переключаем диапазоны с бипером
    case SB_LONG_CLICK: mode_band++; beeper(); flag_mode_band=1;                            //по длинному нажатию переключаем режим перекл. диапазонов, флаг в 1
  if (mode_band>5) mode_band=1; break;}                                                     //ограничиваем значение до 5
  
  if (((mode_band==1)||(mode_band==5)) && FreqCount.read()){                                //в ручном и авто режимах при наличии частоты на входе
  for(0,3){frq=FreqCount.read()*0.16; delay(2);                                             //измеряем входную частоту и приводим её к виду 17...300(шаг 100)
  if (frq>frq_old1) frq_old1=frq;}                                                          //получаем наивысшую частоту "frq_old1"
  for(0,3){frq=FreqCount.read()*0.16; delay(2);                                             //измеряем входную частоту и приводим её к виду 17...300(шаг 100)
  if (frq>frq_old2) frq_old2=frq;}                                                          //получаем наивысшую частоту "frq_old2"
  for(0,3){frq=FreqCount.read()*0.16; delay(2);                                             //измеряем входную частоту и приводим её к виду 17...300(шаг 100)
  if (frq>frq_old3) frq_old3=frq;}                                                          //получаем наивысшую частоту "frq_old3"
  if ((frq_old1==frq_old2)&&(frq_old2==frq_old3)) frq_vox=frq_old1;                         //сравниваем три частоты и при их равенстве записываем в "frq_vox"
  
  switch (frq_vox){                                                                         //после цикла выбора наивысшей частоты и совпадения частот
    case  16 ... 31:  band_get=1;  break;                                                   //получаем диапазон для переключения 160м(1)
    case  32 ... 50:  band_get=2;  break;                                                   //получаем диапазон для переключения 80м (2)
    case  51 ... 80:  band_get=3;  break;                                                   //получаем диапазон для переключения 40м (3)
    case  81 ... 120: band_get=4;  break;                                                   //получаем диапазон для переключения 30м (4)
    case 121 ... 160: band_get=5;  break;                                                   //получаем диапазон для переключения 20м (5)
    case 161 ... 190: band_get=6;  break;                                                   //получаем диапазон для переключения 17м (6)
    case 191 ... 230: band_get=7;  break;                                                   //получаем диапазон для переключения 15м (7)
    case 231 ... 260: band_get=8;  break;                                                   //получаем диапазон для переключения 12м (8)
    case 261 ... 300: band_get=9;  break;                                                   //получаем диапазон для переключения 10м (9)
    case 301 ... 510: band_get=10; break;}}                                                 //получаем диапазон для переключения 6м (10)

  else {frq_old1=0; frq_old2=0; frq_old3=0; frq_vox=0;}                                     //если частоты нет, обнуляем промежуточные счетчики

  if ((mode_band==1)&&(band_get!=band)&&(singleBE==0)){singleBE=1; band=11;                 //если текущий диапазон не совпадает с новым, флаг аварии 1, диапазон 11
    flag_PTT=0; pwr_on=0;}                                                                  //переключаем на шкалу 120Вт, обновляем кнопку ON/OFF
  
  if (mode_band==2){                                                                        //если выбран режим "YAESU-817"
  switch (analogRead(A2)){                                                                  //читаем состояние входа А2
    case 0   ... 70 :   band=1; break;                                                      //-- 160m ------ (0...0,34v) --------------
    case 71  ... 140:   band=2; break;                                                      //-- 80m ------- (0,34...0,68v) -----------
    case 141 ... 210:   band=3; break;                                                      //-- 40m ------- (0,68...1,02v) -----------
    case 211 ... 272:   band=4; break;                                                      //-- 30m ------- (1,02...1,36v) -----------
    case 273 ... 344:   band=5; break;                                                      //-- 20m ------- (1,36...1,7v)-------------
    case 345 ... 470:   band=6; break;                                                      //-- 17m ------- (1,7...2,04v) ------------
    case 471 ... 485:   band=7; break;                                                      //-- 15m ------- (2,04...2,38v) -----------
    case 486 ... 538:   band=8; break;                                                      //-- 12m ------- (2,38...2,72v) -----------
    case 539 ... 608:   band=9; break;                                                      //-- 10m ------- (2,72...3,06v) -----------
    case 609 ... 1023: band=10; break;}}                                                    //-- 6m -------- (3,06...3,4v) ------------
  
  if (mode_band==3){                                                                        //если выбран режим "YAESU-BCD"
    bool bcdA=0;                                                                            //Yaesu вывод 4 разъёма DIN8
    bool bcdB=0;                                                                            //Yaesu вывод 5 разъёма DIN8
    bool bcdC=0;                                                                            //Yaesu вывод 6 разъёма DIN8
    bool bcdD=0;                                                                            //Yaesu вывод 7 разъёма DIN8
  if (analogRead(BCD_A_IN)>409){bcdA=true;}                                                 //если на входе порта A8 больше 2в, bcdA=true
  else {bcdA=false;}                                                                        //иначе bcdA=false
  if (analogRead(BCD_B_IN)>409){bcdB=true;}                                                 //если на входе порта A9 больше 2в, bcdB=true
  else {bcdB=false;}                                                                        //иначе bcdB=false
  if (analogRead(BCD_C_IN)>409){bcdC=true;}                                                 //если на входе порта A10 больше 2в, bcdC=true
  else {bcdC=false;}                                                                        //иначе bcdC=false
  if (analogRead(BCD_D_IN)>409){bcdD=true;}                                                 //если на входе порта A11 больше 2в, bcdD=true
  else {bcdD=false;}                                                                        //иначе bcdD=false
  if (bcdA&&!bcdB&&!bcdC&&!bcdD) {band= 1;}                                                 //--A=1--B=0--C=0--D=0------- 160m ---------
  if (!bcdA&&bcdB&&!bcdC&&!bcdD) {band= 2;}                                                 //--A=0--B=1--C=0--D=0-------- 80m ---------
  if (bcdA&&bcdB&&!bcdC&&!bcdD)  {band= 3;}                                                 //--A=1--B=1--C=0--D=0-------- 40m ---------
  if (!bcdA&&!bcdB&&bcdC&&!bcdD) {band= 4;}                                                 //--A=0--B=0--C=1--D=0-------- 30m ---------
  if (bcdA&&!bcdB&&bcdC&&!bcdD)  {band= 5;}                                                 //--A=1--B=0--C=1--D=0-------- 20m ---------
  if (!bcdA&&bcdB&&bcdC&&!bcdD)  {band= 6;}                                                 //--A=0--B=1--C=1--D=0-------- 17m ---------
  if (bcdA&&bcdB&&bcdC&&!bcdD)   {band= 7;}                                                 //--A=1--B=1--C=1--D=0-------- 15m ---------
  if (!bcdA&&!bcdB&&!bcdC&&bcdD) {band= 8;}                                                 //--A=0--B=0--C=0--D=1-------- 12m ---------
  if (bcdA&&!bcdB&&!bcdC&&bcdD)  {band= 9;}                                                 //--A=1--B=0--C=0--D=1-------- 10m ---------
  if (!bcdA&&!bcdB&&!bcdC&&!bcdD){band=10;}}                                                //--A=0--B=0--C=0--D=0--------- 6m ---------

  if (mode_band==4){                                                                        //если выбран режим "ICOM"
  switch (analogRead(A2)){                                                                  //протокол icom с резистивным делителем 1/2
    case 0 ... 126:   band=4;  break;                                                       //-- 30m 0,1v...1,2v --- (0...0,6v) -------
    case 127 ... 212: band=10; break;                                                       //-- 6m 1,2v...2v ------ (0,6...1v) -------
    case 213 ... 265: band=9;  break;                                                       //-- 10m-12m 2v...2,5v - (1...1,25v) ------
    case 266 ... 365: band=7;  break;                                                       //-- 15v-17v 3v...3,5v - (1,5...1,75v) ----
    case 366 ... 485: band=5;  break;                                                       //-- 20m 4v...4,5v ----- (2...2,25v) ------
    case 486 ... 590: band=3;  break;                                                       //-- 40m 5v...5,5v ----- (2,5...2,75v) ----
    case 591 ... 700: band=2;  break;                                                       //-- 80m 6v...6,5v ----- (3...3,25v) ------
    case 701 ... 818: band=1;  break;                                                       //-- 160m 7v...8v ------ (3,5...4v) -------
    default: band=1; break;}}                                                               //в любых других случаях включаем band1 160m
  
  if ((mode_band==5)&&(band_get!=band)){band=band_get; flag_band_switch=1;                  //если новый диапазон не совпадает со старым -переключаем диапазон и подаём сигнал
    tft.setTextPadding(50); tft.setTextColor(TFT_GREEN,TFT_BLACK);                          //ширина подложки 50, цвет шрифта зеленый
    digitalWrite(TX,LOW); tft.drawCentreString("VOX",440,120,4);                            //откл. передачу, выводим "VOX"
    EEPROM.update(0,band);}                                                                 //обновляем в памяти новое значение диапазона

    tft.setTextPadding(94); tft.setTextColor(TFT_GREEN,TFT_BLACK);                          //включаем обновление подложки шрифта и выбираем цвет текста зеленый
  switch (band){                                                                            //переключаем диапазоны по кольцу
    case 1: tft.drawCentreString("160",56,262,7);                                           //----------------- 160m -------------------
      digitalWrite(D0,HIGH); digitalWrite(D1,LOW);                                          //вывод кода для дешифратора диапазонных ФНЧ
      digitalWrite(D2,LOW); digitalWrite(D3,LOW);  break;                                   //--------- D3=0--D2=0--D1=0--D0=1 ---------
    case 2: tft.drawCentreString("80",64,262,7);                                            //------------------ 80m -------------------
      digitalWrite(D0,LOW); digitalWrite(D1,HIGH);                                          //вывод кода для дешифратора диапазонных ФНЧ
      digitalWrite(D2,LOW); digitalWrite(D3,LOW);  break;                                   //--------- D3=0--D2=0--D1=1--D0=0 ---------
    case 3: tft.drawCentreString("40",64,262,7);                                            //------------------ 40m -------------------
      digitalWrite(D0,HIGH); digitalWrite(D1,HIGH);                                         //вывод кода для дешифратора диапазонных ФНЧ
      digitalWrite(D2,LOW); digitalWrite(D3,LOW);  break;                                   //--------- D3=0--D2=0--D1=1--D0=1 ---------
    case 4: tft.drawCentreString("30",64,262,7);                                            //------------------ 30m -------------------
      digitalWrite(D0,LOW); digitalWrite(D1,LOW);                                           //вывод кода для дешифратора диапазонных ФНЧ
      digitalWrite(D2,HIGH); digitalWrite(D3,LOW); break;                                   //--------- D3=0--D2=1--D1=0--D0=0 ---------
    case 5: tft.drawCentreString("20",64,262,7);                                            //------------------ 20m -------------------
      digitalWrite(D0,HIGH); digitalWrite(D1,LOW);                                          //вывод кода для дешифратора диапазонных ФНЧ
      digitalWrite(D2,HIGH); digitalWrite(D3,LOW); break;                                   //--------- D3=0--D2=1--D1=0--D0=1 ---------
    case 6: tft.drawCentreString("17",56,262,7);                                            //------------------ 17m -------------------
      digitalWrite(D0,LOW); digitalWrite(D1,HIGH);                                          //вывод кода для дешифратора диапазонных ФНЧ
      digitalWrite(D2,HIGH); digitalWrite(D3,LOW); break;                                   //--------- D3=0--D2=1--D1=1--D0=0 ---------
    case 7: tft.drawCentreString("15",56,262,7);                                            //------------------ 15m -------------------
      digitalWrite(D0,HIGH); digitalWrite(D1,HIGH);                                         //вывод кода для дешифратора диапазонных ФНЧ
      digitalWrite(D2,HIGH); digitalWrite(D3,LOW); break;                                   //--------- D3=0--D2=1--D1=1--D0=1 ---------
    case 8: tft.drawCentreString("12",56,262,7);                                            //------------------ 12m -------------------
      digitalWrite(D0,LOW); digitalWrite(D1,LOW);                                           //вывод кода для дешифратора диапазонных ФНЧ
      digitalWrite(D2,LOW); digitalWrite(D3,HIGH); break;                                   //--------- D3=1--D2=0--D1=0--D0=0 ---------
    case 9: tft.drawCentreString("10",56,262,7);                                            //------------------ 10m -------------------
      digitalWrite(D0,HIGH); digitalWrite(D1,LOW);                                          //вывод кода для дешифратора диапазонных ФНЧ
      digitalWrite(D2,LOW); digitalWrite(D3,HIGH); break;                                   //--------- D3=1--D2=0--D1=0--D0=1 ---------
    case 10: tft.drawCentreString("6",68,262,7);                                            //-------------------6m---------------------
      digitalWrite(D0,LOW); digitalWrite(D1,HIGH);                                          //вывод кода для дешифратора диапазонных ФНЧ
      digitalWrite(D2,LOW); digitalWrite(D3,HIGH); break;                                   //--------- D3=1--D2=0--D1=1--D0=0 ---------
    case 11: if (singleBE==1){singleBE=2; tft.fillRect(12,260,105,50,TFT_BLACK);            //флаг аварии в 2, стираем содержимое окна диапазонов
    tft.setFreeFont(FSSB9); tft.setTextColor(TFT_RED,TFT_BLACK);                            //и выводим шрифтом FSSB9
    tft.drawCentreString("BAND",64,270,1);                                                  //"BAND"
    tft.drawCentreString("ERROR",64,290,1);                                                 //"ERROR"
    tft.setTextPadding(50); tft.drawCentreString("",440,120,4);                             //стираем "VOX" или "TX"
    tft.setTextPadding(152); tft.drawString("",200,120,4);                                  //стираем надписи всех аттенюаторов
    flag_erroralarm=1; TONE=900; Time=150; N=3; break;}}                                    //флаг аварии в 1, тон 900Гц, задержка 150мс, число повторений 3
    
    tft.setTextColor(TFT_DARKGREY,TFT_BLACK);                                               //выбираем цвет текста
  if (flag_mode_band==1){tft.setTextPadding(110);tft.setFreeFont(FSSB9);                    //если "flag_mode_band==1"
  switch (mode_band){                                                                       //при длительном нажатии управляем режимами переключения диапазонов
  case 1:tft.drawCentreString("MANUAL",   64,245,1);  break;                                //выбор переключения диапазонов в режиме "MANUAL", "flag_mode=1"
  case 2:tft.drawCentreString("YAESU-817",63,245,1);  break;                                //выбор переключения диапазонов по протоколу "YAESU-817", "flag_mode=2"
  case 3:tft.drawCentreString("YAESU-BCD",63,245,1);  break;                                //выбор переключения диапазонов по протоколу "YAESU-BCD", "flag_mode=3"
  case 4:tft.drawCentreString("I C O M",  63,245,1);  break;                                //выбор переключения диапазонов по протоколу "BAND ICOM", "flag_mode=4"
  case 5:tft.drawCentreString("A U T O",  63,245,1);  break;}                               //выбор переключения диапазонов в режиме "BAND AUTO", "flag_mode=5"
    flag_mode_band=0;}                                                                      //сбрасываем "flag_mode_band=0"
    
    tft.setTextPadding(152); tft.setTextColor(TFT_GREEN,TFT_BLACK);//************************ Аттенюаторы
  if (pwr_on){                                                                              //если включен режим "ON"
  switch (button3.Loop()){                                                                  //описываем работу кнопки "АТТ/VOX"
    case SB_CLICK: beeper(); if (++att>4) att=1; break;                                     //определяем алгоритм работы кнопки ATT по короткому нажатию с бипером
    case SB_LONG_CLICK: if (++vox>1) vox=0; beeper(); VOXcount=VOXDelay; break;}            //определяем алгоритм работы кнопки VOX по длинному нажатию с бипером
  switch (att) {                                                                            //короткими нажатиями переключаем режимы аттенюаторов
    case 1:if (flag_auto3dB==0){flag_autoATT=1;                                             //устанавливаем "flag_autoATT" в 1
    tft.drawString("ATT AUTO",200,120,4);                                                   //выводим надпись "ATT AUTO",  
    digitalWrite(att3dB,LOW); digitalWrite(att6dB,LOW);} break;                             //на выходах ATT-3dB и ATT-6dB низкие уровени
    case 2:flag_autoATT=0; tft.drawString("ATT    OFF",200,120,4);break;                    //сбрасываем "flag_autoATT" в 0, выводим надпись "ATT  OFF"
    case 3:tft.drawString("ATT   -3dB",200,120,4);                                          //выводим надпись "ATT:  -3dB"
    digitalWrite(att3dB,HIGH); digitalWrite(att6dB,LOW);  break;                            //на выходе ATT-3dB высокий уровень, на выходе ATT-6dB низкий
    case 4:tft.drawString("ATT   -6dB",200,120,4);                                          //выводим надпись "ATT:  -6dB"
    digitalWrite(att3dB,HIGH); digitalWrite(att6dB,HIGH) ;break;}                           //на выходе ATT-6dB высокий уровень, на выходе ATT-3dB низкий
    
  if ((flag_PTT==1)&&((att==2 && PWRi>=ATToff) || (att==3 && PWRi>=ATT3dB) ||               //в режиме передачи, при вкл. аттенюаторах и превышении
    (att==4 && PWRi>=ATT6dB))){                                                             //входной мощности
    flag_inputalarm=1; TONE=2500; Time=50; N=10;                                            //устанавливаем флаг в 1 и включаем прерывистый звуковой сигнал
    PTT=0; flag_PTT=0; pwr_on=0; tft.setTextColor(TFT_RED,TFT_BLACK);                       //режим приема, откл. питания, шрифт красный
    tft.setTextPadding(50); tft.drawCentreString("",440,120,4);                             //стираем "VOX" или "TX"
    tft.drawString("INP PWR Hi!",200,120,4);}                                               //выводим надпись "INP PWR Hi!" красным цветом
  
  if ((flag_autoATT==1)&&(flag_PTT==1)){                                                    //при совпадении флагов ************************************ ATT AUTO
  if (PWRi>=ATTauto){ valAutoATT=0; flag_auto3dB=1;                                         //если сигнал на входе выше ATTauto, запускаем счётчик времени задержки отключения АТТ
    tft.setTextColor(TFT_GREEN,TFT_BLACK);                                                  //выбираем зелёный цвет текста
    tft.drawString("ATT   -3dB",200,120,4);                                                 //выводим надпись "ATT   -3dB" зелёным цветом
    digitalWrite(att3dB,HIGH); digitalWrite(att6dB,LOW);}                                   //на выходе ATT-3dB высокий уровень, на выходе ATT-6dB низкий
  else if (millis()-AutoATTMillis>=1){                                                      //формируем задержку выключения аттенюатора
    AutoATTMillis=millis(); valAutoATT++;}                                                  //с каждой миллисекундой увеличиваем значение valAutoATT
  else valAutoATT=0;                                                                        //иначе обнуляем счётчик
  if (valAutoATT>=ATTDelay*10){valAutoATT=0; flag_auto3dB=0;}                               //как только значение valAutoATT становится равным TimeAutoATT*10
  if (PWRi>=ATTalarm){flag_inputalarm=1; TONE=2500; Time=50; N=10;                          //если сигнал на входе выше ATTalarm, включаем прерывистый звуковой сигнал
    PTT=0; flag_PTT=0; pwr_on=0;                                                            //режим приема, откл. питания
    tft.setTextColor(TFT_RED,TFT_BLACK);                                                    //выбираем красный цвет текста
    tft.drawString("INP PWR Hi!",200,120,4);                                                //выводим надпись "INP PWR Hi!" красным цветом
    tft.setTextPadding(50); tft.drawCentreString("",440,120,4);}}}                          //стираем "VOX" или "TX"
//******************************************************************************************* Режим VOX
    tft.setTextPadding(50);                                                                 //включаем обновление подложки шрифта
  if ((pwr_on)&&(!flag_band_switch)&&(num18b20)){bool pedal=digitalRead(pttIN);             //если питание вкл., флаг переключения в 0, кол-во DS18B20 1 или 2, проверяем педаль
  if (vox){                                                                                 //если VOX включен
  if (frq_vox){VOXcount=0; digitalWrite(TX,HIGH); PTT=1; flag_PTT=1;                        //если есть частота, обнуляем счетчик, передача
    tft.setTextColor(TFT_RED,TFT_BLACK); tft.drawCentreString("TX",440,120,4);}             //выводим красным цветом "TX"
  if (++VOXcount>=VOXDelay){VOXcount=0; digitalWrite(TX,LOW); PTT=0; flag_PTT=0;            //если счетчик досчитал, обнуляем его, на выходе PTT низкий уровень
    tft.setTextColor(TFT_GREEN,TFT_BLACK); tft.drawCentreString("VOX",440,120,4);}}         //выводим "VOX" зеленым цветом
  if (!vox){                                                                                //если VOX отключен
  if (!pedal){tft.setTextColor(TFT_RED,TFT_BLACK);                                          //если педаль нажата
    digitalWrite(TX,HIGH); tft.drawCentreString("TX",440,120,4); PTT=0; flag_PTT=1;}        //выводим красным цветом "TX"
  else {tft.setTextColor(TFT_RED,TFT_BLACK);                                                //если не нажата
  if (!PTT){digitalWrite(TX,LOW);   flag_PTT=0;   tft.drawCentreString("",440,120,4);}      //в режиме приема, на выходе PTT 0, флаг передачи 0, стираем надпись
  if (PTT) {digitalWrite(TX,HIGH);  flag_PTT=1;   tft.drawCentreString("TX",440,120,4);}}}} //в режиме передачи, на выходе PTT 1, флаг передачи 1, выводим надпись "TX"

  switch(button4.Loop()){//****************************************************************** Кнопка PTT
    case SB_CLICK: if ((pwr_on)&&(!vox)){if (++PTT>1) PTT=0; beeper();} break;              //определяем алгоритм работы кнопки "PTT" по короткому нажатию с бипером
    case SB_LONG_CLICK: if (++pwr_view>1) pwr_view=0; beeper();                             //определяем алгоритм работы кнопки "PWR_VIEW" по длинному нажатию
    tft.fillRect(20,11,420,24,TFT_BLACK); break;}                                           //затираем строку
}//================================================================================================================================

void PWRSwitch(){// ************************************************************************* Кнопка питания
    tft.setTextPadding(0); tft.setFreeFont(FSSB18);                                         //шрифт FSSB18
  if (!pwr_on){tft.fillRoundRect(8,108,170,56,6,TFT_BLACK);                                 //если питание отключено, стираем содержимое кнопки черным цветов
    tft.fillCircle(138,138,16,TFT_GREY50);                                                  //выводим тень кнопки серым цветом
    tft.fillCircle(136,136,16,TFT_RED); tft.fillCircle(136,136,10,TFT_WHITE);               //выводим кнопку красным цветом и
    tft.fillCircle(136,136,8,TFT_RED);                                                      //рисунок внутри кнопки
    tft.drawLine(133,130,133,123,TFT_RED); tft.drawLine(134,130,134,123,TFT_RED);           //
    tft.drawLine(138,130,138,123,TFT_RED); tft.drawLine(139,130,139,123,TFT_RED);           //
    tft.setTextColor(TFT_RED,TFT_BLACK); tft.drawCentreString("OFF",65,125,1);}             //выводим красным цветом "OFF"
  if (pwr_on){tft.fillRoundRect(8,108,170,56,6,TFT_BLUE);                                   //если питание включено, стираем содержимое кнопки синим цветом
    tft.fillRoundRect(11,111,164,50,4,TFT_CYAN);                                            //выводим фон кнопки светло-голубым цветом, оставляем окантовку синим цветом
    tft.fillCircle(138,138,16,TFT_GREY50);                                                  //выводим тень кнопки серым цветом
    tft.fillCircle(136,136,16,TFT_BLUE); tft.fillCircle(136,136,10,TFT_WHITE);              //выводим кнопку синим цветом и
    tft.fillCircle(136,136,8,TFT_BLUE);                                                     //рисунок внутри кнопки
    tft.drawLine(133,130,133,123,TFT_BLUE); tft.drawLine(134,130,134,123,TFT_BLUE);         //
    tft.drawLine(138,130,138,123,TFT_BLUE); tft.drawLine(139,130,139,123,TFT_BLUE);         //
    tft.setTextColor(TFT_BLUE); tft.drawCentreString("ON",65,125,1);}                       //выводим синим цветом "ON"
    tft.drawLine(135,130,135,123,TFT_WHITE); tft.drawLine(136,130,136,123,TFT_WHITE);       //
    tft.drawLine(137,130,137,123,TFT_WHITE);                                                //
}
void animation(){//************************************************************************** Анимация
  if (++rnd>13) rnd=1;                                                                      //выбор спецэффекта по порядку
  switch (rnd){                                                                             //
    case 1: for(0,240){delay(3);                                                            //прямоугольник из центра
      tft.drawRect(237-i,157-(int)i/1.5,(i+2)*2,(int)((i+2)/1.5)*2,TFT_WHITE);              //
      tft.drawRect(238-i,158-(int)i/1.5,(i+1)*2,(int)((i+1)/1.5)*2,TFT_WHITE);              //
      tft.drawRect(239-i,159-(int)i/1.5,i*2,(int)(i/1.5)*2,TFT_BLACK);} break;              //
    case 2: for(0,240){delay(3);                                                            //прямоугольник в центр
    if (i<238) tft.drawRect(i+2, (int)((i+3)/1.5), 476-i*2, 316-(int)(i/1.5*2), TFT_WHITE); //
      tft.drawRect(i+1, (int)((i+1)/1.5), 478-i*2, 318-(int)(i/1.5*2), TFT_WHITE);          //
      tft.drawRect(i,   (int)i/1.5,       480-i*2, 320-(int)(i/1.5*2), TFT_BLACK);} break;  //
    case 3: tft.drawFastHLine(0,160,480,TFT_BLACK);                                         //две горизонтальные линии из центра
      for(0,160){delay(3);                                                                  //
        tft.drawFastHLine(0,157-i,480,TFT_WHITE); tft.drawFastHLine(0,158-i,480,TFT_WHITE); //
        tft.drawFastHLine(0,162+i,480,TFT_WHITE); tft.drawFastHLine(0,163+i,480,TFT_WHITE); //
        tft.drawFastHLine(0,159-i,480,TFT_BLACK);                                           //
        tft.drawFastHLine(0,161+i,480,TFT_BLACK);}  break;                                  //
    case 4: for(0,160){delay(3);                                                            //две горизонтальные линии в центр
        tft.drawFastHLine(0,1+i,479,TFT_WHITE);                                             //
        tft.drawFastHLine(0,2+i,479,TFT_WHITE);                                             //
        tft.drawFastHLine(0,317-i,479,TFT_WHITE);                                           //
        tft.drawFastHLine(0,318-i,479,TFT_WHITE);                                           //
        tft.drawFastHLine(0,0+i,479,TFT_BLACK);                                             //
        tft.drawFastHLine(0,319-i,479,TFT_BLACK);}  break;                                  //
    case 5: tft.drawFastVLine(239,0,320,TFT_BLACK);                                         //две вертикальные линии из центра
       for(0,240){delay(3);                                                                 //
        tft.drawFastVLine(236-i,0,320,TFT_WHITE); tft.drawFastVLine(237-i,0,320,TFT_WHITE); //
        tft.drawFastVLine(241+i,0,320,TFT_WHITE); tft.drawFastVLine(242+i,0,320,TFT_WHITE); //
        tft.drawFastVLine(238-i,0,320,TFT_BLACK);                                           //
        tft.drawFastVLine(240+i,0,320,TFT_BLACK);}  break;                                  //
    case 6: for(0,240){delay(3);                                                            //две вертикальные линии в центр
        tft.drawFastVLine(1+i,0,319,TFT_WHITE);                                             //
        tft.drawFastVLine(2+i,0,319,TFT_WHITE);                                             //
        tft.drawFastVLine(478-i,0,319,TFT_WHITE);                                           //
        tft.drawFastVLine(477-i,0,319,TFT_WHITE);                                           //
        tft.drawFastVLine(0+i,0,319,TFT_BLACK);                                             //
        tft.drawFastVLine(479-i,0,319,TFT_BLACK);}  break;                                  //
    case 7: for(0,320){delay(3);                                                            //
        tft.drawFastHLine(0,1+i,239,TFT_WHITE);                                             //
        tft.drawFastHLine(0,2+i,239,TFT_WHITE);                                             //
        tft.drawFastHLine(240,317-i,479,TFT_WHITE);                                         //
        tft.drawFastHLine(240,318-i,479,TFT_WHITE);                                         //
        tft.drawFastHLine(0,0+i,239,TFT_BLACK);                                             //
        tft.drawFastHLine(239,319-i,479,TFT_BLACK);} break;                                 //
    case 8: for(0,480){delay(3);                                                            //движущиеся половинные вертикальные линии от левого бока до правого и наоборот
        tft.drawFastVLine(1+i,0,159,TFT_WHITE);                                             //
        tft.drawFastVLine(2+i,0,159,TFT_WHITE);                                             //
        tft.drawFastVLine(478-i,159,160,TFT_WHITE);                                         //
        tft.drawFastVLine(477-i,159,160,TFT_WHITE);                                         //
        tft.drawFastVLine(0+i,0,159,TFT_BLACK);                                             //
        tft.drawFastVLine(479-i,159,160,TFT_BLACK);} break;                                 //
    case 9: for(0,480){                                                                     //движущиеся 
        tft.drawLine(1,318-(int)i/1.5,1+i,318,TFT_WHITE);                                   //
        tft.drawLine(0,319-(int)i/1.5,0+i,319,TFT_BLACK);                                   //
        tft.drawLine(478-i,1,478,1+(int)i/1.5,TFT_WHITE);                                   //
        tft.drawLine(479-i,0,479,0+(int)i/1.5,TFT_BLACK);} break;                           //
    case 10: for(0,480){                                                                    //движущиеся 
        tft.drawLine(1+i,1,1,1+(int)i/1.5,TFT_WHITE);                                       //
        tft.drawLine(0+i,0,0,0+(int)i/1.5,TFT_BLACK);                                       //
        tft.drawLine(478-i,318,478,318-(int)i/1.5,TFT_WHITE);                               //
        tft.drawLine(479-i,319,479,319-(int)i/1.5,TFT_BLACK);} break;                       //
    case 11: for(0,480){                                                                    //движущиеся
        tft.drawLine(1+i,0,479,318-(int)i/1.5,TFT_WHITE);                                   //
        tft.drawLine(0+i,0,479,319-(int)i/1.5,TFT_BLACK);                                   //
        tft.drawLine(0,1+(int)i/1.5,478-i,319,TFT_BLACK);                                   //
        tft.drawLine(0,2+(int)i/1.5,477-i,319,TFT_WHITE);} break;                           //
    case 12: for(0,480){                                                                    //движущиеся
        tft.drawLine(478-i,0,0,318-(int)i/1.5,TFT_WHITE);                                   //
        tft.drawLine(479-i,0,0,319-(int)i/1.5,TFT_BLACK);                                   //
        tft.drawLine(479,0+(int)i/1.5,0+i,319,TFT_BLACK);                                   //
        tft.drawLine(479,1+(int)i/1.5,1+i,319,TFT_WHITE);} break;                           //
    case 13: for(0,240){tft.drawLine(240+i,0,240-i,319,TFT_WHITE);                          //поворачивающийся на 90 градусов крест
        tft.drawLine(239+i,0,241-i,319,TFT_BLACK);                                          //
        tft.drawLine(0,160-i/1.5,479,160+i/1.5,TFT_WHITE);                                  //
        tft.drawLine(0,161-i/1.5,479,159+i/1.5,TFT_BLACK);}                                 //
      for(0,240){tft.drawLine(479,1+i/1.5,0,319-i/1.5,TFT_WHITE);                           //
        tft.drawLine(479,0+i/1.5,0,320-i/1.5,TFT_BLACK);                                    //
        tft.drawLine(478-i,319,1+i,0,TFT_WHITE);                                            //
        tft.drawLine(479-i,319,0+i,0,TFT_BLACK);} break;}                                   //
}                                                                                           //
void beeper(){//***************************************************************************** Управление бипером
  if ((Tonbeep)&&(beep)){tone4.tone(Tonbeep*100);                                           //если "Tonbeep!=0" и "beep==1", устанавливаем тональность бипера Tonbeep
    delay(50); tone4.noTone();}}                                                            //формируем длительность бипера 50мс, отключаем бипер

void symbol_speaker(){//********************************************************************* Символ динамика
    uint16_t ColorSpeaker;                                                                  //переменная цвета
  if (beep) ColorSpeaker=TFT_GREEN;                                                         //если бипер включен, цвет зеленый
  if (!beep)ColorSpeaker=TFT_DARKGREY;                                                      //если бипер отключен, цвет темно-серый

    tft.fillRect(444,20,3,10,ColorSpeaker);                                                 //рисуем "магнит" динамика
    tft.fillRect(448,19,6,12,ColorSpeaker);                                                 //Рисуем "диффузор"
    tft.fillTriangle(448,19,454,19,454,13,ColorSpeaker);                                    //---------------
    tft.fillTriangle(448,30,454,30,454,36,ColorSpeaker);                                    //---------------
    tft.drawPixel(455,24,ColorSpeaker); tft.drawPixel(455,26,ColorSpeaker);                 //рисуем "звуковые волны"
    tft.drawPixel(456,22,ColorSpeaker); tft.drawPixel(456,28,ColorSpeaker);                 //---------------------
    tft.drawPixel(457,23,ColorSpeaker); tft.drawPixel(457,27,ColorSpeaker);                 //---------------------
    tft.drawLine(458,24,458,26,ColorSpeaker);                                               //---------------------
    tft.drawPixel(458,20,ColorSpeaker); tft.drawPixel(458,30,ColorSpeaker);                 //---------------------
    tft.drawPixel(459,21,ColorSpeaker); tft.drawPixel(459,29,ColorSpeaker);                 //---------------------
    tft.drawPixel(460,22,ColorSpeaker); tft.drawPixel(460,28,ColorSpeaker);                 //---------------------
    tft.drawLine(461,23,461,27,ColorSpeaker);}                                              //---------------------

void energy(){//******************************************************************************************************************** Амперметр
    tft.setFreeFont(FSSB12); tft.setTextPadding(75);                                        //включаем обновление подложки шрифта
  if (I4<0){I4=0;}                                                                          //исключаем измерение отрицательных значений
  if (I4<Imax){tft.setTextColor(TFT_GREEN,TFT_BLACK);}                                      //если "I4<Imax" выбираем зелёный цвет текста
  if (I4>Imax){tft.setTextColor(TFT_RED,TFT_BLACK);}                                        //если "I4>Imax" выбираем красный цвет текста

  if (I4>=I4pk) {I4pk=I4; I4count=0;}                                                       //фиксируем пиковое значение I4pk, обнуляем счетчик
  if (++I4count<21){                                                                        //если счетчик меньше 21
    tft.setTextPadding(68);                                                                 //подложка шрифта 68 пикселей
    char bufA[5]; byte lenA=4; dtostrf(I4pk,lenA,1,bufA);                                   //конвертируем символьный массив потребляемого тока усилителя мощности
    bufA[lenA]='A'; bufA[lenA+1]=0;                                                         //
    tft.drawCentreString(bufA,185,286,4);                                                   //выводим значение тока зелёного цвета с добавлением "A"
    tft.setTextPadding(0);                                                                  //отключаем подложку шрифта
    tft.drawString("I: ",135,288,1);}                                                       //выводим символ "I: "
  else I4pk=I4;                                                                             //если счетчик больше 21, сбрасываем I4pk до текущего значения тока

  if ((I4>=Imax)&&(!statealarm)){flag_curalarm=1;                                           //при превышении потребляемого тока устанавливаем флаг в 1
    tft.setTextPadding(152); TONE=1000; Time=120; N=4;                                      //включаем обновление подложки шрифта, выбираем тон сигнала, паузу и кол-во повторений
    tft.drawString("HIGH Current!",200,120,4);                                              //выводим надпись "HIGH Current!" красным цветом
    tft.setTextPadding(50); tft.drawCentreString("",440,120,4);}                            //стираем "VOX" или "TX"
    tft.setTextPadding(75);//****************************************************************************************************** Вольтметр
    float vout=(U4*5)/1024;                                                                 //привязываем U4 к пяти вольтам
    vin=vout/(divider/(R1+divider));                                                        //привязываем к делителю
  if (vin<0.09) vin=0.0;                                                                    //обнуляем нежелательные значения
  if ((vin>=Vmin)&&(vin<=Vmax)) tft.setTextColor(TFT_GREEN,TFT_BLACK);                      //если напряжение находится вне аварийной зоны выбираем зелёный цвет текста
  else tft.setTextColor(TFT_RED,TFT_BLACK);                                                 //иначе выбираем красный цвет текста
    char bufV[5]; byte lenV=4; dtostrf(vin,lenV,1,bufV);                                    //конвертируем символьный массив вывода данных
    bufV[lenV]='V'; bufV[lenV+1]=0;                                                         //напряжения питания усилителя мощности
    tft.drawCentreString(bufV,315,286,4);                                                   //выводим значение напряжения с добавлением "V"
    tft.setTextPadding(0); tft.drawString("U: ",250,288,1);                                 //выводим  "U :"

    tft.setTextPadding(152); tft.setTextColor(TFT_RED,TFT_BLACK);                           //выбираем красный цвет текста, включаем обновление подложки шрифта
  if ((vin>Vmax)&&(!statealarm)){flag_voltagealarm=1;                                       //при превышении напряжения устанавливаем флаг в 1
    TONE=1500; Time=100; N=5; tft.drawString("HIGH Voltage!",200,120,4);                    //выбираем тон сигнала, выводим надпись "HIGH Voltage!" красным цветом
    tft.setTextPadding(50); tft.drawCentreString("",440,120,4);}                            //стираем "VOX" или "TX"

  if ((vin<Vmin)&&(!statealarm)){flag_voltagealarm=1;                                       //при снижении напряжения ниже минимального устанавливаем флаг в 1
    TONE=1500; Time=100; N=5; tft.drawString("LOW Voltage!",200,120,4);                     //выбираем тон сигнала, выводим надпись "LOW Voltage!!" красным цветом
    tft.setTextPadding(50); tft.drawCentreString("",440,120,4);}                            //стираем "VOX" или "TX"

    tft.setFreeFont(FSSB9); tft.setTextColor(TFT_DARKGREY);                                 //выбираем шрифт и цвет текста
    tft.drawNumber(Vmin,250,265,1);                                                         //выводим значение минимального напряжения
    tft.drawNumber(Vmax,315,265,1);                                                         //выводим значение максимального напряжения
    tft.drawCentreString("---",297,265,1);                                                  //выводим тире
    tft.drawString("V",270,265,1);                                                          //выводим "V"
    tft.drawString("V",335,265,1);                                                          //выводим "V"
//***************************************************************************************************************************** Выходная мощность 250_500_1000_2000Вт
    float Vf=(((Upk1+STEP1)*5)/1023)*A;                                                     //приводим напряжение к мощности
    int PWR=(Vf*Vf)/B;                                                                      //вычисляем мощность
    PWRf=PWR*C;                                                                             //округляем значение мощности кратно C
    int a=PWRf/D;                                                                           //определяем число кубиков в градуснике (PWRf/D=50)
  if (aOld!=a){aOld=a;                                                                      //отрисовываем градусник, если изменились показания
  for(0,a){                                                                                 //включаем цикл рисования кубиков
  if (i<22) Red=0;                                                                          //определение красного цвета в градуснике
  if ((i>=22)&&(i<=34)) Red=map(i,22,34,0,255);                                             //---------------------------------------
  if (i>34) Red=255;                                                                        //---------------------------------------
  if (i<=9) Green=map(i,0,9,0,255);                                                         //определение зеленого цвета в градуснике
  if ((i>9)&&(i<=34)) Green=255;                                                            //---------------------------------------
  if (i>34) Green=map(i,34,49,255,0);                                                       //---------------------------------------
  if (i<=9) Blue=255;                                                                       //определение синего цвета в градуснике
  if (i>22) Blue=0;                                                                         //-------------------------------------
  if ((i>9)&&(i<=22)) Blue=map(i,22,10,0,255);                                              //-------------------------------------
    tft.fillRect(17+i*9,65,5,25,tft.color565(Red,Green,Blue));}                             //рисуем градиентный градусник пропорционально мощности
  for(a,50){                                                                                //включаем цикл рисования кубиков подложки и стирания
    tft.fillRect(17+i*9,65,5,25,TFT_GREY40);}}                                              //дорисовываем подложку до конца, цвет темно-серый
  if (!pwr_on){//**************************************************************************** Входная мощность 30_120Вт
    float Vi=(((Upk2+STEP2)*5)/1023)*h;                                                     //приводим напряжение к мощности 120Вт
    PWRi=(Vi*Vi)/50;                                                                        //вычисляем мощность
    int b=PWRi/4;                                                                           //назначаем переменную "b" градусника input_pwr 120Вт
  if (bOld!=b){bOld=b;                                                                      //отрисовываем градусник, если изменились показания
  for(0,b){                                                                                 //включаем цикл рисования кубиков
    tft.fillRect(197+i*9,182,5,23,TFT_SILVER);}                                             //рисуем градусник серебряного цвета пропорционально мощности
  for(b,30){                                                                                //включаем цикл рисования кубиков подложки и стирания
    tft.fillRect(197+i*9,182,5,23,TFT_GREY40);}}                                            //дорисовываем подложку до конца
    digitalWrite(att3dB,LOW); digitalWrite(att6dB,LOW);}                                    //на выходах ATT-3dB и ATT-6dB низкие уровени
  
  if (pwr_on){                                                                              //если включен рабочий режим
  if (!powerin) {float Vi=(((Upk2+STEP2)*5)/1023)*l1;                                       //если включен POWER ON1
    PWRi3=(Vi*Vi)/50;                                                                       //вычисляем мощность до 3Вт 
    int b=PWRi3*10;   PWRi3=b/10.0;                                                         //назначаем переменную "b" градусника input_pwr 3Вт
  if (bOld!=b){bOld=b;                                                                      //отрисовываем градусник, если изменились показания
  for(0,b){                                                                                 //включаем цикл рисования кубиков
    tft.fillRect(197+i*9,182,5,23,TFT_YELLOW);}                                             //рисуем градусник желтого цвета пропорционально мощности
  for(b,30){                                                                                //включаем цикл рисования кубиков подложки и стирания
    tft.fillRect(197+i*9,182,5,23,TFT_GREY40);}}}                                           //дорисовываем подложку до конца  
  if (powerin) {float Vi=(((Upk2+STEP2)*5)/1023)*l2;                                        //если включен POWER ON2
    PWRi=(Vi*Vi)/50;                                                                        //вычисляем мощность до 30Вт 
    int b=PWRi;                                                                             //назначаем переменную "b" градусника input_pwr 30Вт
  if (bOld!=b){bOld=b;                                                                      //отрисовываем градусник, если изменились показания
  for(0,b){                                                                                 //включаем цикл рисования кубиков
    tft.fillRect(197+i*9,182,5,23,TFT_YELLOW);}                                             //рисуем градусник желтого цвета пропорционально мощности
  for(b,30){                                                                                //включаем цикл рисования кубиков подложки и стирания
    tft.fillRect(197+i*9,182,5,23,TFT_GREY40);}}}}                                          //дорисовываем подложку до конца
    Psupply=vin*I4pk;//********************************************************************** Подводимая мощность, КПД и коэффициент усиления УМ
  if (Psupply) u=((int)PWRf/(float)Psupply)*100;                                            //высчитываем КПД, если есть подводимая мощность
  else u=0;                                                                                 //если отсутствует, КПД=0
  if (u>=100) u=100;                                                                        //ограничиваем показания КПД сверху
    uint16_t Kp;                                                                            //переменная коэффициента усиления по мощности
  if (!powerin) {if (!PWRi3)Kp=0; else Kp=PWRf/PWRi3;}                                      //вычисляем коэффициент усиления для 3Вт
  if (powerin)  {if (!PWRi) Kp=0; else Kp=PWRf/PWRi;}                                       //вычисляем коэффициент усиления для 30Вт
  if (pwr_view) {                                                                           //если выбрана информационная строка
    tft.setTextColor(TFT_SILVER,TFT_BLACK);                                                 //выбираем цвет текста с цветом подложки
    char cstr[6]; uint16_t xproc=332;                                                       //символьная переменная, координаты X процентов
    tft.setTextPadding(120); sprintf(cstr,"Kp = %d",Kp); tft.drawString(cstr,40,10,4);      //выводим коэф. передачи по мощности
    tft.setTextPadding(140); sprintf(cstr,"Psup = %d",Psupply);                             //выводим подводимую мощность
    tft.drawString(cstr,175,10,4);                                                          //
    tft.setTextPadding(35);  sprintf(cstr,"u = %d",u);                                      //выводим значение КПД
    xproc+=tft.drawString(cstr,xproc,10,4);                                                 //
    tft.drawString("%",xproc,10,4);}                                                        //добавляем в конце проценты

  if (ALC){                                                                                 //если режим ALC включен
    tft.setFreeFont(FSSB9); tft.setTextColor(TFT_DARKGREY);                                 //выбираем шрифт и цвет текста
    tft.drawCentreString("ALC",215,210,1);                                                  //выводим надпись "ALC"
    float vout_alc=(U6*5.0)/1024.0;                                                         //привязываем U4 к пяти вольтам
    int a=vout_alc*4.9;                                                                     //назначаем переменную "a" градусника ALC
  for(0,a){                                                                                 //включаем цикл рисования кубиков
  if (i>17){tft.fillRect(242+i*9,210,5,14,TFT_RED);}                                        //рисуем градусник красного цвета пропорционально ALC
  else { tft.fillRect(242+i*9,210,5,14,TFT_GREEN);}}                                        //рисуем градусник зелёного цвета пропорционально ALC
  for(a,25){                                                                                //включаем цикл рисования кубиков подложки и стирания
    tft.fillRect(242+i*9,210,5,14,TFT_GREY40);}}                                            //дорисовываем подложку до конца
  
  if (!ALC){                                                                                //если режим ALC выключен выводим входную и выходную мощность
    tft.setFreeFont(FSSB9); tft.setTextColor(TFT_DARKGREY);                                 //выбираем шрифт и цвет текста
    tft.drawString("-Power-",285,210,1);                                                    //выводим надпись "-Power-"
    char cstr[6];                                                                           //символьная переменная
    tft.setFreeFont(FSSB9); tft.setTextPadding(0); tft.setTextColor(TFT_GREEN);             //шрифт FSSB9, зеленый цвет
  if (pwr_on){                                                                              //если включен рабочий режим
  if (!powerin){                                                                            //3Вт
  if (!singleIN3){singleIN3=1; tft.fillRect(235,210,50,13,TFT_BLACK);}                      //
  if (PWRi3old!=PWRi3){PWRi3old=PWRi3; tft.fillRect(235,210,24,13,TFT_BLACK);               //
    tft.drawFloat(PWRi3,1,235,210,1); tft.drawString("W",260,210,1);}}                      //
  if (powerin){singleIN3=0;                                                                 //30Вт
  if (PWRiold!=PWRi){PWRiold=PWRi; tft.fillRect(235,210,48,13,TFT_BLACK);                   //
    sprintf(cstr,"Pin= %dW  ",PWRi); tft.drawString(cstr,194,210,1);}}}                     //
  if (!pwr_on){                                                                             //120Вт
  if (PWRiold!=PWRi){PWRiold=PWRi; tft.fillRect(235,210,50,13,TFT_BLACK);                   //
    sprintf(cstr,"Pin= %dW  ",PWRi); tft.drawString(cstr,194,210,1);}}                      //
  
  if (PWRfold!=PWRf){PWRfold=PWRf; tft.fillRect(407,210,62,13,TFT_BLACK);                   //выходная мощность усилителя
    sprintf(cstr,"Pout= %dW",PWRf); tft.drawString(cstr,355,210,1);}}}                      //

void set_temp(){//*************************************************************************** датчик DS18B20 температура радиатора
    uint16_t drawcolor;                                                                     //переменная цвета
    uint16_t xpos=367;                                                                      //координаты X
    ds1.reset(); ds1.write(0xCC); ds1.write(0x44);                                          //сброс датчика 1
    ds1.reset(); ds1.write(0xCC); ds1.write(0xBE);                                          //запрос данных от датчика 1
    float temp1=((ds1.read()|(ds1.read()<<8)))/16.0;                                        //получаем температуру датчика 1
    
    ds2.reset(); ds2.write(0xCC); ds2.write(0x44);                                          //сброс датчика 2
    ds2.reset(); ds2.write(0xCC); ds2.write(0xBE);                                          //запрос данных от датчика 2
    float temp2=((ds2.read()|(ds2.read()<<8)))/16.0;                                        //получаем температуру датчика 2
    
  if (temp1>=temp2) temp=temp1;                                                             //определяем наивысшую температуру
  else              temp=temp2;                                                             //на датчиках DS18B20
  
  if (!num18b20){                                                                           //не подключены DS18B20
  if (!module){tft.setFreeFont(FSSB9); tft.setTextColor(TFT_DARKGREY);                      //если модуль DS3231 не подключен
    tft.drawCentreString("DS18B20",416,265,1);                                              //выводим надпись "DS18B20"
    tft.setTextColor(TFT_RED); tft.drawCentreString("ERROR",416,288,1);}                    //выводим надпись "ERROR" красным цветом
  if (module){tft.setFreeFont(FSSB12); tft.setTextColor(TFT_RED);                           //если модуль DS18B20 подключен
    tft.drawCentreString("ERROR",416,288,1);}}                                              //выводим надпись "ERROR" красным цветом
  
  if (num18b20==1){                                                                         //если подключен один датчик DS18B20
  if (!module){tft.setTextColor(TFT_DARKGREY); tft.setFreeFont(FSSB9);                      //если модуль DS3231 не подключен
    tft.drawCentreString("DS18B20",416,265,1);}                                             //выводим надпись "DS18B20"
    tft.setTextPadding(0); tft.setFreeFont(FSSB12);                                         //выбираем шрифт FSSB12
  if (temp<TFanMax) {tft.setTextColor(TFT_GREEN,TFT_BLACK); drawcolor=TFT_GREEN;}           //если температура ниже аварийной, цвет зеленый
  if (temp>=TFanMax){tft.setTextColor(TFT_RED,TFT_BLACK);   drawcolor=TFT_RED;}             //если температура равна или выше аварийной, цвет красный
    xpos+=tft.drawString("T: ",xpos,288,1); xpos+=tft.drawFloat(temp,1,xpos,286,4);         //выводим "T: " и температуру DS18B20
    xpos+=tft.drawString("C",xpos+7,286,4); tft.drawCircle(xpos-15,289,2,drawcolor);        //дописываем "C" и знак градуса Цельсия
  if ((temp>=TFanMax)&&(!statealarm)){pwr_on=0;                                             //при превышении температуры отключаем питание
    flag_tempalarm=1; TONE=2200; Time=70; N=6;                                              //устанавливаем "flag_tempalarm" в 1, выбираем тон сигнала 2200Гц, пауза 70мс,
    tft.fillRect(190,119,165,23,TFT_BLACK);                                                 //число повторений 6, затираем предыдущую надпись
    tft.setTextColor(TFT_RED); tft.drawString("OVERHEAT!!!",200,120,4);}}                   //выводим надпись "OVERHEAT!!!" красным цветом
  
  if (num18b20==2){                                                                         //если подключены оба датчика DS18B20
  if (temp1<TFanMax) {tft.setTextColor(TFT_GREEN,TFT_BLACK); drawcolor=TFT_GREEN;}          //если температура ниже аварийной, цвет зеленый
  if (temp1>=TFanMax){tft.setTextColor(TFT_RED,TFT_BLACK);   drawcolor=TFT_RED;}            //если температура равна или выше аварийной, цвет красный
    tft.setTextPadding(0); tft.setFreeFont(FSSB12);                                         //выбираем шрифт FSSB12
    xpos+=tft.drawString("1: ",xpos,263,1);                                                 //выводим надпись "1: "
    xpos+=tft.drawFloat(temp1,1,xpos,261,4);                                                //и значение датчика 1
    xpos+=tft.drawString("C",xpos+6,261,4); tft.drawCircle(xpos-15,264,2,drawcolor);        //добавляем "C" и знак Цельсия
  if (temp2<TFanMax) {tft.setTextColor(TFT_GREEN,TFT_BLACK); drawcolor=TFT_GREEN;}          //если температура ниже аварийной, цвет зеленый
  if (temp2>=TFanMax){tft.setTextColor(TFT_RED,TFT_BLACK);   drawcolor=TFT_RED;}            //если температура равна или выше аварийной, цвет красный
    xpos=367;                                                                               //переносим координаты по X
    xpos+=tft.drawString("2: ",xpos,288,1);                                                 //выводим надпись "2: "
    xpos+=tft.drawFloat(temp2,1,xpos,286,4);                                                //и значение датчика 2
    xpos+=tft.drawString("C",xpos+6,286,4); tft.drawCircle(xpos-15,289,2,drawcolor);        //добавляем "C" и знак Цельсия
  if ((temp1>=TFanMax)&&(!statealarm)){pwr_on=0;                                            //при превышении температуры отключаем питание
    flag_tempalarm=1; TONE=2200; Time=70; N=6;                                              //устанавливаем флаг аварии в 1, выбираем тон сигнала, задержку и кол-во повторений
    tft.fillRect(190,119,165,23,TFT_BLACK);                                                 //стираем надписи
    tft.setTextColor(TFT_RED); tft.drawString("OVERHEAT 1",200,120,4);}                     //выводим надпись "OVERHEAT 1" красным цветом
  if ((temp2>=TFanMax)&&(!statealarm)){pwr_on=0;                                            //при превышении температуры отключаем питание
    flag_tempalarm=1; TONE=2200; Time=70; N=6;                                              //устанавливаем флаг аварии в 1, выбираем тон сигнала, задержку и кол-во повторений
    tft.fillRect(190,119,165,23,TFT_BLACK);                                                 //стираем надписи
    tft.setTextColor(TFT_RED); tft.drawString("OVERHEAT 2",200,120,4);}}                    //выводим надпись "OVERHEAT 2" красным цветом

  if (temp<TFanOff){digitalWrite(Fantemp,LOW);  flagFan=0;                                  //если температура меньше TFanOff, вентилятор отключен, флаг вентилятора в 0
  if (!flagFan){flagFan=2; Draw_colorOld=0; tft.fillCircle(375,130,19,TFT_BLACK);}}         //стираем знак вентилятора

  if (temp<TFanOn){                                                                         //если температура меньше TFanOn
  if (flagFan==1) Draw_color=TFT_GREEN;}                                                    //если флаг вентилятора 1, цвет зеленый
  if (temp>=TFanOn){digitalWrite(Fantemp,HIGH); flagFan=1; Draw_color=TFT_GREEN;}           //если температура выше или равна TFanOn, вентилятор включен, флаг вентилятора в 1
  if (temp>=TFanMax) Draw_color=TFT_RED;                                                    //если температура выше или равна Talarm, цвет красный

  if (flagFan==1){                                                                          //если флаг вентилятора 1
  if (Draw_colorOld!=Draw_color){Draw_colorOld=Draw_color;                                  //если изменился цвет
    tft.fillCircle(375,130,19,Draw_color);                                                  //
    tft.fillCircle(375,130,16,TFT_BLACK);                                                   //
    tft.fillCircle(375,130,3,Draw_color);}                                                  //рисуем центр
  if (Seconds%2){                                                                           //по четным секундам
    tft.fillCircle(375,120,5,Draw_color);                                                   //рисуем лопасти
    tft.fillCircle(384,135,5,Draw_color);                                                   //--------------
    tft.fillCircle(366,135,5,Draw_color);                                                   //--------------
    tft.fillCircle(384,125,5,TFT_BLACK);                                                    //--------------
    tft.fillCircle(366,125,5,TFT_BLACK);                                                    //--------------
    tft.fillCircle(375,140,5,TFT_BLACK);}                                                   //--------------
  else {                                                                                    //по не четным секундам
    tft.fillCircle(375,120,5,TFT_BLACK);                                                    //рисуем лопасти
    tft.fillCircle(384,135,5,TFT_BLACK);                                                    //--------------
    tft.fillCircle(366,135,5,TFT_BLACK);                                                    //--------------
    tft.fillCircle(384,125,5,Draw_color);                                                   //--------------
    tft.fillCircle(366,125,5,Draw_color);                                                   //--------------
    tft.fillCircle(375,140,5,Draw_color);}}                                                 //--------------
}
void draw_inp_pwr3(){digitalWrite(in120,LOW);//************************************************************************************ Прорисовка шкалы входной мощности 3Вт
    tft.fillRect(190,152,250,14,TFT_BLACK);                                                 //рисуем прямоугольник фона шкалы
    const char*inp_pwr[]={"0","0.5","1.0","1.5","2.0","2.5",""};                            //создаём массив символов для надстрочных надписей
  for(0,7){                                                                                 //запускаем цикл
    tft.setFreeFont(FSSB9);                                                                 //выбираем шрифт текста
  if (i>3){tft.setTextColor(TFT_RED);}                                                      //надписи дальше третьей риски красного цвета
  else tft.setTextColor(TFT_GREEN);                                                         //иначе зелёного
  if (i==0){tft.drawString(inp_pwr[i],190+i*45,152,1);}                                     //выводим надстрочные символы до третьего
  else tft.drawString(inp_pwr[i],183+i*45,152,1);}}                                         //выводим надстрочные символы с третьего до конца вправо

void draw_inp_pwr30(){digitalWrite(in120,LOW);//*********************************************************************************** Прорисовка шкалы входной мощности 30Вт
    tft.fillRect(190,152,250,14,TFT_BLACK);                                                 //рисуем прямоугольник фона шкалы
    const char*inp_pwr[]={"0","5","10","15","20","25",""};                                  //создаём массив символов для надстрочных надписей
  for(0,7){                                                                                 //запускаем цикл
    tft.setFreeFont(FSSB9);                                                                 //выбираем шрифт текста
  if (i>3){tft.setTextColor(TFT_RED);}                                                      //надписи дальше третьей риски красного цвета
  else tft.setTextColor(TFT_GREEN);                                                         //иначе зелёного
  if (i<2){tft.drawString(inp_pwr[i],190+i*45,152,1);}                                      //выводим надстрочные символы до третьего
  else tft.drawString(inp_pwr[i],185+i*45,152,1);}}                                         //выводим надстрочные символы с третьего до конца вправо

void draw_inp_pwr120(){digitalWrite(in120,HIGH);//********************************************************************************* Прорисовка шкалы входной мощности 120Вт
    tft.fillRect(190,152,250,14,TFT_BLACK);                                                 //рисуем прямоугольник фона шкалы
    const char*inp_pwr[]={"0","20","40","60","80","100",""};                                //создаём массив символов для надстрочных надписей
  for(0,7){                                                                                 //запускаем цикл
    tft.drawLine(194+i*45,168,194+i*45,175,TFT_SILVER);                                     //рисуем двойные
    tft.drawLine(195+i*45,168,195+i*45,175,TFT_SILVER);                                     //вертикальные риски
    tft.setFreeFont(FSSB9);                                                                 //выбираем шрифт текста
  if (i>3){tft.setTextColor(TFT_RED);}                                                      //надписи дальше третьей риски красного цвета
  else tft.setTextColor(TFT_GREEN);                                                         //иначе зелёного
  if (i<2){tft.drawLine(195,170+i,465,170+i,TFT_SILVER);}                                   //рисуем горизонтальную линию для шкалы
  if (i==0){tft.drawString(inp_pwr[i],190+i*45,152,1);}                                     //выводим надстрочный символ 0
  if ((i>0)&&(i<5)){tft.drawString(inp_pwr[i],185+i*45,152,1);}                             //выводим надстрочные символы до пятого
  if (i==5)tft.drawString(inp_pwr[i],180+i*45,152,1);}}                                     //выводим надстрочные символы с пятого до конца вправо

void draw_out_pwr(){//************************************************************************************************************* Прорисовка шкалы выходной мощности
    tft.drawLine(15,55,465,55,TFT_SILVER);                                                  //рисуем двойную горизонтальную линию
    tft.drawLine(15,56,465,56,TFT_SILVER);                                                  //для шкалы выходной мощности
    tft.setFreeFont(FSSB9);                                                                 //выбираем шрифт текста
  for(0,11){                                                                                //запускаем цикл
    tft.drawLine(14+i*45,51,14+i*45,58,TFT_SILVER);                                         //рисуем двойные
    tft.drawLine(15+i*45,51,15+i*45,58,TFT_SILVER);                                         //вертикальные риски
  if (Scale==1){ const char*out_pwr[]=                                                      //создаём массив символов для надстрочных надписей до 250Вт
    {"  0"," 25"," 50"," 75","100","125","150","175","200","225"," "};                      //---------------------------------------------------------
  if (i>7){tft.setTextColor(TFT_RED);}                                                      //надписи дальше седьмой риски красного цвета
  else tft.setTextColor(TFT_GREEN);                                                         //иначе зелёного
    tft.drawString(out_pwr[i],i*45,36,1);}                                                  //выводим надстрочные символы
  if (Scale==2){ const char*out_pwr[]=                                                      //создаём массив символов для надстрочных надписей до 500Вт
    {"  0"," 50","100","150","200","250","300","350","400","450"," "};                      //---------------------------------------------------------
  if (i>7){tft.setTextColor(TFT_RED);}                                                      //надписи дальше седьмой риски красного цвета
  else tft.setTextColor(TFT_GREEN);                                                         //иначе зелёного
    tft.drawString(out_pwr[i],i*45,36,1);}                                                  //выводим надстрочные символы
  if (Scale==3){ const char*out_pwr[]=                                                      //создаём массив символов для надстрочных надписей до 1000Вт
    {"  0","100","200","300","400","500","600","700","800","900"," "};                      //----------------------------------------------------------
  if (i>7){tft.setTextColor(TFT_RED);}                                                      //надписи дальше седьмой риски красного цвета
  else tft.setTextColor(TFT_GREEN);                                                         //иначе зелёного
    tft.drawString(out_pwr[i],i*45,36,1);}                                                  //выводим надстрочные символы
  if (Scale==4){ const char*out_pwr[]=                                                      //создаём массив символов для надстрочных надписей до 2000Вт
    {"  ","0.2","0.4","0.6","0.8","1.0","1.2","1.4","1.6","1.8"," "};                       //----------------------------------------------------------
  if (i>7){tft.setTextColor(TFT_RED);}                                                      //надписи дальше седьмой риски красного цвета
  else tft.setTextColor(TFT_GREEN);                                                         //иначе зелёного
    tft.drawString(out_pwr[i],2+i*45,36,1);                                                 //выводим надстрочные символы
    tft.setTextColor(TFT_GREEN); tft.drawString("0",9,36,1);}}}                             //выводим "0"

void get3231(){//***************************************************************************************************************** Датчик DS3231 температура внутри корпуса
  if (module){                                                                              //если модуль DS3231 подключен
    Wire.beginTransmission(104); Wire.write(0x11);                                          //запрос данных по адресу 104
    Wire.endTransmission(); Wire.requestFrom(104,2);                                        //конец передачи, получить два байта
    float temp3231=(Wire.read()&B01111111)+((Wire.read()>>6)*0.25);                         //читаем данные, конвертируем и получаем температуру
    
  if (!pwr_view){                                                                           //при включенном режиме часов
    tft.setTextPadding(20); tft.setTextColor(Cclock,TFT_BLACK);                             //цвет Cclock
    uint16_t xpos=50;                                                                       //начальная координата по х для вывода часов
    uint16_t ypos=10;                                                                       //начальная координата по y для вывода часов
    uint16_t xpos1=303;                                                                     //начальная координата по х для вывода даты
    RTC.read(tm);                                                                           //переменная чтения даты и времени
    hh=tm.Hour;                                                                             //выводим часы
    mm=tm.Minute;                                                                           //выводим минуты
    ss=tm.Second;                                                                           //выводим секунды
    dy=tm.Wday;                                                                             //выводим день недели
    da=tm.Day;                                                                              //выводим число
    mo=tm.Month;                                                                            //выводим месяц
    ya=tm.Year+1970;                                                                        //выводим год
    timebeep();                                                                             //выводим знак таймбипа

  if (newsecond!=ss){newsecond=ss;                                                          //если изменился счет секунд
  if (hh<10) xpos+=tft.drawChar('0',xpos,ypos,4);                                           //если показания часов меньше 10 дорисовываем незначащий ноль
    xpos+=tft.drawNumber(hh,xpos,ypos,4);                                                   //выводим значение часов
    xpos+=tft.drawChar(':',xpos,ypos,4);                                                    //рисуем часовое и минутное двоеточие
  if (mm<10) xpos+=tft.drawChar('0',xpos,ypos,4);                                           //если показания минут меньше 10 дорисовываем незначащий ноль
    xpos+=tft.drawNumber(mm,xpos,ypos,4);                                                   //выводим значение минут
    xpos+=tft.drawChar(':',xpos,ypos,4);                                                    //рисуем секундное двоеточие
  if (ss<10) xpos+=tft.drawChar('0',xpos,ypos,4);                                           //если показания секунд меньше 10 дорисовываем незначащий ноль
    tft.drawNumber(ss,xpos,ypos,4);                                                         //выводим значение секунд
  if (da<10) xpos1+=tft.drawChar('0',xpos1,ypos,4);                                         //если показания числа меньше 10 дорисовываем незначащий ноль
    xpos1+=tft.drawNumber(da,xpos1,ypos,4);                                                 //выводим значение числа
    xpos1+=tft.drawChar('-',xpos1,ypos,4);                                                  //формируем пробел между числом и месяцем
  if (mo<10) xpos1+=tft.drawChar('0',xpos1,ypos,4);                                         //если показания месяца меньше 10 дорисовываем незначащий ноль
    xpos1+=tft.drawNumber(mo,xpos1,ypos,4);                                                 //выводим значение месяца
    xpos1+=tft.drawChar('-',xpos1,ypos,4);                                                  //формируем пробел между месяцем и годом
    tft.drawNumber(ya,xpos1,ypos,4);                                                        //выводим значение года
    tft.setTextPadding(136);                                                                //включаем обновление подложки шрифта
  if (!Length){                                                                             //если "Length=0" выводим сокращённые названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.drawCentreString("-- Mon --",225,10,4); break;                              //выводим понедельник
    case 2: tft.drawCentreString("-- Tue --",225,10,4); break;                              //выводим вторник
    case 3: tft.drawCentreString("-- Wed --",225,10,4); break;                              //выводим среда
    case 4: tft.drawCentreString("-- Thu --",225,10,4); break;                              //выводим четверг
    case 5: tft.drawCentreString("-- Fri --",225,10,4); break;                              //выводим пятница
    case 6: tft.drawCentreString("-- Sat --",225,10,4); break;                              //выводим суббота
    case 7: tft.drawCentreString("-- Sun --",225,10,4); break;}}                            //выводим воскресенье
  if (Length){                                                                              //если "Length=1" выводим полные названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.drawCentreString("  Monday ",225,10,4); break;                              //выводим понедельник
    case 2: tft.drawCentreString(" Tuesday ",225,10,4); break;                              //выводим вторник
    case 3: tft.drawCentreString("Wednesday",225,10,4); break;                              //выводим среда
    case 4: tft.drawCentreString(" Thursday",225,10,4); break;                              //выводим четверг
    case 5: tft.drawCentreString("  Friday ",225,10,4); break;                              //выводим пятница
    case 6: tft.drawCentreString(" Saturday",225,10,4); break;                              //выводим суббота
    case 7: tft.drawCentreString("  Sunday ",225,10,4); break;}}}                           //выводим воскресенье
}
  if (num18b20<2){uint16_t xposT=367;                                                       //если кол-во датчиков DS18B20 меньше 2
    tft.setTextPadding(0); tft.setFreeFont(FSSB12);                                         //шрифт FSSB12
    tft.setTextColor(TFT_DARKGREY,TFT_BLACK);                                               //выбираем цвет темно-серый
    xposT+=tft.drawString("T: ",xposT,263,1); xposT+=tft.drawFloat(temp3231,1,xposT,261,4); //выводим "T: ", значение температуры от DS3231
    xposT+=tft.drawString("C",xposT+7,261,4); tft.drawCircle(xposT-15,264,2,TFT_DARKGREY);}}//добавляем в конце "C" и знак Цельсия
  else {                                                                                    //при отключенном модуле DS3231
  if (!pwr_view){                                                                           //в режиме отображения часов
  if (newsecond!=Seconds){newsecond=Seconds;                                                //обновляем время каждую секунду
    uint16_t xpos=50;                                                                       //начальная координата по х для вывода часов
    uint16_t ypos=10;                                                                       //начальная координата по y для вывода часов
    tft.setTextPadding(20); tft.setTextColor(Cclock,TFT_BLACK);                             //обновляем значение времени раз в секунду
  if (hh<10) xpos+=tft.drawChar('0',xpos,ypos,4);                                           //если показания часов меньше 10 дорисовываем незначащий ноль
    xpos+=tft.drawNumber(hh,xpos,ypos,4);                                                   //выводим значение часов
    xpos+=tft.drawChar(':',xpos,ypos,4);                                                    //рисуем часовое и минутное двоеточие
  if (mm<10) xpos+=tft.drawChar('0',xpos,ypos,4);                                           //если показания минут меньше 10 дорисовываем незначащий ноль
    xpos+=tft.drawNumber(mm,xpos,ypos,4);                                                   //выводим значение минут
    xpos+=tft.drawChar(':',xpos,ypos,4);                                                    //рисуем секундное двоеточие
  if (ss<10) xpos+=tft.drawChar('0',xpos,ypos,4);                                           //если показания секунд меньше 10 дорисовываем незначащий ноль
    tft.drawNumber(ss,xpos,ypos,4);                                                         //выводим значение секунд
    timebeep();                                                                             //выводим знак таймбипа
    tft.setFreeFont(FSBI12);                                                                //выбираем шрифт и цвет текста
    tft.setTextColor(Cclock);                                                               //цвет Cclock
    tft.drawCentreString("D 0 I T C  &  D 0 I S M",295,12,1);}}}                            //выводим надпись "D 0 I T C  &  D 0 I S M"
}
void timebeep(){//************************************************************************************************** Знак таймбипа
  if (TimeBeep){                                                                            //при включенном режиме "TimeBeep" выводим символ
    tft.fillCircle(31,20,2,Cclock);                                                         //рисуем пиктограмму Time Beep
    tft.drawPixel(36,17,Cclock);tft.drawPixel(36,23,Cclock);                                //----------------------------
    tft.drawPixel(37,18,Cclock);tft.drawPixel(37,22,Cclock);                                //----------------------------
    tft.drawLine (38,19,38,21,Cclock);                                                      //----------------------------
    tft.drawPixel(38,15,Cclock);tft.drawPixel(38,25,Cclock);                                //----------------------------
    tft.drawPixel(39,16,Cclock);tft.drawPixel(39,24,Cclock);                                //----------------------------
    tft.drawPixel(40,17,Cclock);tft.drawPixel(40,23,Cclock);                                //----------------------------
    tft.drawLine(41,18,41,22,Cclock);}                                                      //----------------------------

  if (!TimeBeep){                                                                           //при выключенном режиме "TimeBeep" символ серого цвета
    tft.fillCircle(31,20,2,TFT_GREY100);                                                    //рисуем пиктограмму Time Beep
    tft.drawPixel(36,17,TFT_GREY100);tft.drawPixel(36,23,TFT_GREY100);                      //----------------------------
    tft.drawPixel(37,18,TFT_GREY100);tft.drawPixel(37,22,TFT_GREY100);                      //----------------------------
    tft.drawLine (38,19,38,21,TFT_GREY100);                                                 //----------------------------
    tft.drawPixel(38,15,TFT_GREY100);tft.drawPixel(38,25,TFT_GREY100);                      //----------------------------
    tft.drawPixel(39,16,TFT_GREY100);tft.drawPixel(39,24,TFT_GREY100);                      //----------------------------
    tft.drawPixel(40,17,TFT_GREY100);tft.drawPixel(40,23,TFT_GREY100);                      //----------------------------
    tft.drawLine(41,18,41,22,TFT_GREY100);}                                                 //----------------------------
}

void preparing_the_screen(){//************************************************************************************ Подготовка экрана
    band_get=band;                                                                          //чтобы при первом переключении в режиме "AUTO BAND" небыло двух "пиков"
    VOXcount=VOXDelay;                                                                      //включение режима VOX без задержки
    PWRfold=1;                                                                              //обновление значений мощности
    PWRiold=1;                                                                              //------
    PWRi3old=1;                                                                             //------
    aOld=1;                                                                                 //обновление градусника выходной мощности
    bOld=1;                                                                                 //обновление градусника входной мощности
    Draw_colorOld=0;                                                                        //обновление значка вентилятора
  
  if (Scale==1){A=22.361; B=250; C=5;  D=5;}                                                //если выбрана выходная мощность  250Вт "Scale==1"
  if (Scale==2){A=31.63;  B=500; C=10; D=10;}                                               //если выбрана выходная мощность  500Вт "Scale==2"
  if (Scale==3){A=44.722; B=500; C=10; D=20;}                                               //если выбрана выходная мощность 1000Вт "Scale==3"
  if (Scale==4){A=63.25;  B=500; C=10; D=40;}                                               //если выбрана выходная мощность 2000Вт "Scale==4"
  
  if (BORDER==1) BORDER=TFT_GREEN;                                                          //если BORDER==1 включается зелёный цвет окантовок рамки
  if (BORDER==2) BORDER=TFT_SILVER;                                                         //если BORDER==2 включается серебряный цвет окантовок рамки
  if (BORDER==3) BORDER=TFT_PINK;                                                           //если BORDER==3 включается розовый цвет окантовок рамки
  if (BORDER==4) BORDER=TFT_ORANGE;                                                         //если BORDER==3 включается оранжевый цвет окантовок рамки
  if (BORDER==5) BORDER=TFT_CYAN;                                                           //если BORDER==3 включается голубой цвет окантовок рамки
  
  if (Cclock==1) Cclock=TFT_GREEN;                                                          //если Cclock==1 включается зелёный цвет вывода часов
  if (Cclock==2) Cclock=TFT_SILVER;                                                         //если Cclock==2 включается серебряный цвет вывода часов
  if (Cclock==3) Cclock=TFT_PINK;                                                           //если Cclock==3 включается розовый цвет вывода часов
  if (Cclock==4) Cclock=TFT_ORANGE;                                                         //если Cclock==4 включается оранжевый цвет вывода часов
  if (Cclock==5) Cclock=TFT_CYAN;                                                           //если Cclock==5 включается голубой цвет вывода часов
    
    flag_mode_band=1;                                                                       //чтобы при выходе из меню отображался режим перекл. диапазонов
    tft.fillScreen(TFT_GREY60);                                                             //заливаем экран серым цветом
    tft.fillRoundRect(6,6,468,96,8,TFT_BLACK);                                              //рисуем черный прямоугольник вывода информации о выходной мощности
    tft.fillRoundRect(8,108,170,56,5,TFT_BLACK);                                            //рисуем черный прямоугольник для кнопки "BYPASS/POWER ON"
    tft.fillRoundRect(6,170,174,58,8,TFT_BLACK);                                            //рисуем черный прямоугольник вывода информации о КСВ
    tft.fillRoundRect(184,106,290,124,8,TFT_BLACK);                                         //рисуем черный прямоугольник вывода информации о входной мощности
    tft.fillRoundRect(6,234,115,80,8,TFT_BLACK);                                            //рисуем черный прямоугольник вывода информации о диапазонах
    tft.fillRoundRect(125,234,113,80,8,TFT_BLACK);                                          //рисуем черный прямоугольник вывода информации о потребляемом токе
    tft.fillRoundRect(242,234,115,80,8,TFT_BLACK);                                          //рисуем черный прямоугольник вывода информации о напряжении питания
    tft.fillRoundRect(361,234,113,80,8,TFT_BLACK);                                          //рисуем черный прямоугольник вывода информации о температуре
  for(0,2){                                                                                 //включаем цикл
    tft.drawRect(0+i,0+i,480-i*2,320-i*2,BORDER);                                           //рисуем наружную окантовку
    tft.drawRoundRect(6+i,6+i,468-i*2,96-i*2,8-i,BORDER);                                   //рисуем внутреннюю окантовку с закруглёнными углами
    tft.drawRoundRect(6+i,106+i,174-i*2,60-i*2,8-i,BORDER);                                 //рисуем окантовку для кнопки "ON/OFF"
    tft.drawRoundRect(6+i,170+i,174-i*2,60-i*2,8-i,BORDER);                                 //рисуем окантовку для вывода информации о КСВ
    tft.drawRoundRect(184+i,106+i,290-i*2,124-i*2,8-i,BORDER);                              //рисуем окантовку для вывода информации о входной мощности
    tft.drawRoundRect(6+i,234+i,115-i*2,80-i*2,8-i,BORDER);                                 //рисуем окантовку для вывода информации о диапазонах
    tft.drawRoundRect(125+i,234+i,113-i*2,80-i*2,8-i,BORDER);                               //рисуем окантовку для вывода информации о потребляемом токе
    tft.drawRoundRect(242+i,234+i,115-i*2,80-i*2,8-i,BORDER);                               //рисуем окантовку для вывода информации о напряжении питания
    tft.drawRoundRect(361+i,234+i,113-i*2,80-i*2,8-i,BORDER);}                              //рисуем окантовку для вывода информации о температуре
    tft.setFreeFont(FSSB9); tft.setTextColor(TFT_DARKGREY);                                 //выбираем шрифт и цвет текста
    tft.drawCentreString("CURRENT",180,245,1);                                              //выводим надпись "CURRENT"
    tft.drawCentreString("VOLTAGE",297,245,1);                                              //выводим надпись "VOLTAGE"
    tft.drawCentreString("TEMP",415,245,1);                                                 //выводим надпись "TEMP"
    tft.setFreeFont(FSSB12); tft.drawString("SWR = WAIT",25,192,1);                         //выбираем шрифт, выводим надпись "SWR = WAIT"
    PWRSwitch();                                                                            //кнопка питания ON/OFF
    draw_inp_pwr120();                                                                      //прорисовка шкалы входной мощности 120Вт
    draw_out_pwr();                                                                         //прорисовка шкалы выходной мощности 250_500_1000_2000Вт
    symbol_speaker();                                                                       //символ бипера
    
    tft.setFreeFont(FSSB9); tft.setTextColor(TFT_DARKGREY);                                 //выбираем шрифт и цвет текста
  if (Acs==1){tft.drawCentreString("ACS7XX-20",180,265,1);                                  //выводим надпись "ACS7XX-20"
    sensor.setSensitivity(ACS712_20_AMPERS);}                                               //выбираем ACS712_20
  if (Acs==2){tft.drawCentreString("ACS7XX-30",180,265,1);                                  //выводим надпись "ACS7XX-30"
    sensor.setSensitivity(ACS712_30_AMPERS);}                                               //выбираем ACS712_30
  if (Acs==3){tft.drawCentreString("ACS7XX-50",180,265,1);                                  //выводим надпись "ACS7XX-50"
    sensor.setSensitivity(ACS758_50_AMPERS);}                                               //выбираем ACS758_50
  if (Acs==4){tft.drawCentreString("ACS7XX-100",181,265,1);                                 //выводим надпись "ACS7XX-100"
    sensor.setSensitivity(ACS758_100_AMPERS);}                                              //выбираем ACS758_100
    sensor.calibrate();                                                                     //калибровка датчика ACS7XX
}
void menu(){//********************************************************************************************************************* Подпрограмма меню
    char buf[5]; byte len=4;                                                                //переменные символьного массива для вывода значений в меню
    tft.fillScreen(TFT_GREY60);                                                             //заливаем экран серым цветом
  for(0,2){                                                                                 //включаем цикл
    tft.drawRect(0+i,0+i,480-i*2,320-i*2,BORDER);                                           //рисуем наружную окантовку
    tft.drawRoundRect(6+i,6+i,468-i*2,308-i*2,8-i,BORDER);}                                 //рисуем внутреннюю окантовку с закруглёнными углами
    int Select1,Select2,Select3,Select4,Select5,Select6,Select7,Select8,Select9,Select10,   //переменные пунктов меню
    Select11,Select12,Select13,Select15,Select16,Select17,Select18,Select20,Select21,       //-----------------------
    Select22,Select23,Select24,Select25,Select26,Select27,Select28,Select29;                //-----------------------
    float Select14,Select19;                                                                //-----------------------
  
  if (place) goto M1;                                                                       //если "place!=0" пропускаем экран навигации меню и переходим по метке М1 и считываем память
    tft.fillRoundRect(8,8,464,304,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
    tft.setFreeFont(FSBI18); tft.setTextColor(BORDER);                                      //выбираем шрифт и цвет текста
    tft.drawCentreString("-- MENU --",240,20,1);                                            //выводим надпись "-- MENU --"
    tft.setTextColor(TFT_SILVER);                                                           //выбираем цвет текста
    tft.drawCentreString("Press the button N1 -> page 1",240,80,1);                         //выводим надпись "Press the button N1 -> page 1"
    tft.drawCentreString("Press the button N2 -> page 2",240,120,1);                        //выводим надпись "Press the button N2 -> page 2"
    tft.drawCentreString("Press the button N3 -> page 3",240,160,1);                        //выводим надпись "Press the button N3 -> page 3"
    tft.drawCentreString("Press the button N4 -> page 4",240,200,1);                        //выводим надпись "Press the button N4 -> page 4"
    tft.setFreeFont(FSBI12); tft.setTextColor(TFT_DARKGREY);                                //выбираем шрифт и цвет текста
    tft.drawCentreString("D0ITC 2019 D0ISM",240,281,1);                                     //выводим надпись "D0ITC 2019 D0ISM"
  
  while (place<1){                                                                          //находимся в цикле пока "place<1"
  switch(button1.Loop()){                                                                   //описываем работу кнопки "button1"
    case SB_CLICK: beeper(); place=1; break;                                                //коротким нажатием переходим на первую страницу
    case SB_LONG_CLICK: beeper(); goto M3; break;}                                          //длинным нажатием по метке M3 выходим из меню
  switch(button2.Loop()){                                                                   //описываем работу кнопки "button2"
    case SB_CLICK: beeper(); place=9; break;}                                               //коротким нажатием переходим на вторую страницу
  switch(button3.Loop()){                                                                   //описываем работу кнопки "button3"
    case SB_CLICK: beeper(); place=17; break;}                                              //коротким нажатием переходим на третью страницу
  switch(button4.Loop()){                                                                   //описываем работу кнопки "button4"
    case SB_CLICK: beeper(); place=25; break;}}                                             //коротким нажатием переходим на четвёртую страницу

M1: VOXDelay   =EEPROM.read(10); Select1=VOXDelay;                                          //читаем содержимое ячейки 10 EEPROM в переменную VOXDelay
    ATTDelay   =EEPROM.read(11); Select2=ATTDelay;                                          //читаем содержимое ячейки 11 EEPROM в переменную ATTDelay
    Imax       =EEPROM.read(12); Select3=Imax;                                              //читаем содержимое ячейки 12 EEPROM в переменную Imax
    Vmin       =EEPROM.read(13); Select4=Vmin;                                              //читаем содержимое ячейки 13 EEPROM в переменную Vmin
    Vmax       =EEPROM.read(14); Select5=Vmax;                                              //читаем содержимое ячейки 14 EEPROM в переменную Vmax
    TFanOff    =EEPROM.read(15); Select6=TFanOff;                                           //читаем содержимое ячейки 15 EEPROM в переменную TFanOff
    TFanOn     =EEPROM.read(16); Select7=TFanOn;                                            //читаем содержимое ячейки 16 EEPROM в переменную TFanOn
    TFanMax    =EEPROM.read(17); Select8=TFanMax;                                           //читаем содержимое ячейки 17 EEPROM в переменную TFanMax
    ATToff     =EEPROM.read(20); Select9=ATToff;                                            //читаем содержимое ячейки 20 EEPROM в переменную ATToff
    ATT3dB     =EEPROM.read(21); Select10=ATT3dB;                                           //читаем содержимое ячейки 21 EEPROM в переменную ATT3dB
    ATT6dB     =EEPROM.read(22); Select11=ATT6dB;                                           //читаем содержимое ячейки 22 EEPROM в переменную ATT6dB
    ATTauto    =EEPROM.read(23); Select12=ATTauto;                                          //читаем содержимое ячейки 23 EEPROM в переменную ATTauto
    ATTalarm   =EEPROM.read(24); Select13=ATTalarm;                                         //читаем содержимое ячейки 24 EEPROM в переменную ATTalarm
    EEPROM.get(27,SWRmax);       Select14=SWRmax;                                           //читаем содержимое ячейки 27-30 EEPROM в переменную SWRmax
    Tonbeep    =EEPROM.read(26); Select15=Tonbeep;                                          //читаем содержимое ячейки 26 EEPROM в переменную Tonbeep
    beep       =EEPROM.read(4);  Select16=beep;                                             //читаем содержимое ячейки 4 EEPROM в переменную beep
    TimeBeep   =EEPROM.read(25); Select17=TimeBeep;                                         //читаем содержимое ячейки 25 EEPROM в переменную TimeBeep
    BandDelay  =EEPROM.read(18); Select18=BandDelay;                                        //читаем содержимое ячейки 18 EEPROM в переменную BandDelay
    EEPROM.get(31,divider);      Select19=divider;                                          //читаем содержимое ячейки 31-34 EEPROM в переменную divider
    RefreshTime=EEPROM.read(7);  Select20=RefreshTime;                                      //читаем содержимое ячейки 7 EEPROM в переменную RefreshTime
    Acs        =EEPROM.read(8);  Select21=Acs;                                              //читаем содержимое ячейки 8 EEPROM в переменную ACS
    Length     =EEPROM.read(9);  Select22=Length;                                           //читаем содержимое ячейки 9 EEPROM в переменную Length
    Scale      =EEPROM.read(35); Select23=Scale;                                            //читаем содержимое ячейки 35 EEPROM в переменную Scale
    BORDER     =EEPROM.read(36); Select24=BORDER;                                           //читаем содержимое ячейки 36 EEPROM в переменную BORDER
  if (BORDER==1) BORDER=TFT_GREEN;                                                          //если BORDER==1 включается зелёный цвет окантовок рамки
  if (BORDER==2) BORDER=TFT_SILVER;                                                         //если BORDER==2 включается серебряный цвет окантовок рамки
  if (BORDER==3) BORDER=TFT_PINK;                                                           //если BORDER==3 включается розовый цвет окантовок рамки
  if (BORDER==4) BORDER=TFT_ORANGE;                                                         //если BORDER==3 включается оранжевый цвет окантовок рамки
  if (BORDER==5) BORDER=TFT_CYAN;                                                           //если BORDER==3 включается голубой цвет окантовок рамки
    ALC        =EEPROM.read(37); Select25=ALC;                                              //читаем содержимое ячейки 37 EEPROM в переменную ALC
    Cclock     =EEPROM.read(38); Select27=Cclock;                                           //читаем содержимое ячейки 38 EEPROM в переменную Cclock
    powerin    =EEPROM.read(39); Select28=powerin;                                          //читаем содержимое ячейки 39 EEPROM в переменную  powerin
    pwr_inv    =EEPROM.read(40); Select29=pwr_inv;                                          //читаем новое значение ячейки 40 EEPROM в переменную pwr_inv    
  
  switch(place){                                                                            //функция выбора страницы меню
    case  1 ... 8:  goto p1; break;                                                         //если пункт 1...8 уходим по метке p1 на первую страницу
    case  9 ... 16: goto p2; break;                                                         //если пункт 9...16 уходим по метке p2 на вторую страницу
    case 17 ... 24: goto p3; break;                                                         //если пункт 7...24 уходим по метке p3 на третью страницу
    case 25 ... 29: goto p4; break;}                                                        //если пункт 25...29 уходим по метке p4 на четвёртую страницу

p1: tft.fillRoundRect(8,8,464,304,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
    tft.setFreeFont(FSSB9); tft.setTextColor(BORDER);                                       //выбираем шрифт и цвет текста
    tft.drawString("page 1",25,20,1);                                                       //выводим надпись "page 1"
    tft.setFreeFont(FSBI12);                                                                //выбираем шрифт
    tft.drawCentreString("-- MENU --",240,20,1);                                            //выводим надпись "-- MENU --"
    tft.setTextColor(TFT_SILVER);                                                           //выбираем цвет текста
    tft.drawString("01. VOX Delay",25,50,1);                                                //выводим надпись "01. VOX Delay"
    tft.drawString("02. ATT Delay",25,83,1);                                                //выводим надпись "02. ATT Delay"
    tft.drawString("03. Imax",25,116,1);                                                    //выводим надпись "03. Imax"
    tft.drawString("04. Vmin",25,149,1);                                                    //выводим надпись "04. Vmin"
    tft.drawString("05. Vmax",25,182,1);                                                    //выводим надпись "05. Vmax"
    tft.drawString("06. TFan Off",25,215,1);                                                //выводим надпись "06. TFan Off"
    tft.drawString("07. TFan On",25,248,1);                                                 //выводим надпись "07. TFan On"
    tft.drawString("08. TFan Max",25,281,1);                                                //выводим надпись "08. TFan Max"
    tft.drawString("2 ... 100",195,50,1);                                                   //выводим пределы регулирования "2...100"
    tft.drawString("10 ... 2500",183,83,1);                                                 //выводим пределы регулирования "10...2500"
    tft.drawString("0 ... 100A",195,116,1);                                                 //выводим пределы регулирования "0...100A"
    tft.drawString("0 ... 50V",195,149,1);                                                  //выводим пределы регулирования "0...50V"
    tft.drawString("0 ... 60V",195,182,1);                                                  //выводим пределы регулирования "0...60V"
    tft.drawString("0 ... 50C",195,215,1);                                                  //выводим пределы регулирования "0...50C"
    tft.drawString("0 ... 50C",195,248,1);                                                  //выводим пределы регулирования "0...50C"
    tft.drawString("0 ... 75C",195,281,1);                                                  //выводим пределы регулирования "0...75C"
    tft.drawNumber(Select1,420,50,1);                                                       //выводим редактируемое значение "VOX Delay"
    dtostrf(Select2*10,len,0,buf);                                                          //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,83,1);                                                     //выводим редактируемое значение "ATT Delay" умноженное на 10
    tft.drawNumber(Select3,410,116,1);                                                      //выводим редактируемое значение "Imax"
    tft.drawNumber(Select4,420,149,1);                                                      //выводим редактируемое значение "Vmin"
    tft.drawNumber(Select5,420,182,1);                                                      //выводим редактируемое значение "Vmax"
    tft.drawNumber(Select6,420,215,1);                                                      //выводим редактируемое значение "TFan Off"
    tft.drawNumber(Select7,420,248,1);                                                      //выводим редактируемое значение "TFan On"
    tft.drawNumber(Select8,420,281,1);                                                      //выводим редактируемое значение "TFan Max"
    tft.setTextColor(TFT_GREY60);                                                           //выбираем шрифт и цвет текста
    tft.drawNumber(Select1,350,50,1);                                                       //выводим текущее значение "VOX Delay"
    tft.drawCentreString(buf,355,83,1);                                                     //выводим текущее значение "ATT Delay" умноженное на 10
    tft.drawNumber(Select3,340,116,1);                                                      //выводим текущее значение "Imax"
    tft.drawNumber(Select4,350,149,1);                                                      //выводим текущее значение "Vmin"
    tft.drawNumber(Select5,350,182,1);                                                      //выводим текущее значение "Vmax"
    tft.drawNumber(Select6,350,215,1);                                                      //выводим текущее значение "TFan Off"
    tft.drawNumber(Select7,350,248,1);                                                      //выводим текущее значение "TFan On"
    tft.drawNumber(Select8,350,281,1);                                                      //выводим текущее значение "TFan Max"
  while (place<9){                                                                          //находимся на первой странице пока place<9
  switch(button1.Loop()){                                                                   //описываем работу кнопки "BYPASS/POWER ON"
    case SB_CLICK: beeper(); place=10; break;                                               //коротким нажатием по метке p4 переходим на четвёртую страницу
    case SB_LONG_CLICK: beeper(); goto M2; break;}                                          //длинным нажатием по метке M2 выходим из меню
  switch(button2.Loop()){                                                                   //кнопкой "Band/Protocol" переключаем редактируемые параметры
    case SB_CLICK: place++; beeper(); if (place>8) place=1; break;                          //коротким нажатием по одному параметру по кольцу
    case SB_LONG_CLICK: place=9; beeper(); break;}                                          //длинным нажатием переходим на вторую страницу
  
  if (place==1){tft.setTextColor(TFT_SILVER); tft.drawString("08. TFan Max",25,281,1);      //восстанавливаем цвет надписи "08. TFan Max"
    tft.drawString("0 ... 75C",195,281,1); tft.drawRect(20,273,440,33,TFT_BLACK);           //затираем рамку "TFan Max"
    tft.setTextColor(TFT_RED); tft.drawString("01. VOX Delay",25,50,1);                     //выводим надпись "VOX Delay" красным цветом
    tft.drawString("2 ... 100",195,50,1);                                                   //выводим пределы регулирования "2...100"
    tft.drawRect(20,42,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                       //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select1++; beeper(); if (Select1>100){Select1=2;}}                      //увеличиваем выбранное значение на единицу
    tft.fillRect(420,50,35,18,TFT_BLACK); tft.drawNumber(Select1,420,50,1); break;          //выводим значение "VOX Delay" красным цветом
    case SB_AUTO_CLICK: {Select1++; beeper(); if (Select1>100){Select1=2;}}                 //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,50,35,18,TFT_BLACK); tft.drawNumber(Select1,420,50,1); break;}         //выводим значение "VOX Delay" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select1--; beeper(); if (Select1<2){Select1=100;}}                      //уменьшаем выбранное значение на единицу
    tft.fillRect(420,50,35,18,TFT_BLACK); tft.drawNumber(Select1,420,50,1); break;          //выводим значение "VOX Delay" красным цветом
    case SB_AUTO_CLICK: {Select1--; beeper(); if (Select1<2){Select1=100;}}                 //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,50,35,18,TFT_BLACK); tft.drawNumber(Select1,420,50,1); break;}}        //выводим значение "VOX Delay" красным цветом
  
  if (place==2){tft.setTextColor(TFT_SILVER); tft.drawString("01. VOX Delay",25,50,1);      //восстанавливаем цвет надписи "VOX Delay"
    tft.drawString("2 ... 100",195,50,1); tft.drawRect(20,42,440,33,TFT_BLACK);             //зарисовываем рамку "VOX Delay"
    tft.setTextColor(TFT_RED); tft.drawString("02. ATT Delay",25,83,1);                     //выводим надпись "ATT Delay" красным цветом
    tft.drawString("10 ... 2500",183,83,1);                                                 //выводим пределы регулирования "10...2500"
    tft.drawRect(20,75,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                       //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select2++; beeper(); if (Select2>250){Select2=1;}}                      //увеличиваем выбранное значение на десять
    tft.fillRect(402,83,49,18,TFT_BLACK); dtostrf(Select2*10,len,0,buf);                    //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,83,1); break;                                              //выводим по центру значение "ATT Delay" красным цветом умноженное на 10
    case SB_AUTO_CLICK: {Select2++; beeper(); if (Select2>250){Select2=1;}}                 //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(402,83,49,18,TFT_BLACK); dtostrf(Select2*10,len,0,buf);                    //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,83,1); break;}                                             //выводим по центру значение "ATT Delay" красным цветом умноженное на 10
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select2--; beeper(); if (Select2<1){Select2=250;}}                      //уменьшаем выбранное значение на десять
    tft.fillRect(402,83,49,18,TFT_BLACK); dtostrf(Select2*10,len,0,buf);                    //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,83,1); break;                                              //выводим по центру значение "ATT Delay" красным цветом умноженное на 10
    case SB_AUTO_CLICK: {Select2--; beeper(); if (Select2<1){Select2=250;}}                 //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(402,83,49,18,TFT_BLACK); dtostrf(Select2*10,len,0,buf);                    //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,83,1); break;}}                                            //выводим по центру значение "ATT Delay" красным цветом умноженное на 10
  
  if (place==3){tft.setTextColor(TFT_SILVER); tft.drawString("02. ATT Delay",25,83,1);      //восстанавливаем цвет надписи "ATT Delay"
    tft.drawString("10 ... 2500",183,83,1); tft.drawRect(20,75,440,33,TFT_BLACK);           //зарисовываем рамку "ATT Delay"
    tft.setTextColor(TFT_RED); tft.drawString("03. Imax",25,116,1);                         //выводим надпись "Imax" красным цветом
    tft.drawString("0 ... 100A",195,116,1);                                                 //выводим пределы регулирования "0...100A"
    tft.drawRect(20,108,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select3++; beeper(); if (Select3>100){Select3=1;}}                      //увеличиваем выбранное значение на единицу
    tft.fillRect(410,116,35,18,TFT_BLACK); tft.drawNumber(Select3,410,116,1); break;        //выводим значение "Imax" красным цветом
    case SB_AUTO_CLICK: {Select3++; beeper(); if (Select3>100){Select3=1;}}                 //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(410,116,35,18,TFT_BLACK); tft.drawNumber(Select3,410,116,1); break;}       //выводим значение "Imax" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select3--; beeper(); if (Select3<1){Select3=100;}}                      //уменьшаем выбранное значение на единицу
    tft.fillRect(410,116,35,18,TFT_BLACK); tft.drawNumber(Select3,410,116,1); break;        //выводим значение "Imax" красным цветом
    case SB_AUTO_CLICK: {Select3--; beeper(); if (Select3<1){Select3=100;}}                 //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(410,116,35,18,TFT_BLACK); tft.drawNumber(Select3,410,116,1); break;}}      //выводим значение "Imax" красным цветом
  
  if (place==4){tft.setTextColor(TFT_SILVER); tft.drawString("03. Imax",25,116,1);          //восстанавливаем цвет надписи "Imax"
    tft.drawString("0 ... 100A",195,116,1); tft.drawRect(20,108,440,33,TFT_BLACK);          //зарисовываем рамку "Imax"
    tft.setTextColor(TFT_RED); tft.drawString("04. Vmin",25,149,1);                         //выводим надпись "Vmin" красным цветом
    tft.drawString("0 ... 50V",195,149,1);                                                  //выводим пределы регулирования "0...50V"
    tft.drawRect(20,141,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select4++; beeper(); if (Select4>50){Select4=0;}}                       //увеличиваем выбранное значение на единицу
    tft.fillRect(420,149,35,18,TFT_BLACK); tft.drawNumber(Select4,420,149,1); break;        //выводим значение "Vmin" красным цветом
    case SB_AUTO_CLICK: {Select4++; beeper(); if (Select4>50){Select4=0;}}                  //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,149,35,18,TFT_BLACK); tft.drawNumber(Select4,420,149,1); break;}       //выводим значение "Vmin" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select4--; beeper(); if (Select4<0){Select4=50;}}                       //уменьшаем выбранное значение на единицу
    tft.fillRect(420,149,35,18,TFT_BLACK); tft.drawNumber(Select4,420,149,1); break;        //выводим значение "Vmin" красным цветом
    case SB_AUTO_CLICK: {Select4--; beeper(); if (Select4<0){Select4=50;}}                  //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,149,35,18,TFT_BLACK); tft.drawNumber(Select4,420,149,1); break;}}      //выводим значение "Vmin" красным цветом
  if (place==5){tft.setTextColor(TFT_SILVER); tft.drawString("04. Vmin",25,149,1);          //восстанавливаем цвет надписи "Vmin"
    tft.drawString("0 ... 50V",195,149,1); tft.drawRect(20,141,440,33,TFT_BLACK);           //зарисовываем рамку "Vmin"
    tft.setTextColor(TFT_RED); tft.drawString("05. Vmax",25,182,1);                         //выводим надпись "Vmax" красным цветом
    tft.drawString("0 ... 60V",195,182,1);                                                  //выводим пределы регулирования "0...60V"
    tft.drawRect(20,174,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select5++; beeper(); if (Select5>60){Select5=0;}}                       //увеличиваем выбранное значение на единицу
    tft.fillRect(420,182,35,18,TFT_BLACK); tft.drawNumber(Select5,420,182,1); break;        //выводим значение "Vmax" красным цветом
    case SB_AUTO_CLICK: {Select5++; beeper(); if (Select5>60){Select5=0;}}                  //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,182,35,18,TFT_BLACK); tft.drawNumber(Select5,420,182,1); break;}       //выводим значение "Vmax" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select5--; beeper(); if (Select5<0){Select5=60;}}                       //уменьшаем выбранное значение на единицу
    tft.fillRect(420,182,35,18,TFT_BLACK); tft.drawNumber(Select5,420,182,1); break;        //выводим значение "Vmax" красным цветом
    case SB_AUTO_CLICK: {Select5--; beeper(); if (Select5<0){Select5=60;}}                  //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,182,35,18,TFT_BLACK); tft.drawNumber(Select5,420,182,1); break;}}      //выводим значение "Vmax" красным цветом
  if (place==6){tft.setTextColor(TFT_SILVER); tft.drawString("05. Vmax",25,182,1);          //восстанавливаем цвет надписи "Vmax"
    tft.drawString("0 ... 60V",195,182,1); tft.drawRect(20,174,440,33,TFT_BLACK);           //зарисовываем рамку "Vmax"
    tft.setTextColor(TFT_RED); tft.drawString("06. TFan Off",25,215,1);                     //выводим надпись "TFan Off" красным цветом
    tft.drawString("0 ... 50C",195,215,1);                                                  //выводим пределы регулирования "0...50C"
    tft.drawRect(20,207,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select6++; beeper(); if (Select6>50){Select6=0;}}                       //увеличиваем выбранное значение на единицу
    tft.fillRect(420,215,35,18,TFT_BLACK); tft.drawNumber(Select6,420,215,1); break;        //выводим значение "TFan Off" красным цветом
    case SB_AUTO_CLICK: {Select6++; beeper(); if (Select6>50){Select6=0;}}                  //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,215,35,18,TFT_BLACK); tft.drawNumber(Select6,420,215,1); break;}       //выводим значение "TFan Off" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select6--; beeper(); if (Select6<0){Select6=50;}}                       //уменьшаем выбранное значение на единицу
    tft.fillRect(420,215,35,18,TFT_BLACK); tft.drawNumber(Select6,420,215,1); break;        //выводим значение "TFan Off" красным цветом
    case SB_AUTO_CLICK: {Select6--; beeper(); if (Select6<0){Select6=50;}}                  //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,215,35,18,TFT_BLACK); tft.drawNumber(Select6,420,215,1); break;}}      //выводим значение "TFan Off" красным цветом
  if (place==7){tft.setTextColor(TFT_SILVER); tft.drawString("06. TFan Off",25,215,1);      //восстанавливаем цвет надписи "TFan Off"
    tft.drawString("0 ... 50C",195,215,1); tft.drawRect(20,207,440,33,TFT_BLACK);           //зарисовываем рамку "TFan Off"
    tft.setTextColor(TFT_RED); tft.drawString("07. TFan On",25,248,1);                      //выводим надпись "TFan On" красным цветом
    tft.drawString("0 ... 50C",195,248,1);                                                  //выводим пределы регулирования "0...50C"
    tft.drawRect(20,240,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select7++; beeper(); if (Select7>50){Select7=0;}}                       //увеличиваем выбранное значение на единицу
    tft.fillRect(420,248,35,18,TFT_BLACK); tft.drawNumber(Select7,420,248,1); break;        //выводим значение "TFan On" красным цветом
    case SB_AUTO_CLICK: {Select7++; beeper(); if (Select7>50){Select7=0;}}                  //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,248,35,18,TFT_BLACK); tft.drawNumber(Select7,420,248,1); break;}       //выводим значение "TFan On" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select7--; beeper(); if (Select7<0){Select7=50;}}                       //уменьшаем выбранное значение на единицу
    tft.fillRect(420,248,35,18,TFT_BLACK); tft.drawNumber(Select7,420,248,1); break;        //выводим значение "TFan On" красным цветом
    case SB_AUTO_CLICK: {Select7--; beeper(); if (Select7<0){Select7=50;}}                  //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,248,35,18,TFT_BLACK); tft.drawNumber(Select7,420,248,1); break;}}      //выводим значение "TFan On" красным цветом
  if (place==8){tft.setTextColor(TFT_SILVER); tft.drawString("07. TFan On",25,248,1);       //восстанавливаем цвет надписи "TFan On"
    tft.drawString("0 ... 50C",195,248,1); tft.drawRect(20,240,440,33,TFT_BLACK);           //зарисовываем рамку "TFan On"
    tft.setTextColor(TFT_RED); tft.drawString("08. TFan Max",25,281,1);                     //выводим надпись "TFan Max" красным цветом
    tft.drawString("0 ... 75C",195,281,1);                                                  //выводим пределы регулирования "0...75C"
    tft.drawRect(20,273,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select8++; beeper(); if (Select8>75){Select8=0;}}                       //увеличиваем выбранное значение на единицу
    tft.fillRect(420,281,35,18,TFT_BLACK); tft.drawNumber(Select8,420,281,1); break;        //выводим значение "TFan Max" красным цветом
    case SB_AUTO_CLICK: {Select8++; beeper(); if (Select8>75){Select8=0;}}                  //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,281,35,18,TFT_BLACK); tft.drawNumber(Select8,420,281,1); break;}       //выводим значение "TFan Max" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select8--; beeper(); if (Select8<0){Select8=75;}}                       //уменьшаем выбранное значение на единицу
    tft.fillRect(420,281,35,18,TFT_BLACK); tft.drawNumber(Select8,420,281,1); break;        //выводим значение "TFan Max" красным цветом
    case SB_AUTO_CLICK: {Select8--; beeper(); if (Select8<0){Select8=75;}}                  //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,281,35,18,TFT_BLACK); tft.drawNumber(Select8,420,281,1); break;}}      //выводим значение "TFan Max" красным цветом
} if ((place==9)||(place==10)){EEPROM.update(10,Select1); EEPROM.update(11,Select2);        //если place=9
    EEPROM.update(12,Select3); EEPROM.update(13,Select4); EEPROM.update(14,Select5);        //и старые значения ячеек отличаются от новых
    EEPROM.update(15,Select6); EEPROM.update(16,Select7); EEPROM.update(17,Select8);        //заменяем их содержимое в EEPROM и переходим на вторую страницу
  if (place==10){place=25; goto M1;}}                                                       //и переходим на четвёртую страницу по метке М1

p2: tft.fillScreen(TFT_GREY60);                                                             //заливаем экран серым цветом
  for(0,2){                                                                                 //включаем цикл
    tft.drawRect(0+i,0+i,480-i*2,320-i*2,BORDER);                                           //рисуем наружную окантовку
    tft.drawRoundRect(6+i,6+i,468-i*2,308-i*2,8-i,BORDER);}                                 //рисуем внутреннюю окантовку с закруглёнными углами
    tft.fillRoundRect(8,8,464,304,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
    tft.setFreeFont(FSSB9); tft.setTextColor(BORDER);                                       //выбираем шрифт и цвет текста
    tft.drawString("page 2",25,20,1);                                                       //выводим надпись "page 2"
    tft.setFreeFont(FSBI12);                                                                //выбираем шрифт
    tft.drawCentreString("-- MENU --",240,20,1);                                            //выводим надпись "-- MENU --"
    tft.setTextColor(TFT_SILVER);                                                           //выбираем цвет текста
    tft.drawString("09. ATT Off",25,50,1);                                                  //выводим надпись "09. ATT Off"
    tft.drawString("10. ATT -3dB",25,83,1);                                                 //выводим надпись "10. ATT -3dB"
    tft.drawString("11. ATT -6dB",25,116,1);                                                //выводим надпись "11. ATT -6dB"
    tft.drawString("12. ATT AUTO",25,149,1);                                                //выводим надпись "12. ATT AUTO"
    tft.drawString("13. ATT alarm",25,182,1);                                               //выводим надпись "13. ATT alarm"
    tft.drawString("14. SWR max",25,215,1);                                                 //выводим надпись "14. SWR max"
    tft.drawString("15. Tone beep",25,248,1);                                               //выводим надпись "15. Tone beep"
    tft.drawString("16. Beeper",25,281,1);                                                  //выводим надпись "16. Beeper"
    tft.drawString("0 ... 30W",195,50,1);                                                   //выводим пределы регулирования "0...30W"
    tft.drawString("0 ... 30W",195,83,1);                                                   //выводим пределы регулирования "0...30W"
    tft.drawString("0 ... 30W",195,116,1);                                                  //выводим пределы регулирования "0...30W"
    tft.drawString("0 ... 30W",195,149,1);                                                  //выводим пределы регулирования "0...30W"
    tft.drawString("0 ... 30W",195,182,1);                                                  //выводим пределы регулирования "0...30W"
    tft.drawString("1.2 ... 9.90",177,215,1);                                               //выводим пределы регулирования "1.2...9.90"
    tft.drawString("100 ... 3000Hz",171,248,1);                                             //выводим пределы регулирования "100...3000Hz"
    tft.drawString("ON / OFF",189,281,1);                                                   //выводим надпись "ON/OFF"
    tft.drawNumber(Select9,420,50,1);                                                       //выводим редактируемое значение "ATT Off"
    tft.drawNumber(Select10,420,83,1);                                                      //выводим редактируемое значение "ATT -3dB"
    tft.drawNumber(Select11,420,116,1);                                                     //выводим редактируемое значение "ATT -6dB"
    tft.drawNumber(Select12,420,149,1);                                                     //выводим редактируемое значение "ATT AUTO"
    tft.drawNumber(Select13,420,182,1);                                                     //выводим редактируемое значение "ATT alarm"
    dtostrf(Select14,len,1,buf); tft.drawCentreString(buf,425,215,1);                       //выводим по центру редактируемое значение "SWR max"
  if (Select15!=0){dtostrf(Select15*100,len,0,buf); tft.drawCentreString(buf,425,248,1);}   //если "Select15!=0" выводим по центру редактируемое значение "Tone beep" умноженное на 100
  if (Select15==0){tft.drawCentreString("OFF",425,248,1);}                                  //если "Select15==0" выводим "OFF"
  if (Select16==1){tft.drawCentreString("ON",430,281,1);                                    //если значение ячейки 4 EEPROM "1" выводим по центру редактируемую надпись "ON"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("ON",360,281,1);}                    //при загрузке второй страницы меню выводим по центру текущую надпись "ON"
  if (Select16==0){tft.setTextColor(TFT_SILVER); tft.drawCentreString("OFF",430,281,1);     //если значение ячейки 4 EEPROM "0" выводим по центру редактируемую надпись "OFF"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("OFF",360,281,1);}                   //при загрузке второй страницы меню выводим по центру текущую надпись "OFF"
    tft.drawNumber(Select9,350,50,1);                                                       //выводим текущее значение "ATT Off"
    tft.drawNumber(Select10,350,83,1);                                                      //выводим текущее значение "ATT -3dB"
    tft.drawNumber(Select11,350,116,1);                                                     //выводим текущее значение "ATT -6dB"
    tft.drawNumber(Select12,350,149,1);                                                     //выводим текущее значение "ATT AUTO"
    tft.drawNumber(Select13,350,182,1);                                                     //выводим текущее значение "ATT alarm"
    dtostrf(Select14,len,1,buf); tft.drawCentreString(buf,355,215,1);                       //выводим по центру текущее значение "SWR max"
  if (Select15!=0){dtostrf(Select15*100,len,0,buf); tft.drawCentreString(buf,355,248,1);}   //если "Select15!=0" выводим по центру текущее значение "Tone beep" умноженное на 100
  if (Select15==0){tft.drawCentreString("OFF",355,248,1);}                                  //если "Select15==0" выводим "OFF"
  while (place<17){                                                                         //находимся на второй странице пока place<17
  switch(button1.Loop()){                                                                   //описываем работу кнопки "BYPASS/POWER ON"
    case SB_CLICK: beeper(); place=18; break;                                               //коротким нажатием по метке M1 переходим на первую страницу
    case SB_LONG_CLICK: beeper(); goto M2; break;}                                          //длинным нажатием по метке M2 выходим из меню
  switch(button2.Loop()){                                                                   //кнопкой "Band/Protocol" переключаем редактируемые параметры
    case SB_CLICK: place++; beeper(); if (place>16){place=9;} break;                        //коротким нажатием по одному параметру по кольцу
    case SB_LONG_CLICK: place=17; beeper(); break;}                                         //длинным нажатием переходим на третью страницу
  
  if (place==9){tft.setTextColor(TFT_SILVER); tft.drawString("16. Beeper",25,281,1);        //восстанавливаем цвет надписи "16. Beeper"
    tft.drawString("ON / OFF",189,281,1); tft.drawRect(20,273,440,33,TFT_BLACK);            //зарисовываем рамку "Beeper"
    tft.setTextColor(TFT_RED); tft.drawString("09. ATT Off",25,50,1);                       //выводим надпись "ATT Off" красным цветом
    tft.drawString("0 ... 30W",195,50,1);                                                   //выводим пределы регулирования "0...30W"
    tft.drawRect(20,42,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                       //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "ATT Off" коротким нажатием
    case SB_CLICK: {Select9++; beeper(); if (Select9>30){Select9=0;}}                       //увеличиваем выбранное значение на единицу
    tft.fillRect(420,50,35,18,TFT_BLACK); tft.drawNumber(Select9,420,50,1); break;          //выводим значение "ATT Off" красным цветом
    case SB_AUTO_CLICK: {Select9++; beeper(); if (Select9>30){Select9=0;}}                  //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,50,35,18,TFT_BLACK); tft.drawNumber(Select9,420,50,1); break;}         //выводим значение "ATT Off" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select9--; beeper(); if (Select9<0){Select9=30;}}                       //уменьшаем выбранное значение на единицу
    tft.fillRect(420,50,35,18,TFT_BLACK); tft.drawNumber(Select9,420,50,1); break;          //выводим значение "ATT Off" красным цветом
    case SB_AUTO_CLICK: {Select9--; beeper(); if (Select9<0){Select9=30;}}                  //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,50,35,18,TFT_BLACK); tft.drawNumber(Select9,420,50,1); break;}}        //выводим значение "ATT Off" красным цветом
  
  if (place==10){tft.setTextColor(TFT_SILVER); tft.drawString("09. ATT Off",25,50,1);       //восстанавливаем цвет надписи "ATT Off"
    tft.drawString("0 ... 30W",195,50,1); tft.drawRect(20,42,440,33,TFT_BLACK);             //зарисовываем рамку "ATT Off"
    tft.setTextColor(TFT_RED); tft.drawString("10. ATT -3dB",25,83,1);                      //выводим надпись "ATT -3dB" красным цветом
    tft.drawString("0 ... 30W",195,83,1);                                                   //выводим пределы регулирования "0...30W"
    tft.drawRect(20,75,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                       //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select10++; beeper(); if (Select10>30){Select10=0;}}                    //увеличиваем выбранное значение на единицу
    tft.fillRect(420,83,37,18,TFT_BLACK); tft.drawNumber(Select10,420,83,1); break;         //выводим значение "ATT -3dB" красным цветом
    case SB_AUTO_CLICK: {Select10++; beeper(); if (Select10>30){Select10=0;}}               //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,83,37,18,TFT_BLACK); tft.drawNumber(Select10,420,83,1); break;}        //выводим значение "ATT -3dB" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select10--; beeper(); if (Select10<0){Select10=30;}}                    //уменьшаем выбранное значение на единицу
    tft.fillRect(420,83,37,18,TFT_BLACK); tft.drawNumber(Select10,420,83,1); break;         //выводим значение "ATT -3dB" красным цветом
    case SB_AUTO_CLICK: {Select10--; beeper(); if (Select10<0){Select10=30;}}               //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,83,37,18,TFT_BLACK); tft.drawNumber(Select10,420,83,1); break;}}       //выводим значение "ATT -3dB" красным цветом
  
  if (place==11){tft.setTextColor(TFT_SILVER); tft.drawString("10. ATT -3dB",25,83,1);      //восстанавливаем цвет надписи "ATT -3dB"
    tft.drawString("0 ... 30W",195,83,1); tft.drawRect(20,75,440,33,TFT_BLACK);             //зарисовываем рамку "ATT -3dB"
    tft.setTextColor(TFT_RED); tft.drawString("11. ATT -6dB",25,116,1);                     //выводим надпись "ATT -6dB" красным цветом
    tft.drawString("0 ... 30W",195,116,1);                                                  //выводим пределы регулирования "0...30W"
    tft.drawRect(20,108,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select11++; beeper(); if (Select11>30){Select11=0;}}                    //увеличиваем выбранное значение на единицу
    tft.fillRect(420,116,35,18,TFT_BLACK); tft.drawNumber(Select11,420,116,1); break;       //выводим значение "ATT -6dB" красным цветом
    case SB_AUTO_CLICK: {Select11++; beeper(); if (Select11>30){Select11=0;}}               //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,116,35,18,TFT_BLACK); tft.drawNumber(Select11,420,116,1); break;}      //выводим значение "ATT -6dB" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select11--; beeper(); if (Select11<0){Select11=30;}}                    //уменьшаем выбранное значение на единицу
    tft.fillRect(420,116,35,18,TFT_BLACK); tft.drawNumber(Select11,420,116,1); break;       //выводим значение "ATT -6dB" красным цветом
    case SB_AUTO_CLICK: {Select11--; beeper(); if (Select11<0){Select11=30;}}               //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,116,35,18,TFT_BLACK); tft.drawNumber(Select11,420,116,1); break;}}     //выводим значение "ATT -6dB" красным цветом
  
  if (place==12){tft.setTextColor(TFT_SILVER); tft.drawString("11. ATT -6dB",25,116,1);     //восстанавливаем цвет надписи "11. ATT -6dB"
    tft.drawString("0 ... 30W",195,116,1); tft.drawRect(20,108,440,33,TFT_BLACK);           //зарисовываем рамку "ATT -6dB"
    tft.setTextColor(TFT_RED); tft.drawString("12. ATT AUTO",25,149,1);                     //выводим надпись "12. ATT AUTO" красным цветом
    tft.drawString("0 ... 30W",195,149,1);                                                  //выводим пределы регулирования "0...30W"
    tft.drawRect(20,141,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select12++; beeper(); if (Select12>30){Select12=0;}}                    //увеличиваем выбранное значение на единицу
    tft.fillRect(420,149,35,18,TFT_BLACK); tft.drawNumber(Select12,420,149,1); break;       //выводим значение "ATT AUTO" красным цветом
    case SB_AUTO_CLICK: {Select12++; beeper(); if (Select12>30){Select12=0;}}               //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,149,35,18,TFT_BLACK); tft.drawNumber(Select12,420,149,1); break;}      //выводим значение "ATT AUTO" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select12--; beeper(); if (Select12<0){Select12=30;}}                    //уменьшаем выбранное значение на единицу
    tft.fillRect(420,149,35,18,TFT_BLACK); tft.drawNumber(Select12,420,149,1); break;       //выводим значение "ATT AUTO" красным цветом
    case SB_AUTO_CLICK: {Select12--; beeper(); if (Select12<0){Select12=30;}}               //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,149,35,18,TFT_BLACK); tft.drawNumber(Select12,420,149,1); break;}}     //выводим значение "ATT AUTO" красным цветом
  
  if (place==13){tft.setTextColor(TFT_SILVER); tft.drawString("12. ATT AUTO",25,149,1);     //восстанавливаем цвет надписи "12. ATT AUTO"
    tft.drawString("0 ... 30W",195,149,1); tft.drawRect(20,141,440,33,TFT_BLACK);           //зарисовываем рамку "ATT AUTO"
    tft.setTextColor(TFT_RED); tft.drawString("13. ATT alarm",25,182,1);                    //выводим надпись "13. ATT alarm" красным цветом
    tft.drawString("0 ... 30W",195,182,1);                                                  //выводим пределы регулирования "0...30W"
    tft.drawRect(20,174,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select13++; beeper(); if (Select13>30){Select13=0;}}                    //увеличиваем выбранное значение на единицу
    tft.fillRect(420,182,35,18,TFT_BLACK); tft.drawNumber(Select13,420,182,1); break;       //выводим значение "ATT alarm" красным цветом
    case SB_AUTO_CLICK: {Select13++; beeper(); if (Select13>30){Select13=0;}}               //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(420,182,35,18,TFT_BLACK); tft.drawNumber(Select13,420,182,1); break;}      //выводим значение "ATT alarm" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select13--; beeper(); if (Select13<0){Select13=30;}}                    //уменьшаем выбранное значение на единицу
    tft.fillRect(420,182,35,18,TFT_BLACK); tft.drawNumber(Select13,420,182,1); break;       //выводим значение "ATT alarm" красным цветом
    case SB_AUTO_CLICK: {Select13--; beeper(); if (Select13<0){Select13=30;}}               //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(420,182,35,18,TFT_BLACK); tft.drawNumber(Select13,420,182,1); break;}}     //выводим значение "ATT alarm" красным цветом
  
  if (place==14){tft.setTextColor(TFT_SILVER); tft.drawString("13. ATT alarm",25,182,1);    //восстанавливаем цвет надписи "13. ATT alarm"
    tft.drawString("0 ... 30W",195,182,1); tft.drawRect(20,174,440,33,TFT_BLACK);           //зарисовываем рамку "ATT alarm"
    tft.setTextColor(TFT_RED); tft.drawString("14. SWR max",25,215,1);                      //выводим надпись "14. SWR max" красным цветом
    tft.drawString("1.2 ... 9.90",177,215,1);                                               //выводим пределы регулирования "1.2...9.90"
    tft.drawRect(20,207,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select14=Select14+0.1; beeper(); if (Select14>9.9){Select14=1.2;}}      //увеличиваем выбранное значение на одну десятую
    tft.fillRect(410,215,37,18,TFT_BLACK); dtostrf(Select14,len,1,buf);                     //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,215,1); break;                                             //выводим значение "SWR max" красным цветом
    case SB_AUTO_CLICK: {Select14=Select14+0.1; beeper();if (Select14>9.9){Select14=1.2;}}  //длинным нажатием и удержанием увеличиваем на одну десятую в авто переключении
    tft.fillRect(410,215,37,18,TFT_BLACK); dtostrf(Select14,len,1,buf);                     //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,215,1); break;}                                            //выводим значение "SWR max" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select14=Select14-0.1; beeper(); if (Select14<1.2){Select14=9.9;}}      //уменьшаем выбранное значение на одну десятую
    tft.fillRect(410,215,37,18,TFT_BLACK); dtostrf(Select14,len,1,buf);                     //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,215,1); break;                                             //выводим значение "SWR max" красным цветом
    case SB_AUTO_CLICK: {Select14=Select14-0.1; beeper();if (Select14<1.2){Select14=9.9;}}  //длинным нажатием и удержанием уменьшаем на одну десятую в авто переключении
    tft.fillRect(410,215,37,18,TFT_BLACK); dtostrf(Select14,len,1,buf);                     //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,215,1); break;}}                                           //выводим значение "SWR max" красным цветом
  
  if (place==15){tft.setTextColor(TFT_SILVER); tft.drawString("14. SWR max",25,215,1);      //восстанавливаем цвет надписи "13. SWR max"
    tft.drawString("1.2 ... 9.90",177,215,1); tft.drawRect(20,207,440,33,TFT_BLACK);        //зарисовываем рамку "SWR max"
    tft.setTextColor(TFT_RED); tft.drawString("15. Tone beep",25,248,1);                    //выводим надпись "15. Tone beep" красным цветом
    tft.drawString("100 ... 3000Hz",171,248,1);                                             //выводим пределы регулирования "100...3000Hz"
    tft.drawRect(20,240,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select15++; beeper(); if (Select15>30){Select15=0;}}                    //увеличиваем выбранное значение на единицу
  if (Select15==0){tft.fillRect(402,248,49,18,TFT_BLACK);                                   //если "Select15==0" затираем предыдущую надпись
    tft.drawCentreString("OFF",425,248,1);}                                                 //и выводим "OFF"
  if (Select15!=0){Tonbeep=Select15; tone4.tone(Tonbeep*100); delay(50); tone4.noTone();    //если "Select15!=0" изменение сразу выводится на пьезо излучатель
    tft.fillRect(402,248,49,18,TFT_BLACK); dtostrf(Select15*100,len,0,buf);                 //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,248,1);} break;                                            //выводим по центру значение "Tone beep" красным цветом умноженное на 100
    case SB_AUTO_CLICK: {Select15++; beeper(); if (Select15>30){Select15=1;}}               //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
  if (Select15!=0){Tonbeep=Select15; tone4.tone(Tonbeep*100); delay(50); tone4.noTone();}   //изменение сразу выводится на пьезо излучатель
    tft.fillRect(402,248,49,18,TFT_BLACK); dtostrf(Select15*100,len,0,buf);                 //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,248,1); break;}                                            //выводим по центру значение "Tone beep" красным цветом умноженное на 100
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select15--; beeper(); if (Select15<0){Select15=30;}}                    //уменьшаем выбранное значение на единицу
  if (Select15==0){tft.fillRect(402,248,49,18,TFT_BLACK);                                   //если "Select15==0" затираем предыдущую надпись
    tft.drawCentreString("OFF",425,248,1);}                                                 //и выводим "OFF"
  if (Select15!=0){Tonbeep=Select15; tone4.tone(Tonbeep*100); delay(50); tone4.noTone();    //если "Select15!=0" изменение сразу выводится на пьезо излучатель
    tft.fillRect(402,248,49,18,TFT_BLACK); dtostrf(Select15*100,len,0,buf);                 //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,248,1);} break;                                            //выводим по центру значение "Tone beep" красным цветом умноженное на 100
    case SB_AUTO_CLICK: {Select15--; beeper(); if (Select15<1){Select15=30;}}               //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
  if (Select15!=0){Tonbeep=Select15; tone4.tone(Tonbeep*100); delay(50); tone4.noTone();}   //изменение сразу выводится на пьезо излучатель
    tft.fillRect(402,248,49,18,TFT_BLACK); dtostrf(Select15*100,len,0,buf);                 //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,248,1); break;}}                                           //выводим по центру значение "Tone beep" красным цветом умноженное на 100
  
  if (place==16){tft.setTextColor(TFT_SILVER); tft.drawString("15. Tone beep",25,248,1);    //восстанавливаем цвет надписи "15. Tone beep"
    tft.drawString("100 ... 3000Hz",171,248,1); tft.drawRect(20,240,440,33,TFT_BLACK);      //зарисовываем рамку "Tone beep"
    tft.setTextColor(TFT_RED); tft.drawString("16. Beeper",25,281,1);                       //выводим надпись "16. Beeper" красным цветом
    tft.drawString("ON / OFF",189,281,1);                                                   //выводим пределы переключения "ON/OFF"
    tft.drawRect(20,273,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" короткими нажатиями
    case SB_CLICK: {Select16++; beeper(); if (Select16>1){Select16=0;}}                     //переключаем включенные режимы "Beeper"(ON/OFF)
  if (Select16==1){beep=1;                                                                  //если "Beeper" включен beep=1
    tft.fillRect(406,281,49,18,TFT_BLACK); tft.drawCentreString("ON",430,281,1); break;}    //выводим "ON"
  if (Select16==0){beep=0;                                                                  //если "Beeper" выключен beep=0
    tft.fillRect(406,281,49,18,TFT_BLACK); tft.drawCentreString("OFF",430,281,1); break;}}  //выводим "OFF"
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" короткими нажатиями
    case SB_CLICK: {Select16++; beeper(); if (Select16>1){Select16=0;}}                     //переключаем включенные режимы "Beeper"(ON/OFF)
  if (Select16==1){beep=1;                                                                  //если "Beeper" включен beep=1
    tft.fillRect(406,281,49,18,TFT_BLACK); tft.drawCentreString("ON",430,281,1); break;}    //выводим  "ON"
  if (Select16==0){beep=0;                                                                  //если "Beeper" выключен beep=0
    tft.fillRect(406,281,49,18,TFT_BLACK); tft.drawCentreString("OFF",430,281,1);break;}}}  //выводим "OFF"
} if ((place==17)||(place==18)){EEPROM.update(20, Select9); EEPROM.update(21,Select10);     //если place=17
    EEPROM.update(22,Select11); EEPROM.update(23,Select12); EEPROM.update(24,Select13);     //и старые значения ячеек отличаются от новых
    EEPROM.put   (27,Select14); EEPROM.update(26,Select15); EEPROM.update( 4,Select16);     //заменяем их содержимое в EEPROM и переходим на третью страницу
  if (place==18){place=1; goto M1;}}                                                        //переходим на первую страницу по метке М1

p3: tft.fillRoundRect(8,8,464,304,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
    tft.setFreeFont(FSSB9); tft.setTextColor(BORDER);                                       //выбираем шрифт и цвет текста
    tft.drawString("page 3",25,20,1);                                                       //выводим надпись "page 3"
    tft.setFreeFont(FSBI12);                                                                //выбираем шрифт
    tft.drawCentreString("-- MENU --",240,20,1);                                            //выводим надпись "-- MENU --"
    tft.setTextColor(TFT_SILVER);                                                           //выбираем цвет текста
    tft.drawString("17. Time Beep",25,50,1);                                                //выводим надпись "17. Time Beep"
    tft.drawString("18. Band Delay",25,83,1);                                               //выводим надпись "18. Band Delay"
    tft.drawString("19. U divider",25,116,1);                                               //выводим надпись "19. U divider"
    tft.drawString("20. RefreshTime",25,149,1);                                             //выводим надпись "20. RefreshTime"
    tft.drawString("21. ACS7XX",25,182,1);                                                  //выводим надпись "21. ACS7XX"
    tft.drawString("22. Length",25,215,1);                                                  //выводим надпись "22. Length"
    tft.drawString("23. Scale OUT",25,248,1);                                               //выводим надпись "23. Scale OUT"
    tft.drawString("24. The color of the border",25,281,1);                                 //выводим надпись "24. Border"
    tft.drawString("ON / OFF",199,50,1);                                                    //выводим надпись "ON/OFF"
    tft.drawString("1 ... 20",210,83,1);                                                    //выводим пределы регулирования "10...250"
    tft.drawString("9.00k ... 11.00k",169,116,1);                                           //выводим пределы регулирования "9.00k ... 11.00k"
    tft.drawString("2 ... 50",210,149,1);                                                   //выводим пределы регулирования "2 ... 50"
    tft.drawString("20/30/50/100A",169,182,1);                                              //выводим надпись "20/30/50/100A"
    tft.drawString("Short/Long",194,215,1);                                                 //выводим надпись "Short/Long"
    tft.drawString("250/500/1/2",190,248,1);                                                //выводим надпись "250/500/1/2"
    tft.drawNumber(Select18,420,83,1);                                                      //выводим редактируемое значение "BandDelay"
    dtostrf(Select19,len,2,buf); tft.drawCentreString(buf,425,116,1);                       //выводим по центру редактируемое значение "divider"
    tft.drawNumber(Select20,415,149,1);                                                     //выводим редактируемое значение "RefreshTime"
  if (Select17==1){tft.setTextColor(TFT_SILVER); tft.drawCentreString("ON",430,50,1);       //если значение ячейки 4 EEPROM "2" выводим по центру редактируемую надпись "ON"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("ON",360,50,1);}                     //при загрузке третьей страницы меню выводим по центру текущую надпись "ON"
  if (Select17==0){tft.setTextColor(TFT_SILVER); tft.drawCentreString("OFF",430,50,1);      //если значение ячейки 4 EEPROM "1" выводим по центру редактируемую надпись "OFF"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("OFF",360,50,1);}                    //при загрузке третьей страницы меню выводим по центру текущую надпись "OFF"
  if (Select21==1){tft.setTextColor(TFT_SILVER); tft.drawCentreString("20A",430,182,1);     //если значение ячейки 4 EEPROM "2" выводим по центру редактируемую надпись "20A"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("20A",360,182,1);}                   //при загрузке третьей страницы меню выводим по центру текущую надпись "20A"
  if (Select21==2){tft.setTextColor(TFT_SILVER); tft.drawCentreString("30A",430,182,1);     //если значение ячейки 4 EEPROM "1" выводим по центру редактируемую надпись "30A"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("30A",360,182,1);}                   //при загрузке третьей страницы меню выводим по центру текущую надпись "30A"
  if (Select21==3){tft.setTextColor(TFT_SILVER); tft.drawCentreString("50A",430,182,1);     //если значение ячейки 4 EEPROM "1" выводим по центру редактируемую надпись "50A"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("50A",360,182,1);}                   //при загрузке третьей страницы меню выводим по центру текущую надпись "50A"
  if (Select21==4){tft.setTextColor(TFT_SILVER); tft.drawCentreString("100A",430,182,1);    //если значение ячейки 4 EEPROM "1" выводим по центру редактируемую надпись "100A"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("100A",360,182,1);}                  //при загрузке третьей страницы меню выводим по центру текущую надпись "100A"
  if (Select22==0){tft.setTextColor(TFT_SILVER); tft.drawCentreString("Short",430,215,1);   //если значение ячейки 4 EEPROM "2" выводим по центру редактируемую надпись "Short"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("Short",360,215,1);}                 //при загрузке третьей страницы меню выводим по центру текущую надпись "Short"
  if (Select22==1){tft.setTextColor(TFT_SILVER); tft.drawCentreString("Long",430,215,1);    //если значение ячейки 4 EEPROM "1" выводим по центру редактируемую надпись "Long"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("Long",360,215,1);}                  //при загрузке третьей страницы меню выводим по центру текущую надпись "Long"
  if (Select23==1){tft.setTextColor(TFT_SILVER); tft.drawCentreString("250",430,248,1);     //если значение ячейки 35 EEPROM "1" выводим по центру редактируемую надпись "250"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("250",360,248,1);}                   //при загрузке третьей страницы меню выводим по центру текущую надпись "250"
  if (Select23==2){tft.setTextColor(TFT_SILVER); tft.drawCentreString("500",430,248,1);     //если значение ячейки 35 EEPROM "2" выводим по центру редактируемую надпись "500"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("500",360,248,1);}                   //при загрузке третьей страницы меню выводим по центру текущую надпись "500"
  if (Select23==3){tft.setTextColor(TFT_SILVER); tft.drawCentreString("1.0",430,248,1);     //если значение ячейки 35 EEPROM "3" выводим по центру редактируемую надпись "1.0"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("1.0",360,248,1);}                   //при загрузке третьей страницы меню выводим по центру текущую надпись "1.0"
  if (Select23==4){tft.setTextColor(TFT_SILVER); tft.drawCentreString("2.0",430,248,1);     //если значение ячейки 35 EEPROM "4" выводим по центру редактируемую надпись "2.0"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("2.0",360,248,1);}                   //при загрузке третьей страницы меню выводим по центру текущую надпись "2.0"
  if (Select24==5){tft.setTextColor(TFT_CYAN); tft.drawCentreString("CYAN",425,281,1);      //если значение ячейки 38 EEPROM "3" выводим по центру редактируемую надпись "CYAN"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("CYAN",355,281,1);}                  //при загрузке четвёртой страницы меню выводим по центру текущую надпись "CYAN"
  if (Select24==4){tft.setTextColor(TFT_ORANGE); tft.drawCentreString("ORG",425,281,1);     //если значение ячейки 38 EEPROM "3" выводим по центру редактируемую надпись "ORG"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("ORG",355,281,1);}                   //при загрузке четвёртой страницы меню выводим по центру текущую надпись "ORG"
  if (Select24==3){tft.setTextColor(TFT_PINK); tft.drawCentreString("PINK",425,281,1);      //если значение ячейки 36 EEPROM "3" выводим по центру редактируемую надпись "PINK"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("PINK",355,281,1);}                  //при загрузке третьей страницы меню выводим по центру текущую надпись "PINK"
  if (Select24==2){tft.setTextColor(TFT_SILVER); tft.drawCentreString("SIL",425,281,1);     //если значение ячейки 36 EEPROM "2" выводим по центру редактируемую надпись "SIL"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("SIL",355,281,1);}                   //при загрузке третьей страницы меню выводим по центру текущую надпись "SIL"
  if (Select24==1){tft.setTextColor(TFT_GREEN); tft.drawCentreString("GRN",425,281,1);      //если значение ячейки 36 EEPROM "1" выводим по центру редактируемую надпись "GRN"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("GRN",355,281,1);}                   //при загрузке первой страницы меню выводим по центру текущую надпись "GRN"
    tft.drawNumber(Select18,350,83,1);                                                      //выводим текущее значение "BandDelay"
    dtostrf(Select19,len,2,buf); tft.drawCentreString(buf,355,116,1);                       //выводим по центру текущее значение "divider"
    tft.drawNumber(Select20,345,149,1);                                                     //выводим текущее значение "RefreshTime"
  while (place<25){                                                                         //находимся на третьей странице пока "place<25"
  switch(button1.Loop()){                                                                   //описываем работу кнопки "BYPASS/POWER ON"
    case SB_CLICK: beeper(); place=26; break;                                               //коротким нажатием по метке p2 переходим на вторую страницу
    case SB_LONG_CLICK: beeper(); goto M2; break;}                                          //длинным нажатием по метке M2 выходим из меню
  switch(button2.Loop()){                                                                   //кнопкой "Band/Protocol" переключаем редактируемые параметры
    case SB_CLICK: place++; beeper(); if (place>24){place=17;} break;                       //коротким нажатием по одному параметру по кольцу
    case SB_LONG_CLICK: place=25; beeper(); break;}                                         //длинным нажатием переходим на четвёртую страницу
  
  if (place==17){tft.setTextColor(TFT_SILVER); tft.drawRect(20,273,440,33,TFT_BLACK);       //зарисовываем рамку "Border"
    tft.drawString("24. The color of the border",25,281,1);                                 //восстанавливаем цвет надписи "24. The color of the border"
    tft.setTextColor(TFT_RED); tft.drawString("17. Time Beep",25,50,1);                     //выводим надпись "17. Time Beep" красным цветом
    tft.drawString("ON / OFF",199,50,1);                                                    //выводим пределы переключения "ON/OFF"
    tft.drawRect(20,42,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                       //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" короткими нажатиями
    case SB_CLICK: {Select17++; beeper(); if (Select17>1){Select17=0;}}                     //переключаем включенные режимы "Time Beep"(ON/OFF)
  if (Select17==1){ TimeBeep=1;                                                             //если "Time Beep" включен TimeBeep=1
    tft.fillRect(406,50,49,18,TFT_BLACK); tft.drawCentreString("ON",430,50,1); break;}      //выводим "ON"
  if (Select17==0){ TimeBeep=0;                                                             //если "Time Beep" выключен TimeBeep=2
    tft.fillRect(406,50,49,18,TFT_BLACK); tft.drawCentreString("OFF",430,50,1); break;}}    //выводим "OFF"  
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" короткими нажатиями
    case SB_CLICK: {Select17++; beeper(); if (Select17>1) Select17=0;}                      //переключаем включенные режимы "Time Beep"(ON/OFF)
  if (Select17==1){ TimeBeep=1;                                                             //если "Time Beep" включен TimeBeep=1
    tft.fillRect(406,50,49,18,TFT_BLACK); tft.drawCentreString("ON",430,50,1); break;}      //выводим  "ON"
  if (Select17==0){ TimeBeep=0;                                                             //если "Time Beep" выключен TimeBeep=2
    tft.fillRect(406,50,49,18,TFT_BLACK); tft.drawCentreString("OFF",430,50,1);break;}}}    //выводим "OFF"
  
  if (place==18){tft.setTextColor(TFT_SILVER); tft.drawString("17. Time Beep",25,50,1);     //восстанавливаем цвет надписи "17. Time Beep"
    tft.drawString("ON / OFF",199,50,1); tft.drawRect(20,42,440,33,TFT_BLACK);              //зарисовываем рамку "VOX Delay"
    tft.setTextColor(TFT_RED); tft.drawString("18. Band Delay",25,83,1);                    //выводим надпись "Band Delay" красным цветом
    tft.drawString("1 ... 20",210,83,1);                                                    //выводим пределы регулирования "1 ... 20"
    tft.drawRect(20,75,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                       //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select18+=1; beeper(); if (Select18>20){Select18=1;}}                   //увеличиваем выбранное значение на десять
    tft.fillRect(402,83,49,18,TFT_BLACK); tft.drawNumber(Select18,420,83,1); break;         //выводим значение "BandDelay" красным цветом
    case SB_AUTO_CLICK: {Select18+=1; beeper(); if (Select18>20){Select18=1;}}              //длинным нажатием и удержанием увеличиваем на десять в авто переключении
    tft.fillRect(402,83,49,18,TFT_BLACK); tft.drawNumber(Select18,420,83,1); break;}        //выводим значение "BandDelay" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select18-=1; beeper(); if (Select18<1){Select18=20;}}                   //уменьшаем выбранное значение на десять
    tft.fillRect(402,83,49,18,TFT_BLACK); tft.drawNumber(Select18,420,83,1); break;         //выводим значение "BandDelay" красным цветом
    case SB_AUTO_CLICK: {Select18-=1; beeper(); if (Select18<1){Select18=20;}}              //длинным нажатием и удержанием уменьшаем на десять в авто переключении
    tft.fillRect(402,83,49,18,TFT_BLACK); tft.drawNumber(Select18,420,83,1); break;}}       //выводим значение "BandDelay" красным цветом
  
  if (place==19){tft.setTextColor(TFT_SILVER); tft.drawString("18. Band Delay",25,83,1);    //восстанавливаем цвет надписи "18. Band Delay"
    tft.drawString("1 ... 20",210,83,1); tft.drawRect(20,75,440,33,TFT_BLACK);              //зарисовываем рамку "BandDelay"
    tft.setTextColor(TFT_RED); tft.drawString("19. U divider",25,116,1);                    //выводим надпись "19. U divider" красным цветом
    tft.drawString("9.00k ... 11.00k",169,116,1);                                           //выводим пределы регулирования "9.00k ... 11.00k"
    tft.drawRect(20,108,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select19=Select19+0.01; beeper(); if (Select19>11.00){Select19=9.00;}}  //увеличиваем выбранное значение на одну десятую
    tft.fillRect(398,116,55,18,TFT_BLACK); dtostrf(Select19,len,2,buf);                     //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,116,1); break;                                             //выводим значение "divider" красным цветом
    case SB_AUTO_CLICK:{Select19=Select19+0.01;beeper();if(Select19>11.00){Select19=9.00;}} //длинным нажатием и удержанием увеличиваем на одну десятую в авто переключении
    tft.fillRect(398,116,55,18,TFT_BLACK); dtostrf(Select19,len,2,buf);                     //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,116,1); break;}                                            //выводим значение "divider" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select19=Select19-0.01;beeper();if(Select19<9.00){Select19=11.00;}}     //уменьшаем выбранное значение на одну десятую
    tft.fillRect(398,116,55,18,TFT_BLACK); dtostrf(Select19,len,2,buf);                     //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,116,1); break;                                             //выводим значение "divider" красным цветом
    case SB_AUTO_CLICK:{Select19=Select19-0.01;beeper();if(Select19<9.00){Select19=11.00;}} //длинным нажатием и удержанием уменьшаем на одну десятую в авто переключении
    tft.fillRect(398,116,55,18,TFT_BLACK); dtostrf(Select19,len,2,buf);                     //конвертируем символьный массив вывода данных
    tft.drawCentreString(buf,425,116,1); break;}}                                           //выводим значение "divider" красным цветом
  
  if (place==20){tft.setTextColor(TFT_SILVER); tft.drawString("19. U divider",25,116,1);    //восстанавливаем цвет надписи "U divider"
    tft.drawString("9.00k ... 11.00k",169,116,1); tft.drawRect(20,108,440,33,TFT_BLACK);    //зарисовываем рамку "U divider"
    tft.setTextColor(TFT_RED); tft.drawString("20. RefreshTime",25,149,1);                  //выводим надпись "RefreshTime" красным цветом
    tft.drawString("2 ... 50",210,149,1);                                                   //выводим пределы регулирования "2 ... 50"
    tft.drawRect(20,141,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" коротким нажатием
    case SB_CLICK: {Select20++; beeper(); if (Select20>50){Select20=2;}}                    //увеличиваем выбранное значение на единицу
    tft.fillRect(410,149,35,18,TFT_BLACK); tft.drawNumber(Select20,415,149,1); break;       //выводим значение "RefreshTime" красным цветом
    case SB_AUTO_CLICK: {Select20++; beeper(); if (Select20>50){Select20=2;}}               //длинным нажатием и удержанием увеличиваем на единицу в авто переключении
    tft.fillRect(410,149,35,18,TFT_BLACK); tft.drawNumber(Select20,415,149,1); break;}      //выводим значение "RefreshTime" красным цветом
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" коротким нажатием
    case SB_CLICK: {Select20--; beeper(); if (Select20<2){Select20=50;}}                    //уменьшаем выбранное значение на единицу
    tft.fillRect(410,149,35,18,TFT_BLACK); tft.drawNumber(Select20,415,149,1); break;       //выводим значение "RefreshTime" красным цветом
    case SB_AUTO_CLICK: {Select20--; beeper(); if (Select20<2){Select20=50;}}               //длинным нажатием и удержанием уменьшаем на единицу в авто переключении
    tft.fillRect(410,149,35,18,TFT_BLACK); tft.drawNumber(Select20,415,149,1); break;}}     //выводим значение "RefreshTime" красным цветом
  
  if (place==21){tft.setTextColor(TFT_SILVER); tft.drawString("20. RefreshTime",25,149,1);  //восстанавливаем цвет надписи "RefreshTime"
    tft.drawString("2 ... 50",210,149,1); tft.drawRect(20,141,440,33,TFT_BLACK);            //зарисовываем рамку "RefreshTime"
    tft.setTextColor(TFT_RED); tft.drawString("21. ACS7XX",25,182,1);                       //выводим надпись "21. ACS7XX" красным цветом
    tft.drawString("20/30/50/100A",169,182,1);                                              //выводим пределы переключения "20/30/50/100A"
    tft.drawRect(20,174,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" короткими нажатиями
    case SB_CLICK: {Select21++; beeper(); if (Select21>4){Select21=1;}}                     //выбираем датчики "ACS7XX_20A", "ACS7XX_30A", "ACS7XX_50A", "ACS7XX_100A"
  if (Select21==1){ Acs=1;                                                                  //если переменная Acs=1 выбран датчик ACS7XX_20A
    tft.fillRect(406,182,49,18,TFT_BLACK); tft.drawCentreString("20A",430,182,1); break;}   //выводим "20A"
  if (Select21==2){ Acs=2;                                                                  //если переменная Acs=2 выбран датчик ACS7XX_30A
    tft.fillRect(406,182,49,18,TFT_BLACK);tft.drawCentreString("30A",430,182,1); break;}    //выводим "30A"
  if (Select21==3){ Acs=3;                                                                  //если переменная Acs=3 выбран датчик ACS7XX_50A
    tft.fillRect(406,182,49,18,TFT_BLACK);tft.drawCentreString("50A",430,182,1); break;}    //выводим "50A"
  if (Select21==4){ Acs=4;                                                                  //если переменная Acs=4 выбран датчик ACS7XX_50A
    tft.fillRect(406,182,49,18,TFT_BLACK);tft.drawCentreString("100A",430,182,1); break;}}  //выводим "100A"
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" короткими нажатиями
    case SB_CLICK: {Select21++; beeper(); if (Select21>4){Select21=1;}}                     //выбираем датчики "ACS7XX_20A", "ACS7XX_30A", "ACS7XX_50A", "ACS7XX_100A"
  if (Select21==1){ Acs=1;                                                                  //если переменная Acs=1 выбран датчик ACS7XX_20A
    tft.fillRect(406,182,49,18,TFT_BLACK); tft.drawCentreString("20A",430,182,1); break;}   //выводим "20A"
  if (Select21==2){ Acs=2;                                                                  //если переменная Acs=2 выбран датчик ACS7XX_30A
    tft.fillRect(406,182,49,18,TFT_BLACK); tft.drawCentreString("30A",430,182,1);break;}    //выводим "30A"
  if (Select21==3){ Acs=3;                                                                  //если переменная Acs=3 выбран датчик ACS7XX_50A
    tft.fillRect(406,182,49,18,TFT_BLACK); tft.drawCentreString("50A",430,182,1);break;}    //выводим "50A"
  if (Select21==4){ Acs=4;                                                                  //если переменная Acs=4 выбран датчик ACS7XX_50A
    tft.fillRect(406,182,49,18,TFT_BLACK); tft.drawCentreString("100A",430,182,1);break;}}} //выводим "100A"
  
  if (place==22){tft.setTextColor(TFT_SILVER); tft.drawString("21. ACS7XX",25,182,1);       //восстанавливаем цвет надписи "ACS7XX"
    tft.drawString("20/30/50/100A",169,182,1); tft.drawRect(20,174,440,33,TFT_BLACK);       //зарисовываем рамку "ACS7XX"
    tft.setTextColor(TFT_RED); tft.drawString("22. Length",25,215,1);                       //выводим надпись "22. Length" красным цветом
    tft.drawString("Short/Long",194,215,1);                                                 //выводим пределы переключения "Short/Long"
    tft.drawRect(20,207,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" короткими нажатиями
    case SB_CLICK: {Select22++; beeper(); if (Select22>1){Select22=0;}}                     //
  if (Select22==0){ Length=0;                                                               //если переменная Length=0
    tft.fillRect(400,214,57,22,TFT_BLACK); tft.drawCentreString("Short",430,215,1);break;}  //выводим "Short"
  if (Select22==1){ Length=1;                                                               //если переменная Length=1
    tft.fillRect(400,214,57,22,TFT_BLACK); tft.drawCentreString("Long",430,215,1); break;}} //выводим "Long"
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" короткими нажатиями
    case SB_CLICK: {Select22++; beeper(); if (Select22>1){Select22=0;}}                     //выбираем датчики "ACS712_20A" или "ACS7XX_30A"
  if (Select22==0){ Length=0;                                                               //если переменная Length=0
    tft.fillRect(400,214,57,22,TFT_BLACK);tft.drawCentreString("Short",430,215,1); break;}  //выводим "Short"
  if (Select22==1){ Length=1;                                                               //если переменная Length=1
    tft.fillRect(400,214,57,22,TFT_BLACK);tft.drawCentreString("Long",430,215,1);break;}}}  //выводим "Long"

  if (place==23){tft.setTextColor(TFT_SILVER); tft.drawString("22. Length",25,215,1);       //восстанавливаем цвет надписи "Length"
    tft.drawString("Short/Long",194,215,1); tft.drawRect(20,207,440,33,TFT_BLACK);          //зарисовываем рамку "Length"
    tft.setTextColor(TFT_RED); tft.drawString("23. Scale OUT",25,248,1);                    //выводим надпись "23. Scale OUT" красным цветом
    tft.drawString("250/500/1/2",190,248,1);                                                //выводим пределы переключения "250/500/1/2"
    tft.drawRect(20,240,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" короткими нажатиями
    case SB_CLICK: {Select23++; beeper(); if (Select23>4){Select23=1;}}                     //выбираем "250","500","1.0" или "2.0"
  if (Select23==1){ Scale=1;                                                                //если переменная Scale=1 выбрана мощность 250Вт
    tft.fillRect(400,248,57,22,TFT_BLACK);tft.drawCentreString("250",430,248,1);break;}     //выводим "250"
  if (Select23==2){ Scale=2;                                                                //если переменная Scale=2 выбрана мощность 500Вт
    tft.fillRect(400,248,57,22,TFT_BLACK);tft.drawCentreString("500",430,248,1); break;}    //выводим "500"
  if (Select23==3){ Scale=3;                                                                //если переменная Scale=3 выбрана мощность 1000Вт
    tft.fillRect(400,248,57,22,TFT_BLACK);tft.drawCentreString("1.0",430,248,1); break;}    //выводим "1.0"
  if (Select23==4){ Scale=4;                                                                //если переменная Scale=3 выбрана мощность 2000Вт
    tft.fillRect(400,248,57,22,TFT_BLACK);tft.drawCentreString("2.0",430,248,1); break;}}   //выводим "2.0"
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" короткими нажатиями
    case SB_CLICK: {Select23--; beeper(); if (Select23<1){Select23=4;}}                     //выбираем "250","500","1.0" или "2.0"
  if (Select23==1){ Scale=1;                                                                //если переменная Scale=1 выбрана мощность 250Вт
    tft.fillRect(400,248,57,22,TFT_BLACK);tft.drawCentreString("250",430,248,1); break;}    //выводим "250"
  if (Select23==2){ Scale=2;                                                                //если переменная Scale=2 выбрана мощность 500Вт
    tft.fillRect(400,248,57,22,TFT_BLACK);tft.drawCentreString("500",430,248,1);break;}     //выводим "500"
  if (Select23==3){ Scale=3;                                                                //если переменная Scale=3 выбрана мощность 1000Вт
    tft.fillRect(400,248,57,22,TFT_BLACK);tft.drawCentreString("1.0",430,248,1);break;}     //выводим "1.0"
  if (Select23==4){ Scale=4;                                                                //если переменная Scale=3 выбрана мощность 2000Вт
    tft.fillRect(400,248,57,22,TFT_BLACK);tft.drawCentreString("2.0",430,248,1);break;}}}   //выводим "2.0"
  
  if (place==24){tft.setTextColor(TFT_SILVER); tft.drawString("23. Scale OUT",25,248,1);    //восстанавливаем цвет надписи "Scale OUT"
    tft.drawString("250/500/1/2",190,248,1); tft.drawRect(20,240,440,33,TFT_BLACK);         //зарисовываем рамку "Scale OUT"
    tft.setTextColor(TFT_RED); tft.drawString("24. The color of the border",25,281,1);      //выводим надпись "24. The color of the border" красным цветом
    tft.drawRect(20,273,440,33,TFT_RED);                                                    //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" короткими нажатиями
    case SB_CLICK: {Select24++; beeper(); if (Select24>5){Select24=1;}}                     //выбираем "GRN","SIL" или "PINK"
  if (Select24==1){ BORDER=1;                                                               //если переменная BORDER=1
    tft.fillRect(392,281,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_GREEN); tft.drawCentreString("GRN",425,281,1); break;}             //выводим "GRN" зелёным цветом
  if (Select24==2){ BORDER=2;                                                               //если переменная BORDER=2
    tft.fillRect(392,281,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_SILVER); tft.drawCentreString("SIL",425,281,1); break;}            //выводим "SIL" серебряным цветом
  if (Select24==3){ BORDER=3;                                                               //если переменная BORDER=3
    tft.fillRect(392,281,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_PINK); tft.drawCentreString("PINK",425,281,1); break;}             //выводим "PINK" розовым цветом
  if (Select24==4){ BORDER=4;                                                               //если переменная BORDER=4
    tft.fillRect(392,281,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_ORANGE); tft.drawCentreString("ORG",425,281,1); break;}            //выводим "ORG" оранжевым цветом
  if (Select24==5){ BORDER=5;                                                               //если переменная BORDER=5
    tft.fillRect(392,281,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_CYAN); tft.drawCentreString("CYAN",425,281,1); break;}}            //выводим "CYAN" голубым цветом
  switch(button4.Loop()){                                                                   //кнопкой "VOX/ATT" короткими нажатиями
    case SB_CLICK: {Select24--; beeper(); if (Select24<1){Select24=5;}}                     //выбираем "GRN","SIL" или "PINK"
  if (Select24==1){ BORDER=1;                                                               //если переменная BORDER=1
    tft.fillRect(392,281,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_GREEN); tft.drawCentreString("GRN",425,281,1); break;}             //выводим "GRN" зелёным цветом
  if (Select24==2){ BORDER=2;                                                               //если переменная BORDER=2
    tft.fillRect(392,281,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_SILVER); tft.drawCentreString("SIL",425,281,1); break;}            //выводим "SIL" серебряным цветом
  if (Select24==3){ BORDER=3;                                                               //если переменная BORDER=3
    tft.fillRect(392,281,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_PINK); tft.drawCentreString("PINK",425,281,1); break;}             //выводим "PINK" розовым цветом
  if (Select24==4){ BORDER=4;                                                               //если переменная BORDER=4
    tft.fillRect(392,281,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_ORANGE); tft.drawCentreString("ORG",425,281,1); break;}            //выводим "ORG" оранжевым цветом
  if (Select24==5){ BORDER=5;                                                               //если переменная BORDER=5
    tft.fillRect(392,281,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_CYAN); tft.drawCentreString("CYAN",425,281,1); break;}}}           //выводим "CYAN" голубым цветом
} if ((place==25)||(place==26)){EEPROM.update(25,Select17); EEPROM.update(18,Select18);     //если place==25
    EEPROM.put   (31,Select19); EEPROM.update( 7,Select20); EEPROM.update( 8,Select21);     //и старое значение ячеек отличается от нового
    EEPROM.update( 9,Select22); EEPROM.update(35,Select23); EEPROM.update(36,Select24);     //заменяем их содержимое в EEPROM и переходим на четвёртую страницу
  if (place==26){place=9; goto M1;}}                                                        //переходим на вторую страницу по метке М1

p4: BORDER=EEPROM.read(36); Select24=BORDER;                                                //читаем содержимое ячейки 36 EEPROM в переменную BORDER
  if (BORDER==1) BORDER=TFT_GREEN;                                                          //если BORDER==1 включается зелёный цвет окантовок рамки
  if (BORDER==2) BORDER=TFT_SILVER;                                                         //если BORDER==2 включается серебряный цвет окантовок рамки
  if (BORDER==3) BORDER=TFT_PINK;                                                           //если BORDER==3 включается розовый цвет окантовок рамки
  if (BORDER==4) BORDER=TFT_ORANGE;                                                         //если BORDER==3 включается оранжевый цвет окантовок рамки
  if (BORDER==5) BORDER=TFT_CYAN;                                                           //если BORDER==3 включается голубой цвет окантовок рамки
    tft.fillScreen(TFT_GREY60);                                                             //заливаем экран серым цветом
  for(0,2){                                                                                 //включаем цикл
    tft.drawRect(0+i,0+i,480-i*2,320-i*2,BORDER);                                           //рисуем наружную окантовку
    tft.drawRoundRect(6+i,6+i,468-i*2,308-i*2,8-i,BORDER);}                                 //рисуем внутреннюю окантовку с закруглёнными углами
    tft.fillRoundRect(8,8,464,304,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
    tft.setFreeFont(FSSB9); tft.setTextColor(BORDER);                                       //выбираем шрифт и цвет текста
    tft.drawString("page 4",25,20,1);                                                       //выводим надпись "page 3"
    tft.setFreeFont(FSBI12);                                                                //выбираем шрифт
    tft.drawCentreString("-- MENU --",240,20,1);                                            //выводим надпись "-- MENU --"
    tft.setTextColor(TFT_SILVER);                                                           //выбираем цвет текста
    tft.drawString("25. ALC",25,50,1);                                                      //выводим надпись "25. ALC"
    tft.drawString("26. Clock setting  -----  short press  S3 or S4",25,83,1);              //выводим надпись "26. Clock setting  -----  short press  S3 or S4"
    tft.drawString("27. The color of the clock",25,116,1);                                  //выводим надпись "27. The color of the clock"
    tft.drawString("28. Powerin",25,149,1);                                                 //выводим надпись "28. Powerin"
    tft.drawString("ON / OFF",199,50,1);                                                    //выводим надпись "ON/OFF"
    tft.drawString("3W / 30W",199,149,1);                                                   //выводим надпись "3W / 30W"
    tft.drawString("29. Inversion power",25,182,1);                                         //выводим надпись "29. Inversion power"
    
  if (Select25==1){tft.setTextColor(TFT_SILVER); tft.drawCentreString("ON",430,50,1);       //если значение ячейки 37 EEPROM "2" выводим по центру редактируемую надпись "ON"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("ON",360,50,1);}                     //при загрузке четвёртой страницы меню выводим по центру текущую надпись "ON"
  if (Select25==0){tft.setTextColor(TFT_SILVER); tft.drawCentreString("OFF",430,50,1);      //если значение ячейки 37 EEPROM "1" выводим по центру редактируемую надпись "OFF"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("OFF",360,50,1);}                    //при загрузке четвёртой страницы меню выводим по центру текущую надпись "OFF"
  if (Select27==5){tft.setTextColor(TFT_CYAN); tft.drawCentreString("CYAN",425,116,1);      //если значение ячейки 38 EEPROM "3" выводим по центру редактируемую надпись "CYAN"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("CYAN",355,116,1);}                  //при загрузке четвёртой страницы меню выводим по центру текущую надпись "CYAN"
  if (Select27==4){tft.setTextColor(TFT_ORANGE); tft.drawCentreString("ORG",425,116,1);     //если значение ячейки 38 EEPROM "3" выводим по центру редактируемую надпись "ORG"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("ORG",355,116,1);}                   //при загрузке четвёртой страницы меню выводим по центру текущую надпись "ORG"
  if (Select27==3){tft.setTextColor(TFT_PINK); tft.drawCentreString("PINK",425,116,1);      //если значение ячейки 38 EEPROM "3" выводим по центру редактируемую надпись "PINK"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("PINK",355,116,1);}                  //при загрузке четвёртой страницы меню выводим по центру текущую надпись "PINK"
  if (Select27==2){tft.setTextColor(TFT_SILVER); tft.drawCentreString("SIL",425,116,1);     //если значение ячейки 38 EEPROM "2" выводим по центру редактируемую надпись "SIL"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("SIL",355,116,1);}                   //при загрузке четвёртой страницы меню выводим по центру текущую надпись "SIL"
  if (Select27==1){tft.setTextColor(TFT_GREEN); tft.drawCentreString("GRN",425,116,1);      //если значение ячейки 38 EEPROM "1" выводим по центру редактируемую надпись "GRN"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("GRN",355,116,1);}                   //при загрузке четвёртой страницы меню выводим по центру текущую надпись "GRN"
  if (Select28==0){tft.setTextColor(TFT_SILVER); tft.drawCentreString("3W",430,149,1);      //если значение ячейки 39 EEPROM "0" выводим по центру редактируемую надпись "3W"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("3W",360,149,1);}                    //при загрузке четвёртой страницы меню выводим по центру текущую надпись "3W"
  if (Select28==1){tft.setTextColor(TFT_SILVER); tft.drawCentreString("30W",430,149,1);     //если значение ячейки 39 EEPROM "1" выводим по центру редактируемую надпись "30W"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("30W",360,149,1);}                   //при загрузке четвёртой страницы меню выводим по центру текущую надпись "30W"
  if (Select29==0){tft.setTextColor(TFT_SILVER); tft.drawCentreString("OFF",430,182,1);     //если значение ячейки 40 EEPROM "0" выводим по центру редактируемую надпись "OFF"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("OFF",360,182,1);}                   //при загрузке четвёртой страницы меню выводим по центру текущую надпись "OFF"
  if (Select29==1){tft.setTextColor(TFT_SILVER); tft.drawCentreString("ON",430,182,1);      //если значение ячейки 40 EEPROM "1" выводим по центру редактируемую надпись "ON"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("ON",360,182,1);}                    //при загрузке четвёртой страницы меню выводим по центру текущую надпись "ON"
    tft.setTextColor(TFT_DARKGREY); tft.drawCentreString("D0ITC 2020 D0ISM",240,281,1);     //выводим надпись "D0ITC 2020 D0ISM"

  while (place<30){                                                                         //находимся на четвёртой странице пока "place<30"
  switch(button1.Loop()){                                                                   //описываем работу кнопки "BYPASS/POWER ON"
    case SB_CLICK: beeper(); place=31; break;                                               //коротким нажатием по метке p3 переходим на третью страницу
    case SB_LONG_CLICK: beeper(); goto M2; break;}                                          //длинным нажатием по метке M2 выходим из меню
  switch(button2.Loop()){                                                                   //кнопкой "Band/Protocol" переключаем редактируемые параметры
    case SB_CLICK: place++; beeper(); if (place>29){place=25;} break;                       //коротким нажатием по одному параметру по кольцу
    case SB_LONG_CLICK: place=30; beeper(); break;}                                         //длинным нажатием переходим на первую страницу
  
  if (place==25){tft.setTextColor(TFT_SILVER);                                              //
    tft.drawString("29. Inversion power",25,182,1);                                         //восстанавливаем цвет надписи "29. Inversion power"
    tft.drawString("3W / 30W",199,149,1); tft.drawRect(20,174,440,33,TFT_BLACK);            //зарисовываем рамку "Powerin"
    tft.setTextColor(TFT_RED); tft.drawString("25. ALC",25,50,1);                           //выводим надпись "25. ALC" красным цветом
    tft.drawString("ON / OFF",199,50,1);                                                    //выводим пределы переключения "ON/OFF"
    tft.drawRect(20,42,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                       //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" короткими нажатиями
    case SB_CLICK: {Select25++; beeper(); if (Select25>1){Select25=0;}}                     //переключаем включенные режимы "ALC"(ON/OFF)
  if (Select25==1){ ALC=1;                                                                  //если "ALC" включен ALC=1
    tft.fillRect(406,50,49,18,TFT_BLACK); tft.drawCentreString("ON",430,50,1); break;}      //выводим "ON"
  if (Select25==0){ ALC=0;                                                                  //если "ALC" выключен ALC=0
    tft.fillRect(406,50,49,18,TFT_BLACK); tft.drawCentreString("OFF",430,50,1); break;}}    //выводим "OFF"
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" короткими нажатиями
    case SB_CLICK: {Select25++; beeper(); if (Select25>1){Select25=0;}}                     //переключаем включенные режимы "ALC"(ON/OFF)
  if (Select25==1){ ALC=1;                                                                  //если "ALC" включен ALC=1
    tft.fillRect(406,50,49,18,TFT_BLACK); tft.drawCentreString("ON",430,50,1); break;}      //выводим  "ON"
  if (Select25==0){ ALC=0;                                                                  //если "ALC" выключен ALC=0
    tft.fillRect(406,50,49,18,TFT_BLACK); tft.drawCentreString("OFF",430,50,1);break;}}}    //выводим "OFF"
  
  if (place==26){tft.setTextColor(TFT_SILVER); tft.drawString("25. ALC",25,50,1);           //восстанавливаем цвет надписи "25. ALC"
    tft.drawString("ON / OFF",199,50,1); tft.drawRect(20,42,440,33,TFT_BLACK);              //зарисовываем рамку "VOX Delay"
    tft.setTextColor(TFT_RED); tft.drawRect(20,75,440,33,TFT_RED);                          //рисуем красную рамку
    tft.drawString("26. Clock setting  -----  short press  S3 or S4",25,83,1);              //выводим "26. Clock setting ----- short press  S3 or S4"
  switch(button3.Loop()){                                                                   //описываем работу кнопки №3
    case SB_CLICK: beeper(); EEPROM.update(38,Select27); setclock(); break;}                //коротким нажатием сохраняем выбранный цвет и вызываем подпрограмму установки часов
  switch(button4.Loop()){                                                                   //описываем работу кнопки №4
    case SB_CLICK: beeper(); EEPROM.update(38,Select27); setclock(); break;}}               //коротким нажатием сохраняем выбранный цвет и вызываем подпрограмму установки часов
  
  if (place==27){tft.setTextColor(TFT_SILVER); tft.drawRect(20,75,440,33,TFT_BLACK);        //восстанавливаем цвет надписи "26. Clock setting --- short press  S3 or S4"
    tft.drawString("26. Clock setting  -----  short press  S3 or S4",25,83,1);              //выводим "26. Clock setting ----- short press  S3 or S4" и зарисовываем рамку
    tft.setTextColor(TFT_RED); tft.drawString("27. The color of the clock",25,116,1);       //выводим надпись "27. The color of the clock" красным цветом
    tft.drawRect(20,108,440,33,TFT_RED);                                                    //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "The color of the clock" короткими нажатиями
    case SB_CLICK: {Select27++; beeper(); if (Select27>5){Select27=1;}}                     //выбираем "GRN","SIL" или "PINK"
  if (Select27==1){ Cclock=1;                                                               //если переменная Cclock=1
    tft.fillRect(392,116,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_GREEN); tft.drawCentreString("GRN",425,116,1); break;}             //выводим "GRN" зелёным цветом
  if (Select27==2){ Cclock=2;                                                               //если переменная Cclock=2
    tft.fillRect(392,116,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_SILVER); tft.drawCentreString("SIL",425,116,1); break;}            //выводим "SIL" серебряным цветом
  if (Select27==3){ Cclock=3;                                                               //если переменная Cclock=3
    tft.fillRect(392,116,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_PINK); tft.drawCentreString("PINK",425,116,1); break;}             //выводим "PINK" розовым цветом
  if (Select27==4){ Cclock=4;                                                               //если переменная Cclock=4
    tft.fillRect(392,116,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_ORANGE); tft.drawCentreString("ORG",425,116,1); break;}            //выводим "ORG" оранжевым цветом
  if (Select27==5){ Cclock=5;                                                               //если переменная Cclock=5
    tft.fillRect(392,116,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_CYAN); tft.drawCentreString("CYAN",425,116,1); break;}}            //выводим "CYAN" голубым цветом
  switch(button4.Loop()){                                                                   //кнопкой "VOX/ATT" короткими нажатиями
    case SB_CLICK: {Select27--; beeper(); if (Select27<1){Select27=5;}}                     //выбираем "GRN","SIL" или "PINK"
  if (Select27==1){ Cclock=1;                                                               //если переменная Cclock=1
    tft.fillRect(392,116,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_GREEN); tft.drawCentreString("GRN",425,116,1); break;}             //выводим "GRN" зелёным цветом
  if (Select27==2){ Cclock=2;                                                               //если переменная Cclock=2
    tft.fillRect(392,116,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_SILVER); tft.drawCentreString("SIL",425,116,1); break;}            //выводим "SIL" серебряным цветом
  if (Select27==3){ Cclock=3;                                                               //если переменная Cclock=3
    tft.fillRect(392,116,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_PINK); tft.drawCentreString("PINK",425,116,1);break;}              //выводим "PINK" розовым цветом
  if (Select27==4){ Cclock=4;                                                               //если переменная Cclock=4
    tft.fillRect(392,116,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_ORANGE); tft.drawCentreString("ORG",425,116,1); break;}            //выводим "ORG" оранжевым цветом
  if (Select27==5){ Cclock=5;                                                               //если переменная Cclock=5
    tft.fillRect(392,116,66,22,TFT_BLACK);                                                  //затираем предыдущую надпись
    tft.setTextColor(TFT_CYAN); tft.drawCentreString("CYAN",425,116,1); break;}}}           //выводим "CYAN" голубым цветом
  
  if (place==28){tft.setTextColor(TFT_SILVER); tft.drawRect(20,108,440,33,TFT_BLACK);       //зарисовываем рамку "Cclock"
    tft.drawString("27. The color of the clock",25,116,1);                                  //восстанавливаем цвет надписи "27. The color of the clock"
    tft.setTextColor(TFT_RED); tft.drawString("28. Powerin",25,149,1);                      //выводим надпись "28. Powerin" и
    tft.drawString("3W / 30W",199,149,1);                                                   //"3W / 30W" красным цветом
    tft.drawRect(20,141,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "Powerin" короткими нажатиями
    case SB_CLICK: {Select28++; beeper(); if (Select28>1){Select28=0;}}                     //переключаем режимы "3W" или "30W"
  if (Select28==0){ powerin=0;                                                              //если powerin=0
    tft.fillRect(405,149,50,18,TFT_BLACK); tft.drawCentreString("3W",430,149,1); break;}    //выводим "3W"
  if (Select28==1){ powerin=1;                                                              //если powerin=1
    tft.fillRect(405,149,50,18,TFT_BLACK); tft.drawCentreString("30W",430,149,1); break;}}  //выводим "30W"
  switch(button4.Loop()){                                                                   //кнопкой "Powerin" короткими нажатиями
    case SB_CLICK: {Select28++; beeper(); if (Select28>1){Select28=0;}}                     //переключаем режимы "3W" или "30W"
  if (Select28==0){ powerin=0;                                                              //если powerin=0
    tft.fillRect(405,149,50,18,TFT_BLACK); tft.drawCentreString("3W",430,149,1); break;}    //выводим "3W"
  if (Select28==1){ powerin=1;                                                              //если powerin=1
    tft.fillRect(405,149,50,18,TFT_BLACK); tft.drawCentreString("30W",430,149,1);break;}}}  //выводим "30W"

  if (place==29){tft.setTextColor(TFT_SILVER);  tft.drawRect(20,141,440,33,TFT_BLACK);      //
    tft.drawString("28. Powerin",25,149,1);                                                 //восстанавливаем цвет надписи "28. Powerin"
    tft.drawString("3W / 30W",199,149,1); tft.drawRect(20,141,440,33,TFT_BLACK);            //зарисовываем рамку "Inversion power"
    tft.setTextColor(TFT_RED); tft.drawString("29. Inversion power",25,182,1);              //выводим надпись "29. Inversion power" красным цветом
    tft.drawRect(20,174,440,33,TFT_RED); tft.setTextColor(TFT_SILVER);                      //рисуем красную рамку
  switch(button3.Loop()){                                                                   //кнопкой "VOX/ATT" короткими нажатиями
    case SB_CLICK: beeper(); Select29=!Select29;                                            //переключаем включенные режимы "Inversion power"(ON/OFF)
  if (Select29==1){ pwr_inv=1;                                                              //если "pwr_inv" включен pwr_inv=1
    tft.fillRect(406,182,49,18,TFT_BLACK); tft.drawCentreString("ON",430,182,1); break;}    //выводим "ON"
  if (Select29==0){ pwr_inv=0;                                                              //если "pwr_inv" выключен pwr_inv=0
    tft.fillRect(406,182,49,18,TFT_BLACK); tft.drawCentreString("OFF",430,182,1); break;}}  //выводим "OFF"
  switch(button4.Loop()){                                                                   //кнопкой "PTT/PWR_VIEW" короткими нажатиями
    case SB_CLICK: beeper(); Select29=!Select29;                                            //переключаем включенные режимы "Inversion power"(ON/OFF)
  if (Select29==1){ pwr_inv=1;                                                              //если "pwr_inv" включен pwr_inv=1
    tft.fillRect(406,182,49,18,TFT_BLACK); tft.drawCentreString("ON",430,182,1); break;}    //выводим  "ON"
  if (Select29==0){ pwr_inv=0;                                                              //если "pwr_inv" выключен pwr_inv=0
    tft.fillRect(406,182,49,18,TFT_BLACK); tft.drawCentreString("OFF",430,182,1);break;}}}  //выводим "OFF"

} if ((place==30)||(place==31)){                                                            //если "place=30" или "place=31"
    EEPROM.update(37,Select25); EEPROM.update(38,Select27); EEPROM.update(39,Select28);     //сохраняем изменения в
    EEPROM.update(40,Select29);                                                             //память ЕЕПРОМ
  if (place==30) {place=1; goto p1;}                                                        //выставляем "place" в 1 и переходим по метке p1 на первую страницу
  if (place==31) {place=17; goto M1;}}                                                      //если "place=31" переходим по метке p3 на третью страницу

M2: EEPROM.update(10, Select1); EEPROM.update(11, Select2); EEPROM.update(12, Select3);     //если старые значения отличаются от новых
    EEPROM.update(13, Select4); EEPROM.update(14, Select5); EEPROM.update(15, Select6);     //заменяем содержимое ячеек EEPROM
    EEPROM.update(16, Select7); EEPROM.update(17 ,Select8); EEPROM.update(20, Select9);     //-------------------------------------------
    EEPROM.update(21,Select10); EEPROM.update(22,Select11); EEPROM.update(23,Select12);     //-------------------------------------------
    EEPROM.update(24,Select13); EEPROM.put   (27,Select14); EEPROM.update(26,Select15);     //-------------------------------------------
    EEPROM.update( 4,Select16); EEPROM.update(25,Select17); EEPROM.update(18,Select18);     //-------------------------------------------
    EEPROM.put   (31,Select19); EEPROM.update( 7,Select20); EEPROM.update( 8,Select21);     //-------------------------------------------
    EEPROM.update( 9,Select22); EEPROM.update(35,Select23); EEPROM.update(36,Select24);     //-------------------------------------------
    EEPROM.update(37,Select25); EEPROM.update(38,Select27); EEPROM.update(39,Select28);     //и выходим из меню
    EEPROM.update(40,Select29);                                                             //

M3: tft.fillRoundRect(8,8,464,304,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
    tft.setFreeFont(FSBI24);                                                                //подключаем внешний шрифт FSBI24
    tft.setTextColor(TFT_SILVER); tft.drawCentreString("EXIT",243,103,1);                   //выводим подложку надписи "EXIT"
    tft.setTextColor(TFT_RED); tft.drawCentreString("EXIT",240,100,1);                      //выводим надпись "EXIT"
    tft.setFreeFont(FSBI18); tft.setTextColor(TFT_DARKGREY);                                //подключаем внешний шрифт FSBI18, выбираем цвет текста
    tft.drawCentreString("D0ITC 2020 D0ISM",240,260,1);                                     //выводим надпись "D0ISM & D0ICT"

    VOXDelay   =EEPROM.read(10);                                                            //читаем новое значение ячейки 10 EEPROM в переменную VOXDelay
    ATTDelay   =EEPROM.read(11);                                                            //читаем новое значение ячейки 11 EEPROM в переменную ATTDelay
    Imax       =EEPROM.read(12);                                                            //читаем новое значение ячейки 12 EEPROM в переменную Imax
    Vmin       =EEPROM.read(13);                                                            //читаем новое значение ячейки 13 EEPROM в переменную Vmin
    Vmax       =EEPROM.read(14);                                                            //читаем новое значение ячейки 14 EEPROM в переменную Vmax
    TFanOff    =EEPROM.read(15);                                                            //читаем новое значение ячейки 15 EEPROM в переменную TFanOff
    TFanOn     =EEPROM.read(16);                                                            //читаем новое значение ячейки 16 EEPROM в переменную TFanOn
    TFanMax    =EEPROM.read(17);                                                            //читаем новое значение ячейки 17 EEPROM в переменную TFanMax
    ATToff     =EEPROM.read(20);                                                            //читаем новое значение ячейки 20 EEPROM в переменную ATToff
    ATT3dB     =EEPROM.read(21);                                                            //читаем новое значение ячейки 21 EEPROM в переменную ATT3dB
    ATT6dB     =EEPROM.read(22);                                                            //читаем новое значение ячейки 22 EEPROM в переменную ATT6dB
    ATTauto    =EEPROM.read(23);                                                            //читаем новое значение ячейки 23 EEPROM в переменную ATTauto
    ATTalarm   =EEPROM.read(24);                                                            //читаем новое значение ячейки 24 EEPROM в переменную ATTalarm
    EEPROM.get(27,SWRmax);                                                                  //читаем новое значение ячейки 27-30 EEPROM в переменную SWRmax
    Tonbeep    =EEPROM.read(26);                                                            //читаем новое значение ячейки 26 EEPROM в переменную Tonbeep
    beep       =EEPROM.read(4);                                                             //читаем новое значение ячейки 4  EEPROM в переменную beep
    TimeBeep   =EEPROM.read(25);                                                            //читаем новое значение ячейки 25 EEPROM в переменную TimeBeep
    BandDelay  =EEPROM.read(18);                                                            //читаем новое значение ячейки 18 EEPROM в переменную BandDelay
    EEPROM.get(31,divider);                                                                 //читаем новое значение ячейки 31-34 EEPROM в переменную divider
    RefreshTime=EEPROM.read(7);                                                             //читаем новое значение ячейки 7  EEPROM в переменную RefreshTime
    Acs        =EEPROM.read(8);                                                             //читаем новое значение ячейки 8  EEPROM в переменную ACS
    Length     =EEPROM.read(9);                                                             //читаем новое значение ячейки 9  EEPROM в переменную Length
    Scale      =EEPROM.read(35);                                                            //читаем новое значение ячейки 35 EEPROM в переменную Scale
    BORDER     =EEPROM.read(36);                                                            //читаем новое значение ячейки 36 EEPROM в переменную BORDER
    ALC        =EEPROM.read(37);                                                            //читаем новое значение ячейки 37 EEPROM в переменную ALC
    Cclock     =EEPROM.read(38);                                                            //читаем новое значение ячейки 38 EEPROM в переменную Cclock
    powerin    =EEPROM.read(39);                                                            //читаем новое значение ячейки 39 EEPROM в переменную powerin
    pwr_inv    =EEPROM.read(40);                                                            //читаем новое значение ячейки 40 EEPROM в переменную pwr_inv
  switch (pwr_inv){                                                                         //инверсия защиты отключения питания
    case 0: digitalWrite(on_off,LOW); break;                                                //если инверсия отключена, на выходе 0
    case 1: digitalWrite(on_off,HIGH); break;}                                              //если инверсия включена, на выходе 1
    delay(1000);                                                                            //задержка 1000мс
    animation();                                                                            //анимация
    preparing_the_screen();}                                                                //вызываем подпрограмму подготовки экрана

void setclock(){//*************************************************************************** Подпрограмма установки часов
    tft.fillRoundRect(8,8,464,304,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
    tft.setFreeFont(FSBI18); tft.setTextColor(BORDER);                                      //выбираем шрифт и цвет текста
    tft.drawCentreString("-- Clock setting --",240,25,1);                                   //выводим надпись "-- Clock setting --"
    Wire.requestFrom(104,2);                                                                //получаем данные с адреса 104 I2C
  if (Wire.available()){                                                                    //если линия I2C отвечает
    tmElements_t tm;                                                                        //вызов функции часов DS3231
    RTC.read(tm);                                                                           //переменная чтения DS3231
    int hh=tm.Hour;                                                                         //выводим часы
    int mm=tm.Minute;                                                                       //выводим минуты
    int ss=tm.Second;                                                                       //выводим секунды
    int dy=tm.Wday;                                                                         //выводим день недели
    int da=tm.Day;                                                                          //выводим число
    int mo=tm.Month;                                                                        //выводим месяц
    int ya=tm.Year;                                                                         //выводим год
    int xpos=137;                                                                           //начальная координата по х для вывода часов
    int ypos=75;                                                                            //начальная координата по y для вывода часов
    int ysecs=ypos;                                                                         //координата по y для вывода секунд
    int xsecs=0;                                                                            //координата по x для вывода секунд
    int xpos1=100;                                                                          //начальная координата по х для вывода даты
    int ypos1=220;                                                                          //начальная координата по y для вывода даты
    int yYear=ypos1;                                                                        //координата по y для вывода года
    int xYear=0;                                                                            //координата по x для вывода года
    Cclock=EEPROM.read(38);                                                                 //читаем из 38 ячейки EEPROM состояние Cclock
  if (Cclock==1){Cclock=TFT_GREEN;}                                                         //если Cclock==1 включается зелёный цвет вывода часов
  if (Cclock==2){Cclock=TFT_SILVER;}                                                        //если Cclock==2 включается серебряный цвет вывода часов
  if (Cclock==3){Cclock=TFT_PINK;}                                                          //если Cclock==3 включается розовый цвет вывода часов
  if (Cclock==4){Cclock=TFT_ORANGE;}                                                        //если Cclock==4 включается оранжевый цвет вывода часов
  if (Cclock==5){Cclock=TFT_CYAN;}                                                          //если Cclock==5 включается голубой цвет вывода часов
    tft.setTextColor(Cclock,TFT_BLACK);                                                     //выставляем выбранный цвет часов
    tft.setTextPadding(20);                                                                 //включаем обновление подложки шрифта
  if (hh < 10) xpos += tft.drawChar('0',xpos,ypos,7);                                       //если показания часов меньше 10 дорисовываем незначащий ноль
    xpos += tft.drawNumber(hh,xpos,ypos,7);                                                 //выводим значение часов
    xpos += tft.drawChar(':',xpos,ypos,7);                                                  //рисуем часовое и минутное двоеточие
  if (mm < 10) xpos += tft.drawChar('0',xpos,ypos,7);                                       //если показания минут меньше 10 дорисовываем незначащий ноль
    xpos += tft.drawNumber(mm,xpos,ypos,7);                                                 //выводим значение минут
    xsecs = xpos;                                                                           //приравниваем координату x вывода секунд к начальной координате по x
    xpos += tft.drawChar(':',xsecs,ysecs,7);                                                //рисуем секундное двоеточие
  if (ss < 10) xpos += tft.drawChar('0',xpos,ypos,7);                                       //если показания секунд меньше 10 дорисовываем незначащий ноль
    tft.drawNumber(ss,xpos,ysecs,7);                                                        //выводим значение секунд
  if (da < 10) xpos1 += tft.drawChar('0',xpos1,ypos1,7);                                    //если показания числа меньше 10 дорисовываем незначащий ноль
    xpos1 += tft.drawNumber(da,xpos1,ypos1,7);                                              //выводим значение числа
    xpos1 += tft.drawChar(':',xpos1,ypos1,7);                                               //формируем пробел между числом и месяцем
  if (mo < 10) xpos1 += tft.drawChar('0',xpos1,ypos1,7);                                    //если показания месяца меньше 10 дорисовываем незначащий ноль
    xpos1 += tft.drawNumber(mo,xpos1,ypos1,7);                                              //выводим значение месяца
    xYear = xpos1;                                                                          //приравниваем координату x вывода года к координате вывода даты
    xpos1 += tft.drawChar(':',xYear,yYear,7);                                               //формируем пробел между месяцем и годом
    tft.drawNumber((int)ya+1970,xpos1,yYear,7);                                             //выводим значение года
    tft.setFreeFont(FSBI24);                                                                //выбираем шрифт вывода дня недели
  if (!Length){                                                                             //если "Length==0" выводим сокращённые названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.drawCentreString("-- Mon --",240,150,1); break;                             //выводим понедельник
    case 2: tft.drawCentreString("-- Tue --",240,150,1); break;                             //выводим вторник
    case 3: tft.drawCentreString("-- Wed --",240,150,1); break;                             //выводим среда
    case 4: tft.drawCentreString("-- Thu --",240,150,1); break;                             //выводим четверг
    case 5: tft.drawCentreString("-- Fri --",240,150,1); break;                             //выводим пятница
    case 6: tft.drawCentreString("-- Sat --",240,150,1); break;                             //выводим суббота
    case 7: tft.drawCentreString("-- Sun --",240,150,1); break;}}                           //выводим воскресенье
  if (Length){                                                                              //если "Length==1" выводим полные названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.drawCentreString("Monday",240,150,1);    break;                             //выводим понедельник
    case 2: tft.drawCentreString("Tuesday",240,150,1);   break;                             //выводим вторник
    case 3: tft.drawCentreString("Wednesday",240,150,1); break;                             //выводим среда
    case 4: tft.drawCentreString("Thursday",240,150,1);  break;                             //выводим четверг
    case 5: tft.drawCentreString("Friday",240,150,1);    break;                             //выводим пятница
    case 6: tft.drawCentreString("Saturday",240,150,1);  break;                             //выводим суббота
    case 7: tft.drawCentreString("Sunday",240,150,1);    break;}}                           //выводим воскресенье
    int place=1;                                                                            //при загрузке активируем пункт 1
  while (place<8){                                                                          //находимся в цикле установки пока "place<8"
  switch (button1.Loop()){                                                                  //описывем работу кнопки "SET TIME"
    case SB_CLICK: place--; beeper(); if (place<1){place=7;} break;}                        //коротким нажатием переключаем по одному параметру справа на лево по кольцу
  switch (button2.Loop()){                                                                  //описывем работу кнопки "SET TIME"
    case SB_CLICK: place++; beeper(); if (place>7){place=1;} break;                         //коротким нажатием переключаем по одному параметру слева на прво по кольцу
    case SB_LONG_CLICK: beeper(); place=8; break;}                                          //длинным нажатием выходим из режима установки
    tft.setTextPadding(0);                                                                  //включаем обновление подложки шрифта
  if (place==1){tft.setTextColor(Cclock,TFT_BLACK);                                         //выбираем цвет текста для восстановления значения года
    tft.drawNumber((int)ya+1970,250,220,7);                                                 //восстанавливаем цвет значения года
  if (mm<10){tft.drawChar('0',213,75,7); tft.drawNumber(mm,245,75,7);}                      //если показания минут меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mm,213,75,7);                                                         //выводим значение минут  
    tft.setTextColor(TFT_RED,TFT_BLACK);                                                    //выбираем цвет часов
  if (hh<10){tft.drawChar('0',137,75,7); tft.drawNumber(hh,169,75,7);}                      //если показания часов меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(hh,137,75,7);                                                         //выводим значение часов
  switch(button3.Loop()){                                                                   //кнопкой "Hour" коротким нажатием
    case SB_CLICK: hh++; beeper(); if (hh>23){hh=0;}                                        //короткими нажатиями выставляем новое значение часов на увеличение по кольцу
  if (hh<10){tft.drawChar('0',137,75,7); tft.drawNumber(hh,169,75,7);}                      //если показания часов меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(hh,137,75,7); break;                                                  //выводим значение часов
    case SB_AUTO_CLICK: hh++; beeper(); if (hh>23){hh=0;}                                   //длинным нажатием перебираем часы на увеличение до отпускания кнопки
  if (hh<10){tft.drawChar('0',137,75,7); tft.drawNumber(hh,169,75,7);}                      //если показания часов меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(hh,137,75,7); break;}                                                 //выводим значения часов
  switch (button4.Loop()){                                                                  //кнопкой "Hour" коротким нажатием
    case SB_CLICK: hh--; beeper(); if (hh<0){hh=23;}                                        //короткими нажатиями выставляем новое значение часов на уменьшение по кольцу
  if (hh<10){tft.drawChar('0',137,75,7); tft.drawNumber(hh,169,75,7);}                      //если показания часов меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(hh,137,75,7); break;                                                  //выводим значение часов
    case SB_AUTO_CLICK: hh--; beeper(); if (hh<0){hh=23;}                                   //длинным нажатием перебираем часы на уменьшение до отпускания кнопки
  if (hh<10){tft.drawChar('0',137,75,7); tft.drawNumber(hh,169,75,7);}                      //если показания часов меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(hh,137,75,7); break;}}                                                //выводим значения часов
  if (place==2){tft.setTextColor(Cclock,TFT_BLACK);                                         //выбираем цвет текста для восстановления значения часов
  if (hh<10){tft.drawChar('0',137,75,7); tft.drawNumber(hh,169,75,7);}                      //если показания часов меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(hh,137,75,7);                                                         //выводим значение часов
  if (ss<10){tft.drawChar('0',289,75,7); tft.drawNumber(ss,321,75,7);}                      //если показания секунд меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(ss,289,75,7);                                                         //выводим значение секунд
    tft.setTextColor(TFT_RED,TFT_BLACK);                                                    //выбираем цвет минут
  if (mm<10){tft.drawChar('0',213,75,7); tft.drawNumber(mm,245,75,7);}                      //если показания минут меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mm,213,75,7);                                                         //выводим значение минут
  switch (button3.Loop()){                                                                  //кнопкой "Minute"
    case SB_CLICK: mm++; beeper(); if (mm>59){mm=0;}                                        //короткими нажатиями выставляем новое значение минут на увеличение по кольцу
  if (mm<10){tft.drawChar('0',213,75,7); tft.drawNumber(mm,245,75,7);}                      //если показания минут меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mm,213,75,7); break;                                                  //выводим значение минут
    case SB_AUTO_CLICK: mm++; beeper(); if (mm>59){mm=0;}                                   //длинным нажатием перебираем минуты на увеличение до отпускания кнопки
  if (mm<10){tft.drawChar('0',213,75,7); tft.drawNumber(mm,245,75,7);}                      //если показания минут меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mm,213,75,7); break;}                                                 //выводим значение минут
  switch (button4.Loop()){                                                                  //кнопкой "Minute"
    case SB_CLICK: mm--; beeper(); if (mm<0){mm=59;}                                        //короткими нажатиями выставляем новое значение минут на уменьшение по кольцу
  if (mm<10){tft.drawChar('0',213,75,7); tft.drawNumber(mm,245,75,7);}                      //если показания минут меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mm,213,75,7); break;                                                  //выводим значение минут
    case SB_AUTO_CLICK: mm--; beeper(); if (mm<0){mm=59;}                                   //длинным нажатием перебираем минуты на уменьшение до отпускания кнопки
  if (mm<10){tft.drawChar('0',213,75,7); tft.drawNumber(mm,245,75,7);}                      //если показания минут меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mm,213,75,7); break;}}                                                //выводим значение минут
  if (place==3){tft.setTextColor(Cclock,TFT_BLACK);                                         //выбираем цвет текста для восстановления значения минут
  if (mm<10){tft.drawChar('0',213,75,7); tft.drawNumber(mm,245,75,7);}                      //если показания минут меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mm,213,75,7);                                                         //выводим значение минут
    tft.setTextColor(Cclock);                                                               //выбираем цвет текста для восстановления значения дней недели
  if (!Length){                                                                             //если "Length==0" выводим сокращённые названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.drawCentreString("-- Mon --",240,150,1); break;                             //выводим понедельник
    case 2: tft.drawCentreString("-- Tue --",240,150,1); break;                             //выводим вторник
    case 3: tft.drawCentreString("-- Wed --",240,150,1); break;                             //выводим среда
    case 4: tft.drawCentreString("-- Thu --",240,150,1); break;                             //выводим четверг
    case 5: tft.drawCentreString("-- Fri --",240,150,1); break;                             //выводим пятница
    case 6: tft.drawCentreString("-- Sat --",240,150,1); break;                             //выводим суббота
    case 7: tft.drawCentreString("-- Sun --",240,150,1); break;}}                           //выводим воскресенье
  if (Length){                                                                              //если "Length==1" выводим полные названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.drawCentreString("Monday",240,150,1);    break;                             //выводим понедельник
    case 2: tft.drawCentreString("Tuesday",240,150,1);   break;                             //выводим вторник
    case 3: tft.drawCentreString("Wednesday",240,150,1); break;                             //выводим среда
    case 4: tft.drawCentreString("Thursday",240,150,1);  break;                             //выводим четверг
    case 5: tft.drawCentreString("Friday",240,150,1);    break;                             //выводим пятница
    case 6: tft.drawCentreString("Saturday",240,150,1);  break;                             //выводим суббота
    case 7: tft.drawCentreString("Sunday",240,150,1);    break;}}                           //выводим воскресенье
    tft.setTextColor(TFT_RED,TFT_BLACK);                                                    //выбираем цвет секунд
  if (ss<10){tft.drawChar('0',289,75,7); tft.drawNumber(ss,321,75,7);}                      //если показания секунд меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(ss,289,75,7);                                                         //выводим значение секунд
  switch (button3.Loop()){                                                                  //кнопкой "Second"
    case SB_CLICK: ss++; beeper(); if (ss>59){ss=0;}                                        //короткими нажатиями выставляем новое значение секунд на увеличение по кольцу
  if (ss<10){tft.drawChar('0',289,75,7); tft.drawNumber(ss,321,75,7);}                      //если показания секунд меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(ss,289,75,7); break;                                                  //выводим значение секунд
    case SB_AUTO_CLICK: ss++; beeper(); if (ss>59){ss=0;}                                   //длинным нажатием перебираем секунды на увеличение до отпускания кнопки
  if (ss<10){tft.drawChar('0',289,75,7); tft.drawNumber(ss,321,75,7);}                      //если показания секунд меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(ss,289,75,7); break;}                                                 //выводим значение секунд
  switch (button4.Loop()){                                                                  //кнопкой "Second"
    case SB_CLICK: ss--; beeper(); if (ss<0){ss=59;}                                        //короткими нажатиями выставляем новое значение секунд на уменьшение по кольцу
  if (ss<10){tft.drawChar('0',289,75,7); tft.drawNumber(ss,321,75,7);}                      //если показания секунд меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(ss,289,75,7); break;                                                  //выводим значение секунд
    case SB_AUTO_CLICK: ss--; beeper(); if (ss<0){ss=59;}                                   //длинным нажатием перебираем секунды на уменьшение до отпускания кнопки
  if (ss<10){tft.drawChar('0',289,75,7); tft.drawNumber(ss,321,75,7);}                      //если показания секунд меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(ss,289,75,7); break;}}                                                //выводим значение секунд
  if (place==4){tft.setTextColor(Cclock,TFT_BLACK);                                         //выбираем цвет текста для восстановления значения секунд
  if (ss<10){tft.drawChar('0',289,75,7); tft.drawNumber(ss,321,75,7);}                      //если показания секунд меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(ss,289,75,7);                                                         //выводим значение секунд
  if (da<10){tft.drawChar('0',100,220,7); tft.drawNumber(da,132,220,7);}                    //если показания даты меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(da,100,220,7);                                                        //выводим значение даты
    tft.setTextColor(TFT_RED);                                                              //выбираем цвет дня недели
  if (!Length){                                                                             //если "Length==0" выводим сокращённые названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.drawCentreString("-- Mon --",240,150,1); break;                             //выводим понедельник
    case 2: tft.drawCentreString("-- Tue --",240,150,1); break;                             //выводим вторник
    case 3: tft.drawCentreString("-- Wed --",240,150,1); break;                             //выводим среда
    case 4: tft.drawCentreString("-- Thu --",240,150,1); break;                             //выводим четверг
    case 5: tft.drawCentreString("-- Fri --",240,150,1); break;                             //выводим пятница
    case 6: tft.drawCentreString("-- Sat --",240,150,1); break;                             //выводим суббота
    case 7: tft.drawCentreString("-- Sun --",240,150,1); break;}}                           //выводим воскресенье
  if (Length){                                                                              //если "Length==1" выводим полные названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.drawCentreString("Monday",240,150,1);    break;                             //выводим понедельник
    case 2: tft.drawCentreString("Tuesday",240,150,1);   break;                             //выводим вторник
    case 3: tft.drawCentreString("Wednesday",240,150,1); break;                             //выводим среда
    case 4: tft.drawCentreString("Thursday",240,150,1);  break;                             //выводим четверг
    case 5: tft.drawCentreString("Friday",240,150,1);    break;                             //выводим пятница
    case 6: tft.drawCentreString("Saturday",240,150,1);  break;                             //выводим суббота
    case 7: tft.drawCentreString("Sunday",240,150,1);    break;}}                           //выводим воскресенье
  switch (button3.Loop()){                                                                  //кнопкой "Wday"
    case SB_CLICK: dy++; beeper(); if (dy>7){dy=1;}                                         //короткими нажатиями выбираем день недели на увеличение по кольцу
  if (!Length){                                                                             //если "Length==0" выводим сокращённые названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Mon --",240,150,1);    break;                                  //выводим понедельник
    case 2: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Tue --",240,150,1);   break;                                   //выводим вторник
    case 3: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Wed --",240,150,1); break;                                     //выводим среда
    case 4: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Thu --",240,150,1);  break;                                    //выводим четверг
    case 5: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Fri --",240,150,1);    break;                                  //выводим пятница
    case 6: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Sat --",240,150,1);  break;                                    //выводим суббота
    case 7: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Sun --",240,150,1);    break;} break;}                         //выводим воскресенье
  if (Length){                                                                              //если "Length==1" выводим полные названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Monday",240,150,1);    break;                                     //выводим понедельник
    case 2: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Tuesday",240,150,1);   break;                                     //выводим вторник
    case 3: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Wednesday",240,150,1); break;                                     //выводим среда
    case 4: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Thursday",240,150,1);  break;                                     //выводим четверг
    case 5: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Friday",240,150,1);    break;                                     //выводим пятница
    case 6: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Saturday",240,150,1);  break;                                     //выводим суббота
    case 7: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Sunday",240,150,1);    break;} break;}}                           //выводим воскресенье
  switch (button4.Loop()){                                                                  //кнопкой "Wday"
    case SB_CLICK: dy--; beeper(); if (dy<1){dy=7;}                                         //короткими нажатиями выбираем день недели на уменьшение по кольцу
  if (!Length){                                                                             //если "Length==2" выводим сокращённые названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Mon --",240,150,1);    break;                                  //выводим понедельник
    case 2: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Tue --",240,150,1);   break;                                   //выводим вторник
    case 3: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Wed --",240,150,1); break;                                     //выводим среда
    case 4: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Thu --",240,150,1);  break;                                    //выводим четверг
    case 5: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Fri --",240,150,1);    break;                                  //выводим пятница
    case 6: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Sat --",240,150,1);  break;                                    //выводим суббота
    case 7: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("-- Sun --",240,150,1);    break;} break;}                         //выводим воскресенье
  if (Length){                                                                              //если "Length==1" выводим полные названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Monday",240,150,1);    break;                                     //выводим понедельник
    case 2: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Tuesday",240,150,1);   break;                                     //выводим вторник
    case 3: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Wednesday",240,150,1); break;                                     //выводим среда
    case 4: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Thursday",240,150,1);  break;                                     //выводим четверг
    case 5: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Friday",240,150,1);    break;                                     //выводим пятница
    case 6: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Saturday",240,150,1);  break;                                     //выводим суббота
    case 7: tft.fillRect(135,149,215,42,TFT_BLACK);                                         //затираем предыдущую надпись
    tft.drawCentreString("Sunday",240,150,1);    break;} break;}}}                          //выводим воскресенье
  if (place==5){tft.setTextColor(Cclock);                                                   //выбираем цвет текста для восстановления значения дней недели
  if (!Length){                                                                             //если "Length==0" выводим сокращённые названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.drawCentreString("-- Mon --",240,150,1); break;                             //выводим понедельник
    case 2: tft.drawCentreString("-- Tue --",240,150,1); break;                             //выводим вторник
    case 3: tft.drawCentreString("-- Wed --",240,150,1); break;                             //выводим среда
    case 4: tft.drawCentreString("-- Thu --",240,150,1); break;                             //выводим четверг
    case 5: tft.drawCentreString("-- Fri --",240,150,1); break;                             //выводим пятница
    case 6: tft.drawCentreString("-- Sat --",240,150,1); break;                             //выводим суббота
    case 7: tft.drawCentreString("-- Sun --",240,150,1); break;}}                           //выводим воскресенье
  if (Length){                                                                              //если "Length==1" выводим полные названия дней недели
  switch (dy) {                                                                             //--- дни недели ---
    case 1: tft.drawCentreString("Monday",240,150,1);    break;                             //выводим понедельник
    case 2: tft.drawCentreString("Tuesday",240,150,1);   break;                             //выводим вторник
    case 3: tft.drawCentreString("Wednesday",240,150,1); break;                             //выводим среда
    case 4: tft.drawCentreString("Thursday",240,150,1);  break;                             //выводим четверг
    case 5: tft.drawCentreString("Friday",240,150,1);    break;                             //выводим пятница
    case 6: tft.drawCentreString("Saturday",240,150,1);  break;                             //выводим суббота
    case 7: tft.drawCentreString("Sunday",240,150,1);    break;}}                           //выводим воскресенье
  if (mo<10){tft.drawChar('0',176,220,7); tft.drawNumber(mo,208,220,7);}                    //если показания месяца меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mo,176,220,7);                                                        //выводим значение месяца  
    tft.setTextColor(TFT_RED,TFT_BLACK);                                                    //выбираем цвет даты
  if (da<10){tft.drawChar('0',100,220,7); tft.drawNumber(da,132,220,7);}                    //если показания даты меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(da,100,220,7);                                                        //выводим значение даты
  switch (button3.Loop()){                                                                  //кнопкой "Day" короткими нажатиями
    case SB_CLICK: da++; beeper(); if (da>31){da=1;}                                        //выставляем новое значение даты на увеличение по кольцу
  if (da<10){tft.drawChar('0',100,220,7); tft.drawNumber(da,132,220,7);}                    //если показания даты меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(da,100,220,7); break;                                                 //выводим значение даты
    case SB_AUTO_CLICK: da++; beeper(); if (da>31){da=1;}                                   //длинным нажатием перебираем дату на увеличение до отпускания кнопки
  if (da<10){tft.drawChar('0',100,220,7); tft.drawNumber(da,132,220,7);}                    //если показания даты меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(da,100,220,7); break;}                                                //выводим значение даты
  switch (button4.Loop()){                                                                  //кнопкой "Day" короткими нажатиями
    case SB_CLICK: da--; beeper(); if (da<1){da=31;}                                        //выставляем новое значение даты на уменьшение по кольцу
  if (da<10){tft.drawChar('0',100,220,7); tft.drawNumber(da,132,220,7);}                    //если показания даты меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(da,100,220,7); break;                                                 //выводим значение даты
    case SB_AUTO_CLICK: da--; beeper(); if (da<1){da=31;}                                   //длинным нажатием перебираем дату на уменьшение до отпускания кнопки
  if (da<10){tft.drawChar('0',100,220,7); tft.drawNumber(da,132,220,7);}                    //если показания даты меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(da,100,220,7); break;}}                                               //выводим значение даты
  if (place==6){tft.setTextColor(Cclock,TFT_BLACK);                                         //выбираем цвет текста для восстановления значения даты
  if (da<10){tft.drawChar('0',100,220,7); tft.drawNumber(da,132,220,7);}                    //если показания даты меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(da,100,220,7);                                                        //выводим значение даты
    tft.drawNumber((int)ya+1970,250,220,7);                                                 //восстанавливаем цвет значения года
    tft.setTextColor(TFT_RED,TFT_BLACK);                                                    //выбираем цвет месяца
  if (mo<10){tft.drawChar('0',176,220,7); tft.drawNumber(mo,208,220,7);}                    //если показания месяца меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mo,176,220,7);                                                        //выводим значение месяца
  switch (button3.Loop()){                                                                  //кнопкой "Month" короткими нажатиями
    case SB_CLICK: mo++; beeper(); if (mo>12){mo=1;}                                        //выставляем новое значение месяца на увеличение по кольцу
  if (mo<10){tft.drawChar('0',176,220,7); tft.drawNumber(mo,208,220,7);}                    //если показания месяца меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mo,176,220,7); break;}                                                //выводим значение месяца
  switch (button4.Loop()){                                                                  //кнопкой "Month" короткими нажатиями
    case SB_CLICK: mo--; beeper(); if (mo<1){mo=12;}                                        //выставляем новое значение месяца на уменьшение по кольцу
  if (mo<10){tft.drawChar('0',176,220,7); tft.drawNumber(mo,208,220,7);}                    //если показания месяца меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mo,176,220,7); break;}}                                               //выводим значение месяца
  if (place==7){tft.setTextColor(Cclock,TFT_BLACK);                                         //выбираем цвет текста для восстановления значения месяца
  if (mo<10){tft.drawChar('0',176,220,7); tft.drawNumber(mo,208,220,7);}                    //если показания месяца меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(mo,176,220,7);                                                        //выводим значение месяца
  if (hh<10){tft.drawChar('0',137,75,7); tft.drawNumber(hh,169,75,7);}                      //если показания часов меньше 10 дорисовываем незначащий ноль
  else tft.drawNumber(hh,137,75,7);                                                         //выводим значение часов
    tft.setTextColor(TFT_RED,TFT_BLACK);                                                    //выбираем цвет года
    tft.drawNumber((int)ya+1970,250,220,7);                                                 //выводим значение года
  switch (button3.Loop()){                                                                  //кнопкой "Year" короткими нажатиями
    case SB_CLICK: ya++; beeper(); if (ya>59){ya=49;}                                       //выставляем новое значение года на увеличение по кольцу
    tft.drawNumber((int)ya+1970,250,220,7); break;}                                         //выводим значение года
  switch (button4.Loop()){                                                                  //кнопкой "Year" короткими нажатиями
    case SB_CLICK: ya--; beeper(); if (ya<49){ya=59;}                                       //выставляем новое значение года на уменьшение по кольцу
    tft.drawNumber((int)ya+1970,250,220,7); break;}}                                        //выводим значение года
}   Wire.beginTransmission(104);                                                            //при выходе из цикла установки опрашиваем адрес I2C
    Wire.write(0);                                                                          //начинаем передачу данных
    Wire.write(decToBcd(ss));                                                               //задаем секунды
    Wire.write(decToBcd(mm));                                                               //задаем минуты
    Wire.write(decToBcd(hh));                                                               //задаем часы
    Wire.write(decToBcd(dy));                                                               //задаем день недели
    Wire.write(decToBcd(da));                                                               //задаем число
    Wire.write(decToBcd(mo));                                                               //задаем месяц
    Wire.write(decToBcd(tmYearToY2k(ya)));                                                  //задаем год
    Wire.endTransmission();}                                                                //завершаем передачу данных
  else {tft.setFreeFont(FSBI24);                                                            //иначе выбираем шрифт
    tft.setTextColor(TFT_SILVER); tft.drawCentreString("The DS3231 module",243,103,1);      //выводим подложку надписи "The DS3231 module"
    tft.setTextColor(TFT_RED); tft.drawCentreString("The DS3231 module",240,100,1);         //выводим надпись "The DS3231 module"
    tft.setTextColor(TFT_SILVER); tft.drawCentreString("is not connected",243,173,1);       //выводим подложку надписи "is not connected"
    tft.setTextColor(TFT_RED); tft.drawCentreString("is not connected",240,170,1);          //выводим надпись "is not connected"
    delay(3000);}                                                                           //задержка для индикации надписи
    tft.fillRoundRect(8,8,464,304,8,TFT_BLACK);                                             //рисуем черный прямоугольник фона
    tft.setFreeFont(FSSB9); tft.setTextColor(BORDER);                                       //выбираем шрифт и цвет текста
    tft.drawString("page 4",25,20,1);                                                       //выводим надпись "page 3"
    tft.setFreeFont(FSBI12);                                                                //выбираем шрифт
    tft.drawCentreString("-- MENU --",240,20,1);                                            //выводим надпись "-- MENU --"
    tft.setTextColor(TFT_SILVER);                                                           //выбираем цвет текста
    tft.drawString("25. ALC",25,50,1);                                                      //выводим надпись "25. ALC"
    tft.drawString("ON / OFF",199,50,1);                                                    //выводим надпись "ON/OFF"
    tft.setTextColor(TFT_DARKGREY); tft.drawCentreString("D0ITC 2019 D0ISM",240,281,1);     //выводим надпись "D0ITC 2019 D0ISM"
    int Select25,Select27,Select28;                                                         //переменные ALC и цвета вывода часов
    ALC=EEPROM.read(37); Select25=ALC;                                                      //читаем содержимое ячейки 37 EEPROM в переменную ALC
    Cclock=EEPROM.read(38); Select27=Cclock;                                                //читаем содержимое ячейки 38 EEPROM в переменную Cclock
    powerin=EEPROM.read(39); Select28=powerin;                                              //читаем содержимое ячейки 39 EEPROM в переменную  powerin
  if (Select25==2){tft.setTextColor(TFT_SILVER); tft.drawCentreString("ON",430,50,1);       //если значение ячейки 37 EEPROM "2" выводим по центру редактируемую надпись "ON"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("ON",360,50,1);}                     //при загрузке третьей страницы меню выводим по центру текущую надпись "ON"
  if (Select25==1){tft.setTextColor(TFT_SILVER); tft.drawCentreString("OFF",430,50,1);      //если значение ячейки 37 EEPROM "1" выводим по центру редактируемую надпись "OFF"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("OFF",360,50,1);}                    //при загрузке третьей страницы меню выводим по центру текущую надпись "OFF"
    tft.setTextColor(TFT_SILVER); tft.drawString("27. The color of the clock",25,116,1);    //выводим надпись "27. The color of the clock"
    tft.drawString("28. Powerin",25,149,1);                                                 //выводим надпись "28. Powerin"
    tft.drawString("3W / 30W",199,149,1);                                                   //выводим надпись "3W / 30W"
  if (Select27==5){tft.setTextColor(TFT_CYAN); tft.drawCentreString("CYAN",425,116,1);      //если значение ячейки 38 EEPROM "3" выводим по центру редактируемую надпись "CYAN"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("CYAN",355,116,1);}                  //при загрузке четвёртой страницы меню выводим по центру текущую надпись "CYAN"
  if (Select27==4){tft.setTextColor(TFT_ORANGE); tft.drawCentreString("ORG",425,116,1);     //если значение ячейки 38 EEPROM "3" выводим по центру редактируемую надпись "ORG"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("ORG",355,116,1);}                   //при загрузке четвёртой страницы меню выводим по центру текущую надпись "ORG"  
  if (Select27==3){tft.setTextColor(TFT_PINK); tft.drawCentreString("PINK",425,116,1);      //если значение ячейки 38 EEPROM "3" выводим по центру редактируемую надпись "PINK"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("PINK",355,116,1);}                  //при загрузке третьей страницы меню выводим по центру текущую надпись "PINK"
  if (Select27==2){tft.setTextColor(TFT_SILVER); tft.drawCentreString("SIL",425,116,1);     //если значение ячейки 38 EEPROM "2" выводим по центру редактируемую надпись "SIL"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("SIL",355,116,1);}                   //при загрузке третьей страницы меню выводим по центру текущую надпись "SIL"
  if (Select27==1){tft.setTextColor(TFT_GREEN); tft.drawCentreString("GRN",425,116,1);      //если значение ячейки 38 EEPROM "1" выводим по центру редактируемую надпись "GRN"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("GRN",355,116,1);}                   //при загрузке третьей страницы меню выводим по центру текущую надпись "GRN"
  if (Select28==0){tft.setTextColor(TFT_SILVER); tft.drawCentreString("3W",430,149,1);      //если значение ячейки 39 EEPROM "2" выводим по центру редактируемую надпись "3W"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("3W",360,149,1);}                    //при загрузке четвёртой страницы меню выводим по центру текущую надпись "3W"
  if (Select28==1){tft.setTextColor(TFT_SILVER); tft.drawCentreString("30W",430,149,1);     //если значение ячейки 39 EEPROM "1" выводим по центру редактируемую надпись "30W"
    tft.setTextColor(TFT_GREY60); tft.drawCentreString("30W",360,149,1);}                   //при загрузке четвёртой страницы меню выводим по центру текущую надпись "30W"  
}//******************************************************************************************************************************** Конец!!!
